package Locale::CLDR::Transformations::Sera::Latn::Ethi;
# This file auto generated from Data\common\transforms\und-Ethi-t-und-latn-m0-sera.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(\|q),
					result  => q(᎕),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|d),
					result  => q(᎔),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|qu),
					result  => q(᎙),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|dh),
					result  => q(᎘),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|h),
					result  => q(᎗),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|c),
					result  => q(᎖),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|r),
					result  => q(᎓),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|hr),
					result  => q(᎒),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|de),
					result  => q(᎑),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\|y),
					result  => q(᎐),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`\`),
					result  => q(\`),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`\!),
					result  => q(¡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\>),
					result  => q(›),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\<),
					result  => q(‹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\>\>),
					result  => q(»),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\<\<),
					result  => q(«),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:),
					result  => q(፡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`\?),
					result  => q(፧),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\+),
					result  => q(፠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\|\:),
					result  => q(፨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\-),
					result  => q(፦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\-\:),
					result  => q(፥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(፤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\,),
					result  => q(፣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\:),
					result  => q(።),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`9),
					result  => q(፱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`8),
					result  => q(፰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`7),
					result  => q(፯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`6),
					result  => q(፮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`5),
					result  => q(፭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`4),
					result  => q(፬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`3),
					result  => q(፫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`2),
					result  => q(፪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`1),
					result  => q(፩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`90),
					result  => q(፺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`80),
					result  => q(፹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`70),
					result  => q(፸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`60),
					result  => q(፷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`50),
					result  => q(፶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`40),
					result  => q(፵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`30),
					result  => q(፴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`20),
					result  => q(፳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`10),
					result  => q(፲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`100),
					result  => q(፻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`1000),
					result  => q(፲፻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`10000),
					result  => q(፼),
					revisit => 0,
				},
				{
					before  => q([^Kkgq]),
					after   => q(),
					replace => q(Y),
					result  => q(),
					revisit => 1,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(([OU])),
					result  => q(),
					revisit => 12,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(([BFJLMRV])),
					result  => q(),
					revisit => 10,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(ፕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pW),
					result  => q(ᎏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pWE),
					result  => q(ᎎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pWa),
					result  => q(ፗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pWi),
					result  => q(ᎍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pWu),
					result  => q(ᎏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pWe),
					result  => q(ᎌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(po),
					result  => q(ፖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(poa),
					result  => q(ⶒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pE),
					result  => q(ፔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pa),
					result  => q(ፓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pi),
					result  => q(ፒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pu),
					result  => q(ፑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pe),
					result  => q(ፐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fW),
					result  => q(ᎋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fWE),
					result  => q(ᎊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fWa),
					result  => q(ፏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fWi),
					result  => q(ᎉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fWu),
					result  => q(ᎋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fWe),
					result  => q(ᎈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fYa),
					result  => q(ፚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fo),
					result  => q(ፎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fE),
					result  => q(ፌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fa),
					result  => q(ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fi),
					result  => q(ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fu),
					result  => q(ፉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fe),
					result  => q(ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(S),
					result  => q(ጽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(SWa),
					result  => q(ጿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(So),
					result  => q(ጾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(SE),
					result  => q(ጼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Sa),
					result  => q(ጻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Si),
					result  => q(ጺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Su),
					result  => q(ጹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Se),
					result  => q(ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` S),
					result  => q(ፅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` So),
					result  => q(ፆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Soa),
					result  => q(ፇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` SE),
					result  => q(ፄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Sa),
					result  => q(ፃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Si),
					result  => q(ፂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Su),
					result  => q(ፁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Se),
					result  => q(ፀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(P),
					result  => q(ጵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(PWa),
					result  => q(ጷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Po),
					result  => q(ጶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Poa),
					result  => q(ⶑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(PE),
					result  => q(ጴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Pa),
					result  => q(ጳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Pi),
					result  => q(ጲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Pu),
					result  => q(ጱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Pe),
					result  => q(ጰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gW),
					result  => q(ጕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gWE),
					result  => q(ጔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gWa),
					result  => q(ጓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gWi),
					result  => q(ጒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gWu),
					result  => q(ጕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gWe),
					result  => q(ጐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(go),
					result  => q(ጎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(goa),
					result  => q(ጏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gE),
					result  => q(ጌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ga),
					result  => q(ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gi),
					result  => q(ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gu),
					result  => q(ጉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ge),
					result  => q(ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gY),
					result  => q(ⷝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gYo),
					result  => q(ⷞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gYE),
					result  => q(ⷜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gYa),
					result  => q(ⷛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gYi),
					result  => q(ⷚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gYu),
					result  => q(ⷙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gYe),
					result  => q(ⷘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jWa),
					result  => q(ጇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jo),
					result  => q(ጆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(joa),
					result  => q(ⶎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jE),
					result  => q(ጄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ja),
					result  => q(ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ji),
					result  => q(ጂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ju),
					result  => q(ጁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(je),
					result  => q(ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dWa),
					result  => q(ዷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(do),
					result  => q(ዶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(doa),
					result  => q(ⶌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dE),
					result  => q(ዴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(da),
					result  => q(ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(di),
					result  => q(ዲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(du),
					result  => q(ዱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(de),
					result  => q(ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(D),
					result  => q(ዽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(DWa),
					result  => q(ዿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Do),
					result  => q(ዾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Doa),
					result  => q(ⶍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(DE),
					result  => q(ዼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Da),
					result  => q(ዻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Di),
					result  => q(ዺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Du),
					result  => q(ዹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(De),
					result  => q(ዸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yo),
					result  => q(ዮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yoa),
					result  => q(ዯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yE),
					result  => q(ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ya),
					result  => q(ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yi),
					result  => q(ዪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(yu),
					result  => q(ዩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ye),
					result  => q(የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zWa),
					result  => q(ዟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zo),
					result  => q(ዞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zoa),
					result  => q(ⶋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zE),
					result  => q(ዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(za),
					result  => q(ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zi),
					result  => q(ዚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zu),
					result  => q(ዙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ze),
					result  => q(ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Z),
					result  => q(ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ZWa),
					result  => q(ዧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Zo),
					result  => q(ዦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ZE),
					result  => q(ዤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Za),
					result  => q(ዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Zi),
					result  => q(ዢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Zu),
					result  => q(ዡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ze),
					result  => q(ዠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Z),
					result  => q(ⶵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Zo),
					result  => q(ⶶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ZE),
					result  => q(ⶴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Za),
					result  => q(ⶳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Zi),
					result  => q(ⶲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Zu),
					result  => q(ⶱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Ze),
					result  => q(ⶰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(ዕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(ዖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(ዔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(ዓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(ዒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(ዑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`e),
					result  => q(ዐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wo),
					result  => q(ዎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(woa),
					result  => q(ዏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wE),
					result  => q(ዌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wa),
					result  => q(ዋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wi),
					result  => q(ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(wu),
					result  => q(ዉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(we),
					result  => q(ወ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kW),
					result  => q(ኵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kWE),
					result  => q(ኴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kWa),
					result  => q(ኳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kWi),
					result  => q(ኲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kWu),
					result  => q(ኵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kWe),
					result  => q(ኰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ko),
					result  => q(ኮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(koa),
					result  => q(ኯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kE),
					result  => q(ኬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ka),
					result  => q(ካ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ki),
					result  => q(ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ku),
					result  => q(ኩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ke),
					result  => q(ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kY),
					result  => q(ⷍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kYo),
					result  => q(ⷎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kYE),
					result  => q(ⷌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kYa),
					result  => q(ⷋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kYi),
					result  => q(ⷊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kYu),
					result  => q(ⷉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kYe),
					result  => q(ⷈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(K),
					result  => q(ኽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KW),
					result  => q(ዅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KWE),
					result  => q(ዄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KWa),
					result  => q(ዃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KWi),
					result  => q(ዂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KWu),
					result  => q(ዅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KWe),
					result  => q(ዀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ko),
					result  => q(ኾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KE),
					result  => q(ኼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ka),
					result  => q(ኻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ki),
					result  => q(ኺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ku),
					result  => q(ኹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ke),
					result  => q(ኸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KY),
					result  => q(ⷕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KYo),
					result  => q(ⷖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KYE),
					result  => q(ⷔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KYa),
					result  => q(ⷓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KYi),
					result  => q(ⷒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KYu),
					result  => q(ⷑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(KYe),
					result  => q(ⷐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(ኦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(ⶊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(እ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(ኢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(ኤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(ኡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'a),
					result  => q(አ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(ኧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(ኣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ⶊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(እ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(አ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nWa),
					result  => q(ኗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(no),
					result  => q(ኖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(noa),
					result  => q(ⶈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nE),
					result  => q(ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(na),
					result  => q(ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ni),
					result  => q(ኒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(nu),
					result  => q(ኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ne),
					result  => q(ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(N),
					result  => q(ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(NWa),
					result  => q(ኟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(No),
					result  => q(ኞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Noa),
					result  => q(ⶉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(NE),
					result  => q(ኜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Na),
					result  => q(ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ni),
					result  => q(ኚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Nu),
					result  => q(ኙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ne),
					result  => q(ኘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(G),
					result  => q(ጝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GW),
					result  => q(ⶖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GWE),
					result  => q(ⶕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GWa),
					result  => q(ጟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GWi),
					result  => q(ⶔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GWu),
					result  => q(ⶖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GWe),
					result  => q(ⶓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Go),
					result  => q(ጞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GE),
					result  => q(ጜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ga),
					result  => q(ጛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Gi),
					result  => q(ጚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Gu),
					result  => q(ጙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ge),
					result  => q(ጘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ho),
					result  => q(ሆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hoa),
					result  => q(ሇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hE),
					result  => q(ሄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hi),
					result  => q(ሂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ha),
					result  => q(ሃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hu),
					result  => q(ሁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(he),
					result  => q(ሀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hW),
					result  => q(ኍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hWE),
					result  => q(ኌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hWa),
					result  => q(ኋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hWi),
					result  => q(ኊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hWu),
					result  => q(ኍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(hWe),
					result  => q(ኈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` h),
					result  => q(ኅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hW),
					result  => q(ኍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hWE),
					result  => q(ኌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hWa),
					result  => q(ኋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hWi),
					result  => q(ኊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hWu),
					result  => q(ኍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hWe),
					result  => q(ኈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ho),
					result  => q(ኆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hoa),
					result  => q(ኇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hE),
					result  => q(ኄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ha),
					result  => q(ኃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hi),
					result  => q(ኂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` hu),
					result  => q(ኁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` he),
					result  => q(ኀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(c),
					result  => q(ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cWa),
					result  => q(ቿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(co),
					result  => q(ቾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(coa),
					result  => q(ⶇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cE),
					result  => q(ቼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ca),
					result  => q(ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ci),
					result  => q(ቺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(cu),
					result  => q(ቹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ce),
					result  => q(ቸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` c),
					result  => q(ⶭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` co),
					result  => q(ⶮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` cE),
					result  => q(ⶬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ca),
					result  => q(ⶫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ci),
					result  => q(ⶪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` cu),
					result  => q(ⶩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ce),
					result  => q(ⶨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(C),
					result  => q(ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Co),
					result  => q(ጮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Coa),
					result  => q(ⶐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ca),
					result  => q(ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ci),
					result  => q(ጪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(CE),
					result  => q(ጬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Cu),
					result  => q(ጩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(CWa),
					result  => q(ጯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ce),
					result  => q(ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` C),
					result  => q(ⶽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Co),
					result  => q(ⶾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Ca),
					result  => q(ⶻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Ci),
					result  => q(ⶺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` CE),
					result  => q(ⶼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Cu),
					result  => q(ⶹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` Ce),
					result  => q(ⶸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tWa),
					result  => q(ቷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(to),
					result  => q(ቶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(toa),
					result  => q(ⶆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tE),
					result  => q(ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ta),
					result  => q(ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ti),
					result  => q(ቲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tu),
					result  => q(ቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(te),
					result  => q(ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(T),
					result  => q(ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(TWa),
					result  => q(ጧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(To),
					result  => q(ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Toa),
					result  => q(ⶏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(TE),
					result  => q(ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ta),
					result  => q(ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ti),
					result  => q(ጢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Tu),
					result  => q(ጡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Te),
					result  => q(ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(ቭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vWa),
					result  => q(ቯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vo),
					result  => q(ቮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vE),
					result  => q(ቬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(va),
					result  => q(ቫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vi),
					result  => q(ቪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(vu),
					result  => q(ቩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ve),
					result  => q(ቨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bW),
					result  => q(ᎇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bWE),
					result  => q(ᎆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bWa),
					result  => q(ቧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bWi),
					result  => q(ᎅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bWu),
					result  => q(ᎇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bWe),
					result  => q(ᎄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bo),
					result  => q(ቦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(boa),
					result  => q(ⶅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bE),
					result  => q(ቤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ba),
					result  => q(ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bi),
					result  => q(ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bu),
					result  => q(ቡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(be),
					result  => q(በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qW),
					result  => q(ቊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qWE),
					result  => q(ቌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qWa),
					result  => q(ቋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qWu),
					result  => q(ቍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qWi),
					result  => q(ቊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qWe),
					result  => q(ቈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qo),
					result  => q(ቆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qoa),
					result  => q(ቇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qE),
					result  => q(ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qa),
					result  => q(ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qi),
					result  => q(ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qu),
					result  => q(ቁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qe),
					result  => q(ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Q),
					result  => q(ቕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(QW),
					result  => q(ቝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(QWE),
					result  => q(ቜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(QWa),
					result  => q(ቛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(QWi),
					result  => q(ቚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(QWu),
					result  => q(ቝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(QWe),
					result  => q(ቘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Qo),
					result  => q(ቖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(QE),
					result  => q(ቔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Qa),
					result  => q(ቓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Qi),
					result  => q(ቒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Qu),
					result  => q(ቑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Qe),
					result  => q(ቐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qY),
					result  => q(ⷅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qYo),
					result  => q(ⷆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qYE),
					result  => q(ⷄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qYa),
					result  => q(ⷃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qYi),
					result  => q(ⷂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qYu),
					result  => q(ⷁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qYe),
					result  => q(ⷀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sWa),
					result  => q(ሷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(so),
					result  => q(ሶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(soa),
					result  => q(ⶃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sE),
					result  => q(ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sa),
					result  => q(ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(si),
					result  => q(ሲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(su),
					result  => q(ሱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(se),
					result  => q(ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xWa),
					result  => q(ሿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xo),
					result  => q(ሾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xoa),
					result  => q(ⶄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xE),
					result  => q(ሼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xa),
					result  => q(ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xi),
					result  => q(ሺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xu),
					result  => q(ሹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(xe),
					result  => q(ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` x),
					result  => q(ⶥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` xo),
					result  => q(ⶦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` xE),
					result  => q(ⶤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` xa),
					result  => q(ⶣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` xi),
					result  => q(ⶢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` xu),
					result  => q(ⶡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` xe),
					result  => q(ⶠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rYa),
					result  => q(ፘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ro),
					result  => q(ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(roa),
					result  => q(ⶂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rE),
					result  => q(ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ra),
					result  => q(ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ri),
					result  => q(ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ru),
					result  => q(ሩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(rWa),
					result  => q(ሯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(re),
					result  => q(ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` s),
					result  => q(ሥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` sWa),
					result  => q(ሧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` so),
					result  => q(ሦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` sE),
					result  => q(ሤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` sa),
					result  => q(ሣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` si),
					result  => q(ሢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` su),
					result  => q(ሡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` se),
					result  => q(ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mW),
					result  => q(ᎃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mWE),
					result  => q(ᎂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mWa),
					result  => q(ሟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mWi),
					result  => q(ᎁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mWu),
					result  => q(ᎃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mWe),
					result  => q(ᎀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mYa),
					result  => q(ፙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mo),
					result  => q(ሞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(moa),
					result  => q(ⶁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mE),
					result  => q(ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ma),
					result  => q(ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mi),
					result  => q(ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(mu),
					result  => q(ሙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(me),
					result  => q(መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lWa),
					result  => q(ሏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lo),
					result  => q(ሎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(loa),
					result  => q(ⶀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lE),
					result  => q(ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(la),
					result  => q(ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(li),
					result  => q(ሊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(lu),
					result  => q(ሉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(le),
					result  => q(ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(H),
					result  => q(ሕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(HWa),
					result  => q(ሗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ho),
					result  => q(ሖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(HE),
					result  => q(ሔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ha),
					result  => q(ሓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Hi),
					result  => q(ሒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Hu),
					result  => q(ሑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(He),
					result  => q(ሐ),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
