package Locale::CLDR::Transformations::Ungegn::Sinh::Latn;
# This file auto generated from Data\common\transforms\Sinhala-Latin.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ක),
					result  => q(k|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඛ),
					result  => q(kh|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ග),
					result  => q(g|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඝ),
					result  => q(gh|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඞ),
					result  => q(ṁ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ච),
					result  => q(ch|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඡ),
					result  => q(chh|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ජ),
					result  => q(j|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඣ),
					result  => q(q|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඤ),
					result  => q(ñ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ට),
					result  => q(ṭ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඨ),
					result  => q(ṯ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඩ),
					result  => q(ḍ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඪ),
					result  => q(ḍh|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ණ),
					result  => q(ṇ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ත),
					result  => q(t|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ථ),
					result  => q(th|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ද),
					result  => q(d|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ධ),
					result  => q(dh|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(න),
					result  => q(n|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ප),
					result  => q(p|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඵ),
					result  => q(ph|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(බ),
					result  => q(b|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(භ),
					result  => q(bh|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ම),
					result  => q(m|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ය),
					result  => q(y|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ර),
					result  => q(r|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ල),
					result  => q(l|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ව),
					result  => q(v|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෆ),
					result  => q(f|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ශ),
					result  => q(ś|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෂ),
					result  => q(sh|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ස),
					result  => q(s|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(හ),
					result  => q(h|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ළ),
					result  => q(ḷ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඟ),
					result  => q(n̆g|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඥ),
					result  => q(gn|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඦ),
					result  => q(n̆ǰ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඬ),
					result  => q(n̆ḍ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඳ),
					result  => q(n̆d|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඹ),
					result  => q(ḅ|a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(අ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ආ),
					result  => q(ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඇ),
					result  => q(æ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඈ),
					result  => q(ǣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඉ),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඊ),
					result  => q(ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(උ),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඌ),
					result  => q(ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(එ),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඒ),
					result  => q(ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඔ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඕ),
					result  => q(ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ං),
					result  => q(ṅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඍ),
					result  => q(ṛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ඖ),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a්),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aා),
					result  => q(ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aැ),
					result  => q(æ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෑ),
					result  => q(ǣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aි),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aී),
					result  => q(ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aු),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aූ),
					result  => q(ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෘ),
					result  => q(ṛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෙ),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aේ),
					result  => q(ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෛ),
					result  => q(ĩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aො),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෝ),
					result  => q(ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෞ),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෟ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(aෲ),
					result  => q(rr),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ා),
					result  => q(ā),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ැ),
					result  => q(æ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෑ),
					result  => q(ǣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ි),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ී),
					result  => q(ī),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ු),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ූ),
					result  => q(ū),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෘ),
					result  => q(ṛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෙ),
					result  => q(e),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ේ),
					result  => q(ē),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෛ),
					result  => q(ĩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ො),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෝ),
					result  => q(ō),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෞ),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෟ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ෲ),
					result  => q(rr),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
