package Locale::CLDR::Transformations::Tekie_alibekit::Byn_latn::Byn_ethi;
# This file auto generated from Data\common\transforms\byn-Ethi-t-byn-latn-m0-tekie-alibekit.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(፡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(፤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(፦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(፣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(።),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(1),
					result  => q(፩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(10),
					result  => q(፲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(100),
					result  => q(፻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(፼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(9),
					result  => q(፱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(8),
					result  => q(፰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(7),
					result  => q(፯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(6),
					result  => q(፮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(5),
					result  => q(፭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(4),
					result  => q(፬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(3),
					result  => q(፫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(2),
					result  => q(፪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(90),
					result  => q(፺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(80),
					result  => q(፹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(70),
					result  => q(፸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(60),
					result  => q(፷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(50),
					result  => q(፶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(40),
					result  => q(፵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(30),
					result  => q(፴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(20),
					result  => q(፳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ሆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ሄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ሂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ሁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ሀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ኌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ኋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ኊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ኍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h\'),
					result  => q(ኈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ),
					result  => q(ሕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ\'),
					result  => q(ሗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ\'),
					result  => q(ሖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ\'),
					result  => q(ሕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ\'),
					result  => q(ሔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ\'),
					result  => q(ሒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ\'),
					result  => q(ሑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ħ\'),
					result  => q(ሐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(ፕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p\'),
					result  => q(ፐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(fy\'),
					result  => q(ፚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f\'),
					result  => q(ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ሷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ሶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ሲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ሱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s\'),
					result  => q(ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ),
					result  => q(ጽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sʾ\'),
					result  => q(ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ),
					result  => q(ጵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pʾ\'),
					result  => q(ጰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ቷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ቶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ቲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t\'),
					result  => q(ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ),
					result  => q(ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tʾ\'),
					result  => q(ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ),
					result  => q(ጝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ⶕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ⶔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ⶖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ⶓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ŋ\'),
					result  => q(ጘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ጉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g\'),
					result  => q(ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ),
					result  => q(ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ǧ\'),
					result  => q(ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ዷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ዶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ዴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ዲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ዱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d\'),
					result  => q(ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y\'),
					result  => q(ዮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y\'),
					result  => q(ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y\'),
					result  => q(ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y\'),
					result  => q(ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y\'),
					result  => q(ዪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y\'),
					result  => q(ዩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y\'),
					result  => q(የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z\'),
					result  => q(ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ),
					result  => q(ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(zʾ\'),
					result  => q(ዠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʕ\'),
					result  => q(ዖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʕ\'),
					result  => q(ዕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʕ\'),
					result  => q(ዔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʕ\'),
					result  => q(ዓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʕ\'),
					result  => q(ዒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʕ\'),
					result  => q(ዑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w\'),
					result  => q(ዎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w\'),
					result  => q(ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w\'),
					result  => q(ዌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w\'),
					result  => q(ዋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w\'),
					result  => q(ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w\'),
					result  => q(ዉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w\'),
					result  => q(ወ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ካ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ኩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k\'),
					result  => q(ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(ኽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ዄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ዃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ዂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ዅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ዀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ኾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ኽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ኼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ኻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ኺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ኹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x\'),
					result  => q(ኸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ\'),
					result  => q(ኧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ\'),
					result  => q(ኦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ\'),
					result  => q(እ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ\'),
					result  => q(ኤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ\'),
					result  => q(ኢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ\'),
					result  => q(ኡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʔ\'),
					result  => q(አ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ),
					result  => q(ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ñ\'),
					result  => q(ኘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ኗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ኖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ኒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n\'),
					result  => q(ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č),
					result  => q(ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ቿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ቾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ቼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ቺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ቹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(č\'),
					result  => q(ቸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ),
					result  => q(ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(čʾ\'),
					result  => q(ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v),
					result  => q(ቭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(v\'),
					result  => q(ቨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(ቧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(ቦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(ቤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(ቡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b\'),
					result  => q(በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ),
					result  => q(ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʷʾ\'),
					result  => q(ቌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʷʾ\'),
					result  => q(ቋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʷʾ\'),
					result  => q(ቊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʷʾ\'),
					result  => q(ቍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʷʾ\'),
					result  => q(ቈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ\'),
					result  => q(ቆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ\'),
					result  => q(ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ\'),
					result  => q(ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ\'),
					result  => q(ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ\'),
					result  => q(ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ\'),
					result  => q(ቁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(kʾ\'),
					result  => q(ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ),
					result  => q(ቕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʷʾ\'),
					result  => q(ቜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʷʾ\'),
					result  => q(ቛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʷʾ\'),
					result  => q(ቚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʷʾ\'),
					result  => q(ቝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʷʾ\'),
					result  => q(ቘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ\'),
					result  => q(ቖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ\'),
					result  => q(ቕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ\'),
					result  => q(ቔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ\'),
					result  => q(ቓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ\'),
					result  => q(ቒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ\'),
					result  => q(ቑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(qʾ\'),
					result  => q(ቐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š),
					result  => q(ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(š\'),
					result  => q(ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ry\'),
					result  => q(ፘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ሯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ሩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r\'),
					result  => q(ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(my\'),
					result  => q(ፙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(ሟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(ሞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(ሙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m\'),
					result  => q(መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ሏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ሎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ሊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ሉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l\'),
					result  => q(ለ),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
