package Locale::CLDR::Transformations::Any::Latin::Ug;
# This file auto generated from Data\common\transforms\ug-Latin.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFD),
				},
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(Y),
					result  => q(ي),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(I),
					result  => q(ى),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(É),
					result  => q(ې),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(W),
					result  => q(ۋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ü),
					result  => q(ۈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ö),
					result  => q(ۆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(U),
					result  => q(ۇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(O),
					result  => q(و),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(H),
					result  => q(ھ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(N),
					result  => q(ن),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(M),
					result  => q(م),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(L),
					result  => q(ل),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(G),
					result  => q(گ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ng),
					result  => q(ڭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(NG),
					result  => q(ڭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(K),
					result  => q(ك),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Q),
					result  => q(ق),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(F),
					result  => q(ف),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Gh),
					result  => q(غ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GH),
					result  => q(غ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(S),
					result  => q(س),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Sh),
					result  => q(ش),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(SH),
					result  => q(ش),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Z),
					result  => q(ز),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(R),
					result  => q(ر),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(D),
					result  => q(د),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(X),
					result  => q(خ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(Ch),
					result  => q(چ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(CH),
					result  => q(چ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(J),
					result  => q(ج),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(T),
					result  => q(ت),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(P),
					result  => q(پ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(B),
					result  => q(ب),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(E),
					result  => q(ە),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(A),
					result  => q(ا),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(y),
					result  => q(ي),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(i),
					result  => q(ى),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(é),
					result  => q(ې),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(w),
					result  => q(ۋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ü),
					result  => q(ۈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ö),
					result  => q(ۆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(u),
					result  => q(ۇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(o),
					result  => q(و),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(h),
					result  => q(ھ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(n),
					result  => q(ن),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(m),
					result  => q(م),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(l),
					result  => q(ل),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(g),
					result  => q(گ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ng),
					result  => q(ڭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(k),
					result  => q(ك),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(q),
					result  => q(ق),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(f),
					result  => q(ف),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(gh),
					result  => q(غ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(s),
					result  => q(س),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(sh),
					result  => q(ش),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(z),
					result  => q(ز),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(r),
					result  => q(ر),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(d),
					result  => q(د),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(x),
					result  => q(خ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ch),
					result  => q(چ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(j),
					result  => q(ج),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(t),
					result  => q(ت),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(p),
					result  => q(پ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(b),
					result  => q(ب),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(e),
					result  => q(ە),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(a),
					result  => q(ا),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(JANDARM),
					result  => q(ژاندارم),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(PROJÉKTOR),
					result  => q(پروژېكتور),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(STAJ),
					result  => q(ستاژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(TIRAJ),
					result  => q(تىراژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GHUJMEK),
					result  => q(غۇژمەك),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(GARAJ),
					result  => q(گاراژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(TAMOJNA),
					result  => q(تاموژنا),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ORANJÉ),
					result  => q(ئورانژې),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(WOLTAJ),
					result  => q(ۋولتاژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(BUJGHUN),
					result  => q(بۇژغۇن),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(JURNAL),
					result  => q(ژۇرنال),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(PARIJ),
					result  => q(پارىژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(MAROJ),
					result  => q(ماروژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(PÉRSONAJ),
					result  => q(پېرسوناژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(PURJIN),
					result  => q(پۇرژىن),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(CHÉRTYOJ),
					result  => q(چېرتيوژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(JURNILI),
					result  => q(ژۇرنىلى),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(RÉJISSOR),
					result  => q(رېژىسسور),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(DIRIJOR),
					result  => q(دىرىژور),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jandarm),
					result  => q(ژاندارم),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(projéktor),
					result  => q(پروژېكتور),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(staj),
					result  => q(ستاژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tiraj),
					result  => q(تىراژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ghujmek),
					result  => q(غۇژمەك),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(garaj),
					result  => q(گاراژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(tamojna),
					result  => q(تاموژنا),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(oranjé),
					result  => q(ئورانژې),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(woltaj),
					result  => q(ۋولتاژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(bujghun),
					result  => q(بۇژغۇن),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jurnal),
					result  => q(ژۇرنال),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(parij),
					result  => q(پارىژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(maroj),
					result  => q(ماروژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(pérsonaj),
					result  => q(پېرسوناژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(purjin),
					result  => q(پۇرژىن),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(chértyoj),
					result  => q(چېرتيوژ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(jurnili),
					result  => q(ژۇرنىلى),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(réjissor),
					result  => q(رېژىسسور),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(dirijor),
					result  => q(دىرىژور),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[iI]),
					result  => q(ئى),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[éÉ]),
					result  => q(ئې),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[üÜ]),
					result  => q(ئۈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[öÖ]),
					result  => q(ئۆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[uU]),
					result  => q(ئۇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[oO]),
					result  => q(ئو),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[eE]),
					result  => q(ئە),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q({[aA]),
					result  => q(ئا),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([iI]),
					result  => q(ئى),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([éÉ]),
					result  => q(ئې),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([üÜ]),
					result  => q(ئۈ),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([öÖ]),
					result  => q(ئۆ),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([uU]),
					result  => q(ئۇ),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([oO]),
					result  => q(ئو),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([eE]),
					result  => q(ئە),
					revisit => 0,
				},
				{
					before  => q(\p{Separator} *),
					after   => q(),
					replace => q([aA]),
					result  => q(ئا),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(’),
					result  => q(‹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(‘),
					result  => q(›),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(؟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(؛),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'),
					result  => q(،),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\'̱),
					result  => q(٫),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
