package Locale::CLDR::Transformations::Any::Am_brai::Am_ethi;
# This file auto generated from Data\common\transforms\am-Ethi-t-am-brai.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠃⠆⠿),
					result  => q(፱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠔⠆⠿),
					result  => q(፰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠊⠆⠿),
					result  => q(፯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠢⠿),
					result  => q(፮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠑⠆⠿),
					result  => q(፭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠤⠆⠿),
					result  => q(፬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠒⠆⠿),
					result  => q(፫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠉⠆⠿),
					result  => q(፪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠁⠆⠿),
					result  => q(፩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠃⠆⠿),
					result  => q(፺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠔⠆⠿),
					result  => q(፹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠊⠆⠿),
					result  => q(፸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠢⠆⠿),
					result  => q(፷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠑⠆⠿),
					result  => q(፶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠤⠆⠿),
					result  => q(፵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠒⠆⠿),
					result  => q(፴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠉⠆⠿),
					result  => q(፳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠅⠆⠿),
					result  => q(፲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠿⠁⠍⠁⠅⠿),
					result  => q(፻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠄),
					result  => q(\.),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠔⠔),
					result  => q(\*),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠤⠤),
					result  => q(\—),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠒),
					result  => q(፦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠒⠒),
					result  => q(\-),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠐⠂),
					result  => q(\/),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠶),
					result  => q(\(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠶⠄),
					result  => q(\]),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠠⠶),
					result  => q(\[),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠘),
					result  => q(\$),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠄⠠),
					result  => q(፡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠂),
					result  => q(፣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠆),
					result  => q(፤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠲),
					result  => q(።),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠄⠄⠄),
					result  => q(…),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏),
					result  => q(ፕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠥),
					result  => q(ፑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠭),
					result  => q(ፗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠺⠊),
					result  => q(ᎍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠺⠑),
					result  => q(ᎎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠺⠥),
					result  => q(ᎏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠺⠢),
					result  => q(ᎌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠕),
					result  => q(ፖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠁),
					result  => q(ፓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠊),
					result  => q(ፒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠑),
					result  => q(ፔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠏⠢),
					result  => q(ፐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋),
					result  => q(ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠥),
					result  => q(ፉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠭),
					result  => q(ፏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠺⠊),
					result  => q(ᎉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠺⠑),
					result  => q(ᎊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠺⠥),
					result  => q(ᎋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠺⠢),
					result  => q(ᎈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠕),
					result  => q(ፎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠁),
					result  => q(ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠊),
					result  => q(ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠑),
					result  => q(ፌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠋⠢),
					result  => q(ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮),
					result  => q(ጽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮⠕),
					result  => q(ጾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮⠁),
					result  => q(ጻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮⠊),
					result  => q(ጺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮⠑),
					result  => q(ጼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮⠥),
					result  => q(ጹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮⠭),
					result  => q(ጿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠮⠢),
					result  => q(ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠯),
					result  => q(ፅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠯⠕),
					result  => q(ፆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠯⠁),
					result  => q(ፃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠯⠊),
					result  => q(ፂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠯⠑),
					result  => q(ፄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠯⠥),
					result  => q(ፁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠯⠢),
					result  => q(ፀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖),
					result  => q(ጵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖⠕),
					result  => q(ጶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖⠁),
					result  => q(ጳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖⠊),
					result  => q(ጲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖⠑),
					result  => q(ጴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖⠥),
					result  => q(ጱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖⠭),
					result  => q(ጷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠖⠢),
					result  => q(ጰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛),
					result  => q(ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠥),
					result  => q(ጉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠭),
					result  => q(ጓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠺⠊),
					result  => q(ጒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠺⠑),
					result  => q(ጔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠺⠥),
					result  => q(ጕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠺⠢),
					result  => q(ጐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠕),
					result  => q(ጎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠁),
					result  => q(ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠊),
					result  => q(ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠑),
					result  => q(ጌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠛⠢),
					result  => q(ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚),
					result  => q(ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚⠕),
					result  => q(ጆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚⠁),
					result  => q(ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚⠊),
					result  => q(ጂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚⠑),
					result  => q(ጄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚⠥),
					result  => q(ጁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚⠭),
					result  => q(ጇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠚⠢),
					result  => q(ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙),
					result  => q(ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙⠕),
					result  => q(ዶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙⠁),
					result  => q(ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙⠊),
					result  => q(ዲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙⠑),
					result  => q(ዴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙⠥),
					result  => q(ዱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙⠭),
					result  => q(ዷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠙⠢),
					result  => q(ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠽),
					result  => q(ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠽⠕),
					result  => q(ዮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠽⠁),
					result  => q(ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠽⠊),
					result  => q(ዪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠽⠑),
					result  => q(ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠽⠥),
					result  => q(ዩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠽⠢),
					result  => q(የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵),
					result  => q(ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵⠕),
					result  => q(ዞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵⠁),
					result  => q(ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵⠊),
					result  => q(ዚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵⠑),
					result  => q(ዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵⠥),
					result  => q(ዙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵⠭),
					result  => q(ዟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠵⠢),
					result  => q(ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴),
					result  => q(ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠕),
					result  => q(ዦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠁),
					result  => q(ዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠊),
					result  => q(ዢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠑),
					result  => q(ዤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠥),
					result  => q(ዡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠭),
					result  => q(ዧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠢),
					result  => q(ዠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ዕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠕),
					replace => q(),
					result  => q(ዖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠊),
					replace => q(),
					result  => q(ዒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠑),
					replace => q(),
					result  => q(ዔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠁),
					replace => q(),
					result  => q(ዓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠥),
					replace => q(),
					result  => q(ዑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠢),
					replace => q(),
					result  => q(ዐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠺),
					result  => q(ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠺⠕),
					result  => q(ዎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠺⠁),
					result  => q(ዋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠺⠊),
					result  => q(ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠺⠑),
					result  => q(ዌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠺⠥),
					result  => q(ዉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠺⠢),
					result  => q(ወ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅),
					result  => q(ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠥),
					result  => q(ኩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠭),
					result  => q(ኳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠺⠊),
					result  => q(ኲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠺⠑),
					result  => q(ኴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠺⠥),
					result  => q(ኵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠺⠢),
					result  => q(ኰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠕),
					result  => q(ኮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠁),
					result  => q(ካ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠊),
					result  => q(ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠑),
					result  => q(ኬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠅⠢),
					result  => q(ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦),
					result  => q(ኽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠥),
					result  => q(ኹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠭),
					result  => q(ዃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠺⠊),
					result  => q(ዂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠺⠑),
					result  => q(ዄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠺⠥),
					result  => q(ዅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠺⠢),
					result  => q(ዀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠕),
					result  => q(ኾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠁),
					result  => q(ኻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠊),
					result  => q(ኺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠑),
					result  => q(ኼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠦⠢),
					result  => q(ኸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(እ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠕),
					replace => q(),
					result  => q(ኦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠑),
					replace => q(),
					result  => q(ኤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠁),
					replace => q(),
					result  => q(ኣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠊),
					replace => q(),
					result  => q(ኢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠥),
					replace => q(),
					result  => q(ኡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(⠢),
					replace => q(),
					result  => q(አ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝),
					result  => q(ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝⠕),
					result  => q(ኖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝⠁),
					result  => q(ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝⠊),
					result  => q(ኒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝⠑),
					result  => q(ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝⠥),
					result  => q(ኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝⠭),
					result  => q(ኗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠝⠢),
					result  => q(ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬),
					result  => q(ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬⠕),
					result  => q(ኞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬⠁),
					result  => q(ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬⠊),
					result  => q(ኚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬⠥),
					result  => q(ኙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬⠑),
					result  => q(ኜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬⠭),
					result  => q(ኟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠬⠢),
					result  => q(ኘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓),
					result  => q(ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠕),
					result  => q(ሆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠊),
					result  => q(ሂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠑),
					result  => q(ሄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠁),
					result  => q(ሃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠥),
					result  => q(ሁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠢),
					result  => q(ሀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠭),
					result  => q(ኋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠺⠊),
					result  => q(ኊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠺⠑),
					result  => q(ኌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠺⠥),
					result  => q(ኍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠓⠺⠢),
					result  => q(ኈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡),
					result  => q(ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡⠕),
					result  => q(ቾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡⠁),
					result  => q(ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡⠊),
					result  => q(ቺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡⠑),
					result  => q(ቼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡⠥),
					result  => q(ቹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡⠭),
					result  => q(ቿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠡⠢),
					result  => q(ቸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉),
					result  => q(ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉⠕),
					result  => q(ጮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉⠁),
					result  => q(ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉⠊),
					result  => q(ጪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉⠑),
					result  => q(ጬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉⠥),
					result  => q(ጩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉⠭),
					result  => q(ጯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠉⠢),
					result  => q(ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞),
					result  => q(ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞⠕),
					result  => q(ቶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞⠊),
					result  => q(ቲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞⠑),
					result  => q(ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞⠁),
					result  => q(ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞⠥),
					result  => q(ቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞⠭),
					result  => q(ቷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠞⠢),
					result  => q(ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾),
					result  => q(ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾⠕),
					result  => q(ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾⠁),
					result  => q(ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾⠊),
					result  => q(ጢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾⠑),
					result  => q(ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾⠥),
					result  => q(ጡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾⠭),
					result  => q(ጧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠾⠢),
					result  => q(ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧),
					result  => q(ቭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧⠕),
					result  => q(ቮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧⠁),
					result  => q(ቫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧⠊),
					result  => q(ቪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧⠑),
					result  => q(ቬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧⠥),
					result  => q(ቩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧⠭),
					result  => q(ቯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠧⠢),
					result  => q(ቨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃),
					result  => q(ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠥),
					result  => q(ቡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠭),
					result  => q(ቧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠺⠊),
					result  => q(ᎅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠺⠑),
					result  => q(ᎆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠺⠥),
					result  => q(ᎇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠺⠢),
					result  => q(ᎄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠕),
					result  => q(ቦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠁),
					result  => q(ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠊),
					result  => q(ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠑),
					result  => q(ቤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠃⠢),
					result  => q(በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟),
					result  => q(ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠥),
					result  => q(ቁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠭),
					result  => q(ቋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠺⠊),
					result  => q(ቊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠺⠑),
					result  => q(ቌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠺⠥),
					result  => q(ቍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠺⠢),
					result  => q(ቈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠕),
					result  => q(ቆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠁),
					result  => q(ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠊),
					result  => q(ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠑),
					result  => q(ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠟⠢),
					result  => q(ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎),
					result  => q(ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎⠕),
					result  => q(ሶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎⠊),
					result  => q(ሲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎⠑),
					result  => q(ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎⠁),
					result  => q(ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎⠥),
					result  => q(ሱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎⠭),
					result  => q(ሷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠎⠢),
					result  => q(ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩),
					result  => q(ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩⠕),
					result  => q(ሾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩⠊),
					result  => q(ሺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩⠑),
					result  => q(ሼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩⠁),
					result  => q(ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩⠥),
					result  => q(ሹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩⠭),
					result  => q(ሿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠩⠢),
					result  => q(ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗),
					result  => q(ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗⠕),
					result  => q(ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗⠊),
					result  => q(ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗⠑),
					result  => q(ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗⠁),
					result  => q(ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗⠥),
					result  => q(ሩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗⠭),
					result  => q(ሯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠗⠢),
					result  => q(ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍),
					result  => q(ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠥),
					result  => q(ሙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠭),
					result  => q(ሟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠺⠊),
					result  => q(ᎁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠺⠑),
					result  => q(ᎂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠺⠥),
					result  => q(ᎃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠺⠢),
					result  => q(ᎀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠕),
					result  => q(ሞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠊),
					result  => q(ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠑),
					result  => q(ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠁),
					result  => q(ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠍⠢),
					result  => q(መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇),
					result  => q(ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇⠕),
					result  => q(ሎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇⠊),
					result  => q(ሊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇⠑),
					result  => q(ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇⠁),
					result  => q(ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇⠥),
					result  => q(ሉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇⠭),
					result  => q(ሏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠇⠢),
					result  => q(ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠴⠄),
					result  => q(›),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(⠠⠦),
					result  => q(‹),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
