package Locale::CLDR::Transformations::Gutgarts::Cyrl::Ethi;
# This file auto generated from Data\common\transforms\und-Ethi-t-und-cyrl-m0-gutgarts.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(\`),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`\`),
					result  => q(\`),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\_),
					result  => q(\u135f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:),
					result  => q(፡),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\+),
					result  => q(፠),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\|\:),
					result  => q(፨),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\-),
					result  => q(፦),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\-\:),
					result  => q(፥),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(፤),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\,),
					result  => q(፣),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\:\:),
					result  => q(።),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`9),
					result  => q(፱),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`8),
					result  => q(፰),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`7),
					result  => q(፯),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`6),
					result  => q(፮),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`5),
					result  => q(፭),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`4),
					result  => q(፬),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`3),
					result  => q(፫),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`2),
					result  => q(፪),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`1),
					result  => q(፩),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`90),
					result  => q(፺),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`80),
					result  => q(፹),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`70),
					result  => q(፸),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`60),
					result  => q(፷),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`50),
					result  => q(፶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`40),
					result  => q(፵),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`30),
					result  => q(፴),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`20),
					result  => q(፳),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`10),
					result  => q(፲),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`100),
					result  => q(፻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`1000),
					result  => q(፲፻),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\`10000),
					result  => q(፼),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п),
					result  => q(ፕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пўе),
					result  => q(ᎎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пўа),
					result  => q(ፗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пўи),
					result  => q(ᎍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пўы),
					result  => q(ᎏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пўэ),
					result  => q(ᎌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(по),
					result  => q(ፖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пы),
					result  => q(ፕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пе),
					result  => q(ፔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(па),
					result  => q(ፓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пи),
					result  => q(ፒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пу),
					result  => q(ፑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(пэ),
					result  => q(ፐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ф),
					result  => q(ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фйа),
					result  => q(ፚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фўе),
					result  => q(ᎊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фўа),
					result  => q(ፏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фўи),
					result  => q(ᎉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фўы),
					result  => q(ᎋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фўэ),
					result  => q(ᎈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фо),
					result  => q(ፎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фы),
					result  => q(ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фе),
					result  => q(ፌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фа),
					result  => q(ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фи),
					result  => q(ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фу),
					result  => q(ፉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(фэ),
					result  => q(ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣),
					result  => q(ጽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣ўа),
					result  => q(ጿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣о),
					result  => q(ጾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣ы),
					result  => q(ጽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣е),
					result  => q(ጼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣а),
					result  => q(ጻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣и),
					result  => q(ጺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣у),
					result  => q(ጹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ц̣э),
					result  => q(ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣),
					result  => q(ፅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣о),
					result  => q(ፆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣ы),
					result  => q(ፅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣е),
					result  => q(ፄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣а),
					result  => q(ፃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣и),
					result  => q(ፂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣у),
					result  => q(ፁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(\` ц̣э),
					result  => q(ፀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣),
					result  => q(ጵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣ўа),
					result  => q(ጷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣о),
					result  => q(ጶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣ы),
					result  => q(ጵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣е),
					result  => q(ጴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣а),
					result  => q(ጳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣и),
					result  => q(ጲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣у),
					result  => q(ጱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(п̣э),
					result  => q(ጰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч),
					result  => q(ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(чўа),
					result  => q(ቿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(чо),
					result  => q(ቾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(чы),
					result  => q(ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(че),
					result  => q(ቼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ча),
					result  => q(ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(чи),
					result  => q(ቺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(чу),
					result  => q(ቹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(чэ),
					result  => q(ቸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣),
					result  => q(ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣ўа),
					result  => q(ጯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣о),
					result  => q(ጮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣ы),
					result  => q(ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣е),
					result  => q(ጬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣а),
					result  => q(ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣и),
					result  => q(ጪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣у),
					result  => q(ጩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ч̣э),
					result  => q(ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т),
					result  => q(ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(тўа),
					result  => q(ቷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(то),
					result  => q(ቶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ты),
					result  => q(ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(те),
					result  => q(ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(та),
					result  => q(ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ти),
					result  => q(ቲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ту),
					result  => q(ቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(тэ),
					result  => q(ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣),
					result  => q(ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣ўа),
					result  => q(ጧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣о),
					result  => q(ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣ы),
					result  => q(ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣е),
					result  => q(ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣а),
					result  => q(ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣и),
					result  => q(ጢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣у),
					result  => q(ጡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(т̣э),
					result  => q(ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(г),
					result  => q(ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гўе),
					result  => q(ጔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гўа),
					result  => q(ጓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гўи),
					result  => q(ጒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гўы),
					result  => q(ጕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гўэ),
					result  => q(ጐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(го),
					result  => q(ጎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гы),
					result  => q(ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ге),
					result  => q(ጌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(га),
					result  => q(ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ги),
					result  => q(ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гу),
					result  => q(ጉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(гэ),
					result  => q(ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(дж),
					result  => q(ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(джўа),
					result  => q(ጇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(джо),
					result  => q(ጆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(джы),
					result  => q(ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(дже),
					result  => q(ጄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(джа),
					result  => q(ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(джи),
					result  => q(ጂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(джу),
					result  => q(ጁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(джэ),
					result  => q(ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(дўа),
					result  => q(ዷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(до),
					result  => q(ዶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ды),
					result  => q(ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(де),
					result  => q(ዴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(да),
					result  => q(ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ди),
					result  => q(ዲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ду),
					result  => q(ዱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(дэ),
					result  => q(ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(йы),
					result  => q(ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ё),
					result  => q(ዮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(я),
					result  => q(ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(йи),
					result  => q(ዪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(йиэ),
					result  => q(ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ю),
					result  => q(ዩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(е),
					result  => q(የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ж),
					result  => q(ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(жўа),
					result  => q(ዧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(жо),
					result  => q(ዦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(жы),
					result  => q(ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(же),
					result  => q(ዤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(жа),
					result  => q(ዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(жи),
					result  => q(ዢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(жу),
					result  => q(ዡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(жэ),
					result  => q(ዠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(з),
					result  => q(ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(зўа),
					result  => q(ዟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(зо),
					result  => q(ዞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(зы),
					result  => q(ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(зе),
					result  => q(ዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(за),
					result  => q(ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(зи),
					result  => q(ዚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(зу),
					result  => q(ዙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(зэ),
					result  => q(ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʹ),
					result  => q(ዕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʹ),
					result  => q(ዖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʹ),
					result  => q(ዒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʹ),
					result  => q(ዔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʹ),
					result  => q(ዓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʹ),
					result  => q(ዑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ʹэ),
					result  => q(ዐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ў),
					result  => q(ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ўо),
					result  => q(ዎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ўы),
					result  => q(ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ўе),
					result  => q(ዌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ўа),
					result  => q(ዋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ўи),
					result  => q(ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ўу),
					result  => q(ዉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ўэ),
					result  => q(ወ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к),
					result  => q(ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(кўе),
					result  => q(ኴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(кўа),
					result  => q(ኳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(кўи),
					result  => q(ኲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(кўы),
					result  => q(ኵ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(кўэ),
					result  => q(ኰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ко),
					result  => q(ኮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(кы),
					result  => q(ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ке),
					result  => q(ኬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ка),
					result  => q(ካ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ки),
					result  => q(ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ку),
					result  => q(ኩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(кэ),
					result  => q(ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱),
					result  => q(ኽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱ўе),
					result  => q(ዄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱ўа),
					result  => q(ዃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱ўи),
					result  => q(ዂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱ўы),
					result  => q(ዅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱ўэ),
					result  => q(ዀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱о),
					result  => q(ኾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱ы),
					result  => q(ኽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱е),
					result  => q(ኼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱а),
					result  => q(ኻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱и),
					result  => q(ኺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱у),
					result  => q(ኹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̱э),
					result  => q(ኸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(͵),
					result  => q(ኦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(͵),
					result  => q(እ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(͵),
					result  => q(ኢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(͵),
					result  => q(ኤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(͵),
					result  => q(ኡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(͵э),
					result  => q(አ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(͵),
					result  => q(ኣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(እ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(э),
					result  => q(አ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(),
					result  => q(ኣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(н),
					result  => q(ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нўа),
					result  => q(ኗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(но),
					result  => q(ኖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ны),
					result  => q(ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(не),
					result  => q(ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(на),
					result  => q(ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ни),
					result  => q(ኒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ну),
					result  => q(ኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нэ),
					result  => q(ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нг),
					result  => q(ጝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгўе),
					result  => q(ⶕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгўа),
					result  => q(ጟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгўи),
					result  => q(ⶔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгўы),
					result  => q(ⶖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгўэ),
					result  => q(ⶓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нго),
					result  => q(ጞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгы),
					result  => q(ጝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нге),
					result  => q(ጜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нга),
					result  => q(ጛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нги),
					result  => q(ጚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгу),
					result  => q(ጙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нгэ),
					result  => q(ጘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нь),
					result  => q(ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ньўа),
					result  => q(ኟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ньо),
					result  => q(ኞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ньы),
					result  => q(ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(нье),
					result  => q(ኜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ньа),
					result  => q(ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ньи),
					result  => q(ኚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ньу),
					result  => q(ኙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ньэ),
					result  => q(ኘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х),
					result  => q(ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(хо),
					result  => q(ሆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(хы),
					result  => q(ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(хе),
					result  => q(ሄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ха),
					result  => q(ሃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(хи),
					result  => q(ሂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ху),
					result  => q(ሁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(хэ),
					result  => q(ሀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮),
					result  => q(ኅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮ўе),
					result  => q(ኌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮ўа),
					result  => q(ኋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮ўи),
					result  => q(ኊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮ўы),
					result  => q(ኍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮ўэ),
					result  => q(ኈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮о),
					result  => q(ኆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮ы),
					result  => q(ኅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮е),
					result  => q(ኄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮а),
					result  => q(ኃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮и),
					result  => q(ኂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮у),
					result  => q(ኁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̮э),
					result  => q(ኀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(в),
					result  => q(ቭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(вўа),
					result  => q(ቯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(во),
					result  => q(ቮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(вы),
					result  => q(ቭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ве),
					result  => q(ቬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ва),
					result  => q(ቫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ви),
					result  => q(ቪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ву),
					result  => q(ቩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(вэ),
					result  => q(ቨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(б),
					result  => q(ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бўе),
					result  => q(ᎆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бўа),
					result  => q(ቧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бўи),
					result  => q(ᎅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бўы),
					result  => q(ᎇ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бўэ),
					result  => q(ᎄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бо),
					result  => q(ቦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бы),
					result  => q(ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бе),
					result  => q(ቤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ба),
					result  => q(ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(би),
					result  => q(ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бу),
					result  => q(ቡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(бэ),
					result  => q(በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣ўе),
					result  => q(ቌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣ўа),
					result  => q(ቋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣ўы),
					result  => q(ቊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣ўи),
					result  => q(ቍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣ўэ),
					result  => q(ቈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣о),
					result  => q(ቆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣ы),
					result  => q(ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣е),
					result  => q(ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣а),
					result  => q(ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣и),
					result  => q(ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣у),
					result  => q(ቁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣э),
					result  => q(ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄),
					result  => q(ቕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄ўе),
					result  => q(ቜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄ўа),
					result  => q(ቛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄ўы),
					result  => q(ቝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄ўи),
					result  => q(ቚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄ўэ),
					result  => q(ቘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄о),
					result  => q(ቖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄ы),
					result  => q(ቕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄е),
					result  => q(ቔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄а),
					result  => q(ቓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄и),
					result  => q(ቒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄у),
					result  => q(ቑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(к̣̄э),
					result  => q(ቐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ш),
					result  => q(ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(шўа),
					result  => q(ሿ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(шо),
					result  => q(ሾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(шы),
					result  => q(ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ше),
					result  => q(ሼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ша),
					result  => q(ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ши),
					result  => q(ሺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(шу),
					result  => q(ሹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(шэ),
					result  => q(ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(с),
					result  => q(ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(сўа),
					result  => q(ሷ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(со),
					result  => q(ሶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(сы),
					result  => q(ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(се),
					result  => q(ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(са),
					result  => q(ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(си),
					result  => q(ሲ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(су),
					result  => q(ሱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(сэ),
					result  => q(ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(р),
					result  => q(ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(рйа),
					result  => q(ፘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(рўа),
					result  => q(ሯ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ро),
					result  => q(ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ры),
					result  => q(ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ре),
					result  => q(ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ра),
					result  => q(ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ри),
					result  => q(ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ру),
					result  => q(ሩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(рэ),
					result  => q(ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ć),
					result  => q(ሥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćўа),
					result  => q(ሧ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćо),
					result  => q(ሦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćы),
					result  => q(ሥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćе),
					result  => q(ሤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćа),
					result  => q(ሣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćи),
					result  => q(ሢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćу),
					result  => q(ሡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ćэ),
					result  => q(ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(м),
					result  => q(ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мйа),
					result  => q(ፙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мўе),
					result  => q(ᎂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мўа),
					result  => q(ሟ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мўи),
					result  => q(ᎁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мўы),
					result  => q(ᎃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мўэ),
					result  => q(ᎀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мо),
					result  => q(ሞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мы),
					result  => q(ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ме),
					result  => q(ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ма),
					result  => q(ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ми),
					result  => q(ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(му),
					result  => q(ሙ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(мэ),
					result  => q(መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(лўа),
					result  => q(ሏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ло),
					result  => q(ሎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(лы),
					result  => q(ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ле),
					result  => q(ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ла),
					result  => q(ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ли),
					result  => q(ሊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(лу),
					result  => q(ሉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(лэ),
					result  => q(ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣),
					result  => q(ሕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣ўа),
					result  => q(ሗ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣о),
					result  => q(ሖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣ы),
					result  => q(ሕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣е),
					result  => q(ሔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣а),
					result  => q(ሓ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣и),
					result  => q(ሒ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣у),
					result  => q(ሑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(х̣э),
					result  => q(ሐ),
					revisit => 0,
				},
			],
		},
		{
			type => 'transform',
			data => [
				{
					from => q(Any),
					to => q(NFC),
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
