package Locale::CLDR::Transformations::Ungegn::Laoo::Latn;
# This file auto generated from Data\common\transforms\Lao-Latin.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ເັຽະ),
					result  => q(ia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເຶອະ),
					result  => q(ua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເາະ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເິະ),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເັຽ),
					result  => q(ia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເຶອ),
					result  => q(ua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເືອ),
					result  => q(ua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ົວະ),
					result  => q(oua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເົາ),
					result  => q(ao),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຣ໌),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເະ),
					result  => q(é),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເັ),
					result  => q(é),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ແະ),
					result  => q(è),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ແັ),
					result  => q(è),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໂະ),
					result  => q(ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ັອ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເິ),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເີ),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເື),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ັຽ),
					result  => q(ia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ັວ),
					result  => q(oua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ົວ),
					result  => q(oua),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ກ),
					result  => q(k),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຂ),
					result  => q(kh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຄ),
					result  => q(kh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ງ),
					result  => q(ng),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຈ),
					result  => q(ch),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ສ),
					result  => q(s),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຊ),
					result  => q(x),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຍ),
					result  => q(gn),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ດ),
					result  => q(d),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຕ),
					result  => q(t),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຖ),
					result  => q(th),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ທ),
					result  => q(th),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ນ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ບ),
					result  => q(b),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ປ),
					result  => q(p),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຜ),
					result  => q(ph),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຝ),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ພ),
					result  => q(ph),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຟ),
					result  => q(f),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ມ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຢ),
					result  => q(y),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຣ),
					result  => q(r),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ລ),
					result  => q(l),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ວ),
					result  => q(v),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຫ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q([\p{L}\p{M}]),
					after   => q(),
					replace => q(ອ),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ອ),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຮ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ະ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ັ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(າ),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ິ),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ີ),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຶ),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ື),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຸ),
					result  => q(ou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ູ),
					result  => q(ou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ເ),
					result  => q(é),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ແ),
					result  => q(è),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ົ),
					result  => q(ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໂ),
					result  => q(ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໍ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຽ),
					result  => q(ia),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໄ),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໃ),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຳ),
					result  => q(am),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(່),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(້),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(໊),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(໋),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຯ),
					result  => q(…),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ฯ),
					result  => q(…),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໆ),
					result  => q(⓶),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ຼ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(໌),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໜ),
					result  => q(n),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ໝ),
					result  => q(n),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
