package Locale::CLDR::Transformations::Ungegn::Khmr::Latn;
# This file auto generated from Data\common\transforms\Khmer-Latin.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^um:\G.)/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(â្ក),
					result  => q(k|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ខ),
					result  => q(kh|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្គ),
					result  => q(k|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ឃ),
					result  => q(kh|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ង),
					result  => q(ng|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ច),
					result  => q(ch|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ឆ),
					result  => q(chh|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ជ),
					result  => q(ch|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ឈ),
					result  => q(chh|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ញ),
					result  => q(nh|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ដ),
					result  => q(d|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ឋ),
					result  => q(th|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ឌ),
					result  => q(d|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ឍ),
					result  => q(th|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ណ),
					result  => q(n|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ត),
					result  => q(t|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ថ),
					result  => q(th|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ទ),
					result  => q(t|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ធ),
					result  => q(th|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ន),
					result  => q(n|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ប),
					result  => q(b|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ផ),
					result  => q(ph|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ព),
					result  => q(p|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ភ),
					result  => q(ph|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ម),
					result  => q(m|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្យ),
					result  => q(y|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្រ),
					result  => q(r|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្ល),
					result  => q(l|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ô្វ),
					result  => q(v|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ស),
					result  => q(s|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្ហ),
					result  => q(h|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(â្អ),
					result  => q(’|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âុំ),
					result  => q(om),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âាំ),
					result  => q(ăm),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âិះ),
					result  => q(ĕh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âុះ),
					result  => q(ŏh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âេះ),
					result  => q(éh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âោះ),
					result  => q(aôh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôុំ),
					result  => q(ŭm),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôាំ),
					result  => q(ŏâm),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôិះ),
					result  => q(ĭh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôុះ),
					result  => q(ŭh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôេះ),
					result  => q(éh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôោះ),
					result  => q(ŏăh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ក),
					result  => q(kâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ខ),
					result  => q(khâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្គ),
					result  => q(kô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ឃ),
					result  => q(khô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ង),
					result  => q(ngô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ច),
					result  => q(châ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ឆ),
					result  => q(chhâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ជ),
					result  => q(chô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ឈ),
					result  => q(chhô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ញ),
					result  => q(nhô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ដ),
					result  => q(dâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ឋ),
					result  => q(thâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ឌ),
					result  => q(dô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ឍ),
					result  => q(thô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ណ),
					result  => q(nâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ត),
					result  => q(tâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ថ),
					result  => q(thâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ទ),
					result  => q(tô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ធ),
					result  => q(thô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ន),
					result  => q(nô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ប),
					result  => q(bâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ផ),
					result  => q(phâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ព),
					result  => q(pô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ភ),
					result  => q(phô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ម),
					result  => q(mô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្យ),
					result  => q(yô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្រ),
					result  => q(rô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ល),
					result  => q(lô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្វ),
					result  => q(vô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ស),
					result  => q(sâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្ហ),
					result  => q(hâ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្អ),
					result  => q(’â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âា),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âិ),
					result  => q(ĕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âី),
					result  => q(ei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âឹ),
					result  => q(œ̆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âឺ),
					result  => q(œ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âុ),
					result  => q(ŏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âូ),
					result  => q(o),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âួ),
					result  => q(uŏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âើ),
					result  => q(aeu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âឿ),
					result  => q(œă),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âៀ),
					result  => q(iĕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âេ),
					result  => q(é),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âែ),
					result  => q(ê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âៃ),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âោ),
					result  => q(aô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âៅ),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôា),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôិ),
					result  => q(ĭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôី),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôឹ),
					result  => q(œ̆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôឺ),
					result  => q(œ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôុ),
					result  => q(ŭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôូ),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôួ),
					result  => q(uŏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôើ),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôឿ),
					result  => q(œă),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôៀ),
					result  => q(iĕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôេ),
					result  => q(é),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôែ),
					result  => q(ê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôៃ),
					result  => q(ey),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôោ),
					result  => q(oŭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôៅ),
					result  => q(ŏu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âំ),
					result  => q(âm),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(âះ),
					result  => q(ăh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôំ),
					result  => q(um),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ôះ),
					result  => q(eăh),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ក),
					result  => q(k|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ខ),
					result  => q(kh|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(គ),
					result  => q(k|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឃ),
					result  => q(kh|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ង),
					result  => q(ng|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ច),
					result  => q(ch|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឆ),
					result  => q(chh|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ជ),
					result  => q(ch|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឈ),
					result  => q(chh|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ញ),
					result  => q(nh|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ដ),
					result  => q(d|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឋ),
					result  => q(th|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឌ),
					result  => q(d|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឍ),
					result  => q(th|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ណ),
					result  => q(n|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ត),
					result  => q(t|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ថ),
					result  => q(th|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ទ),
					result  => q(t|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ធ),
					result  => q(th|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ន),
					result  => q(n|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ប),
					result  => q(b|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ផ),
					result  => q(ph|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ព),
					result  => q(p|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ភ),
					result  => q(ph|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ម),
					result  => q(m|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(យ),
					result  => q(y|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(រ),
					result  => q(r|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ល),
					result  => q(l|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(វ),
					result  => q(v|ô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ស),
					result  => q(s|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ហ),
					result  => q(h|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឡ),
					result  => q(l|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(អ),
					result  => q(’|â),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(០),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(១),
					result  => q(1),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(២),
					result  => q(2),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៣),
					result  => q(3),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៤),
					result  => q(4),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៥),
					result  => q(5),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៦),
					result  => q(6),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៧),
					result  => q(7),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៨),
					result  => q(8),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៩),
					result  => q(9),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ា),
					result  => q(a),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ិ),
					result  => q(ĭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ី),
					result  => q(i),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឹ),
					result  => q(œ̆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឺ),
					result  => q(œ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ុ),
					result  => q(ŭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ូ),
					result  => q(u),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ួ),
					result  => q(uŏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ើ),
					result  => q(eu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឿ),
					result  => q(œă),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ៀ),
					result  => q(iĕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(េ),
					result  => q(é),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ែ),
					result  => q(ê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ៃ),
					result  => q(ey),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ោ),
					result  => q(oŭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ៅ),
					result  => q(ŏu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ំ),
					result  => q(m),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ះ),
					result  => q(h),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឥ),
					result  => q(ĕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឦ),
					result  => q(ei),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឧ),
					result  => q(ŏ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឨ),
					result  => q(ou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឩ),
					result  => q(ou),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឪ),
					result  => q(âu),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឫ),
					result  => q(rœ̆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឬ),
					result  => q(rœ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឭ),
					result  => q(lœ̆),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឮ),
					result  => q(lœ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឯ),
					result  => q(ê),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឰ),
					result  => q(ai),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឱ),
					result  => q(aô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឳ),
					result  => q(au),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ឲ),
					result  => q(aô),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៖),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ៗ),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(។),
					result  => q(\'),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ៈ),
					result  => q(u’),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៉),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៊),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(់),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៌),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៍),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(៏),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(័),
					result  => q(),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(្),
					result  => q(),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
