package Locale::CLDR::Transformations::Geminate::Am_ethi::Am_ethi;
# This file auto generated from Data\common\transforms\am-Ethi-t-am-ethi-m0-geminate.xml
#	on Wed 15 Jan 11:22:39 am GMT

use strict;
use warnings;
use version;

our $VERSION = version->declare('v0.46.0');

use v5.12.0;
use mro 'c3';
use utf8;
use feature 'unicode_strings';
use Types::Standard qw( Str Int HashRef ArrayRef CodeRef RegexpRef );
use Moo;

BEGIN {
	die "Transliteration requires Perl 5.18 or above"
		unless $^V ge v5.18.0;
}

no warnings 'experimental::regex_sets';
has 'transforms' => (
	is => 'ro',
	isa => ArrayRef,
	init_arg => undef,
	default => sub { [
		qr/(?^umi:\G\p{Ethiopic})/,
		{
			type => 'transform',
			data => [
			],
		},
		{
			type => 'conversion',
			data => [
				{
					before  => q(),
					after   => q(),
					replace => q(ፖስተኛ),
					result  => q(ፖስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፖሊቲከኛ),
					result  => q(ፖሊቲከኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፕሮፓጋንዳ),
					result  => q(ፕሮፓጋንዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፓፓዬ),
					result  => q(ፓፓ፟ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፓኮ),
					result  => q(ፓኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎከት),
					result  => q(ፎከት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎከተ),
					result  => q(ፎከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎከረ),
					result  => q(ፎከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎነነ),
					result  => q(ፎነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎቀቅ),
					result  => q(ፎቀ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎረሸ),
					result  => q(ፎረ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎልፏላ),
					result  => q(ፎልፏላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፎሌ),
					result  => q(ፎሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍጹምነት),
					result  => q(ፍጹ፟ምነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍጥጥ),
					result  => q(ፍጥጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍግፋጊ),
					result  => q(ፍግፋ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍግም),
					result  => q(ፍግ፟ም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍጅት),
					result  => q(ፍጅ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍዳውን),
					result  => q(ፍዳ፟ውን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍዳ),
					result  => q(ፍዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍየል),
					result  => q(ፍየ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍንድቅ),
					result  => q(ፍንድ፟ቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍንክች),
					result  => q(ፍንክች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍንካች),
					result  => q(ፍንካ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍች),
					result  => q(ፍች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍትግ),
					result  => q(ፍት፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍትወተኛ),
					result  => q(ፍትወተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍተጋ),
					result  => q(ፍተ፟ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍተሻ),
					result  => q(ፍተ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍቅፋቂ),
					result  => q(ፍቅፋ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍቅረኛ),
					result  => q(ፍቅረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍስክ),
					result  => q(ፍስ፟ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍስስ),
					result  => q(ፍስ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍሳሽ),
					result  => q(ፍሳ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍርፋሪ),
					result  => q(ፍርፋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍርጥ),
					result  => q(ፍር፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍርስ),
					result  => q(ፍር፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍርምባ),
					result  => q(ፍርምባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍሬያማ),
					result  => q(ፍሬያማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍራቻ),
					result  => q(ፍራቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍራሽ),
					result  => q(ፍራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍሥሐ),
					result  => q(ፍሥ፟ሐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍልቃቂ),
					result  => q(ፍል፟ቃ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍልስፍና),
					result  => q(ፍልስፍና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍላጎት),
					result  => q(ፍላ፟ጎት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፍለጋ),
					result  => q(ፍለ፟ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፌዘኛ),
					result  => q(ፌዘ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፋፋ),
					result  => q(ፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፋኖ),
					result  => q(ፋኖ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፋንድያ),
					result  => q(ፋንድ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፋነነ),
					result  => q(ፋነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፊጥኝ),
					result  => q(ፊጥ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፊኛ),
					result  => q(ፊኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፊን),
					result  => q(ፊን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፊትና),
					result  => q(ፊትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፊተኛው),
					result  => q(ፊተኛ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፊር),
					result  => q(ፊር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፉጉሎ),
					result  => q(ፉጉሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፉክክር),
					result  => q(ፉክክ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፉከራ),
					result  => q(ፉከ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፉት),
					result  => q(ፉት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈጻሚ),
					result  => q(ፈጻ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈጸመ),
					result  => q(ፈጸ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈጠፈጠ),
					result  => q(ፈጠፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈጠመ),
					result  => q(ፈጠ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈግጠው),
					result  => q(ፈግ፟ጠው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈገፈገ),
					result  => q(ፈገፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈገገ),
					result  => q(ፈገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈገመ),
					result  => q(ፈገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈጅ),
					result  => q(ፈጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈጀ),
					result  => q(ፈጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈየደ),
					result  => q(ፈየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈየለ),
					result  => q(ፈየ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈዛዛ),
					result  => q(ፈዛዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈዘዘ),
					result  => q(ፈዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈዋሽ),
					result  => q(ፈዋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈወሰ),
					result  => q(ፈወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈካ),
					result  => q(ፈካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈንጣራ),
					result  => q(ፈንጣራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈንጠዝያ),
					result  => q(ፈንጠዝያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈንጋላ),
					result  => q(ፈንጋላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈንዳዳ),
					result  => q(ፈንዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈነገለ),
					result  => q(ፈነገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈነዳ),
					result  => q(ፈነዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈነደቀ),
					result  => q(ፈነደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈነከተ),
					result  => q(ፈነከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈነቀለ),
					result  => q(ፈነቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈትለክ),
					result  => q(ፈትለክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈት),
					result  => q(ፈት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈታኝ),
					result  => q(ፈታ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈታታ),
					result  => q(ፈታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈታሽ),
					result  => q(ፈታ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈታ),
					result  => q(ፈታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈተፈተ),
					result  => q(ፈተፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈተገ),
					result  => q(ፈተ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈተነ),
					result  => q(ፈተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈተሸ),
					result  => q(ፈተ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈተለ),
					result  => q(ፈተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈቃደኛነት),
					result  => q(ፈቃደኛ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈቃደኛ),
					result  => q(ፈቃደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈቀፈቀ),
					result  => q(ፈቀፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈቀደው),
					result  => q(ፈቀ፟ደው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈቀደ),
					result  => q(ፈቀ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈቀቅ),
					result  => q(ፈቀቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈሳ),
					result  => q(ፈሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈሰፈሰ),
					result  => q(ፈሰፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈሰከ),
					result  => q(ፈሰ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈሰሰ),
					result  => q(ፈሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈርጣማ),
					result  => q(ፈርጣማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈራረሰ),
					result  => q(ፈራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈራሚ),
					result  => q(ፈራ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈራ),
					result  => q(ፈራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈሪነት),
					result  => q(ፈሪነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረፈረ),
					result  => q(ፈረፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረጠ),
					result  => q(ፈረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረደበት),
					result  => q(ፈረ፟ደበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረደለት),
					result  => q(ፈረ፟ደለት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረደ),
					result  => q(ፈረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረክራካ),
					result  => q(ፈረክራካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረንሳይኛ),
					result  => q(ፈረንሳይኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረሱላ),
					result  => q(ፈረሱላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረሰኛ),
					result  => q(ፈረሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረሰ),
					result  => q(ፈረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈረመ),
					result  => q(ፈረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈልሳሳ),
					result  => q(ፈልሳ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈላጊ),
					result  => q(ፈላ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈላሻ),
					result  => q(ፈላ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈላ),
					result  => q(ፈላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈሊጠኛ),
					result  => q(ፈሊጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለፈለ),
					result  => q(ፈለፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለጠ),
					result  => q(ፈለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለገ),
					result  => q(ፈለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለቀቀ),
					result  => q(ፈለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለቀ),
					result  => q(ፈለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለሰፈ),
					result  => q(ፈለሰ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለሰመ),
					result  => q(ፈለሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፈለሰ),
					result  => q(ፈለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ፀሐያማ),
					result  => q(ፀሐያማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጾመኛ),
					result  => q(ጾመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጽጌረዳ),
					result  => q(ጽጌ፟ረዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጽዋ),
					result  => q(ጽዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጽኑነት),
					result  => q(ጽኑነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጽላት),
					result  => q(ጽላ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጽላተ),
					result  => q(ጽላ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸጸተኛ),
					result  => q(ጸጸተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸጸተ),
					result  => q(ጸጸ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸጥተኛ),
					result  => q(ጸጥ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸጥ),
					result  => q(ጸጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸጋ),
					result  => q(ጸጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸዳ),
					result  => q(ጸዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸደቀ),
					result  => q(ጸደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸያፍ),
					result  => q(ጸያ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸና),
					result  => q(ጸና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸነነ),
					result  => q(ጸነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸበረቀ),
					result  => q(ጸበረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸሎተኛ),
					result  => q(ጸሎተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጸለየ),
					result  => q(ጸለ፟የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጳጳስ),
					result  => q(ጳጳ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጳጳሳት),
					result  => q(ጳጳ፟ሳት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጮቤ),
					result  => q(ጮቤ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጮራ),
					result  => q(ጮራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጮረረ),
					result  => q(ጮረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጮሌ),
					result  => q(ጮሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭፍን),
					result  => q(ጭፍ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭፈራ),
					result  => q(ጭፈ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭውውት),
					result  => q(ጭው፟ውት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭው),
					result  => q(ጭው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭኮ),
					result  => q(ጭኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭካኔ),
					result  => q(ጭካ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭከና),
					result  => q(ጭከ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭንቅላት),
					result  => q(ጭንቅ፟ላት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭንቅላታም),
					result  => q(ጭንቅላ፟ታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቦኛ),
					result  => q(ጭቦ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቦ),
					result  => q(ጭቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭብጦ),
					result  => q(ጭብ፟ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭብጥ),
					result  => q(ጭብ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭባጭ),
					result  => q(ጭባ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቆና),
					result  => q(ጭቆ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቅና),
					result  => q(ጭቅና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቅቅት),
					result  => q(ጭቅቅ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቅቅታም),
					result  => q(ጭቅቅ፟ታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቃማ),
					result  => q(ጭቃማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭቁን),
					result  => q(ጭቁ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭርታ),
					result  => q(ጭር፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭር),
					result  => q(ጭር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭራሽ),
					result  => q(ጭራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭራሹ),
					result  => q(ጭራ፟ሹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭምት),
					result  => q(ጭም፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭምር),
					result  => q(ጭም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭማቂ),
					result  => q(ጭማ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭማሪ),
					result  => q(ጭማ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭልፊት),
					result  => q(ጭልፊት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭልጥ),
					result  => q(ጭል፟ጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭላጭ),
					result  => q(ጭላ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጭለማ),
					result  => q(ጭለ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫፍና),
					result  => q(ጫፍና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫጩት),
					result  => q(ጫጩት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫካማ),
					result  => q(ጫካማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫካ),
					result  => q(ጫካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫን),
					result  => q(ጫን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫና),
					result  => q(ጫና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫር),
					result  => q(ጫር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጫማ),
					result  => q(ጫማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጩርር),
					result  => q(ጩርር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፍጋጋ),
					result  => q(ጨፍጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፍራራ),
					result  => q(ጨፍራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፌ),
					result  => q(ጨፌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፋና),
					result  => q(ጨፋ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፋሪ),
					result  => q(ጨፋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፈገገ),
					result  => q(ጨፈገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፈነ),
					result  => q(ጨፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፈረ),
					result  => q(ጨፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨፈለቀ),
					result  => q(ጨፈለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨጓራ),
					result  => q(ጨጓ፟ራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨገገ),
					result  => q(ጨገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨውናና),
					result  => q(ጨውናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨዋነት),
					result  => q(ጨዋነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨካኝ),
					result  => q(ጨካ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨከነ),
					result  => q(ጨከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨንባሳ),
					result  => q(ጨንባሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨንቋራ),
					result  => q(ጨንቋራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨነገፈ),
					result  => q(ጨነገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨነቀ),
					result  => q(ጨነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨቦደ),
					result  => q(ጨቦ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨበጠ),
					result  => q(ጨበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨቋኝ),
					result  => q(ጨቋ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨቆነ),
					result  => q(ጨቆ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨቅጫቃ),
					result  => q(ጨቅጫቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨቅላነት),
					result  => q(ጨቅላነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨቀየ),
					result  => q(ጨቀየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨርጫሳ),
					result  => q(ጨርጫሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨርሶ),
					result  => q(ጨር፟ሶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨርማዳ),
					result  => q(ጨርማዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨርማታ),
					result  => q(ጨርማታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨርማማ),
					result  => q(ጨርማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨረፈ),
					result  => q(ጨረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨረገደ),
					result  => q(ጨረገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨረታ),
					result  => q(ጨረ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨረሰ),
					result  => q(ጨረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨምዳዳ),
					result  => q(ጨምዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨምታራ),
					result  => q(ጨምታራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨምባሳ),
					result  => q(ጨምባሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨምላቃ),
					result  => q(ጨምላቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨመደደ),
					result  => q(ጨመደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨመተ),
					result  => q(ጨመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨመቀ),
					result  => q(ጨመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨመረ),
					result  => q(ጨመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨመለቅ),
					result  => q(ጨመለ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨሌ),
					result  => q(ጨሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨላጭ),
					result  => q(ጨላ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨለፈ),
					result  => q(ጨለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨለጠ),
					result  => q(ጨለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨለማ),
					result  => q(ጨለ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጨለመ),
					result  => q(ጨለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦቢያ),
					result  => q(ጦቢ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦሽ),
					result  => q(ጦሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦስኝ),
					result  => q(ጦስኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦሰኛ),
					result  => q(ጦሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦርነት),
					result  => q(ጦርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦረኛ),
					result  => q(ጦረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦመኛ),
					result  => q(ጦመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦልጧላ),
					result  => q(ጦልጧላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጦልጣሏ),
					result  => q(ጦልጣሏ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥፋተኛ),
					result  => q(ጥፋተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥፊ),
					result  => q(ጥፊ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥግን),
					result  => q(ጥግ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥግ),
					result  => q(ጥግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥጋበኛ),
					result  => q(ጥጋበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥገኛነት),
					result  => q(ጥገ፟ኛ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥገኛ),
					result  => q(ጥገ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥገና),
					result  => q(ጥገ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥገት),
					result  => q(ጥገ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥጃ),
					result  => q(ጥጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥይፍተኛ),
					result  => q(ጥይ፟ፍተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥይት),
					result  => q(ጥይ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥያቄ),
					result  => q(ጥያ፟ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥዩፍ),
					result  => q(ጥዩ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥየቃ),
					result  => q(ጥየ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥንዚዛ),
					result  => q(ጥንዚዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥንካሬ),
					result  => q(ጥንካ፟ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥንቃቄ),
					result  => q(ጥንቃ፟ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥቦት),
					result  => q(ጥቦ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥብኛ),
					result  => q(ጥብ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥብቆ),
					result  => q(ጥብ፟ቆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥብቅና),
					result  => q(ጥብቅና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥብቅ),
					result  => q(ጥብ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥቢ),
					result  => q(ጥቢ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥበት),
					result  => q(ጥበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥበበኛ),
					result  => q(ጥበበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥበቃ),
					result  => q(ጥበ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥቅል),
					result  => q(ጥቅ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥቃቅን),
					result  => q(ጥቃቅ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥቁም),
					result  => q(ጥቁ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥስቅ),
					result  => q(ጥስ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥርኝ),
					result  => q(ጥርኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥርቅምአድርጎ),
					result  => q(ጥርቅም፟አድርጎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥርቅም),
					result  => q(ጥርቅ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥርቃሞ),
					result  => q(ጥርቃ፟ሞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥርቃሚ),
					result  => q(ጥርቃ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥር),
					result  => q(ጥር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥራጊ),
					result  => q(ጥራ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥራቢ),
					result  => q(ጥራ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥሪ),
					result  => q(ጥሪ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥሩምበኛ),
					result  => q(ጥሩምበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥሞና),
					result  => q(ጥሞ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥምጥም),
					result  => q(ጥምጥም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥምዝ),
					result  => q(ጥምዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥምር),
					result  => q(ጥም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥምልምል),
					result  => q(ጥምልምል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥማድ),
					result  => q(ጥማ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥልቆ),
					result  => q(ጥል፟ቆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥልቅ),
					result  => q(ጥል፟ቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥላቻ),
					result  => q(ጥላቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥላማ),
					result  => q(ጥላማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጥለኛ),
					result  => q(ጥለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጤናዳም),
					result  => q(ጤናዳ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጤናማ),
					result  => q(ጤናማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጤነኛ),
					result  => q(ጤነኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጣፊያ),
					result  => q(ጣፊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጣፈጠ),
					result  => q(ጣፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጣጠኛ),
					result  => q(ጣጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጣሰሰ),
					result  => q(ጣሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጢን),
					result  => q(ጢን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጢቅታ),
					result  => q(ጢቅ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጢቅ),
					result  => q(ጢቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጢሰኛ),
					result  => q(ጢሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጢም),
					result  => q(ጢም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡጥ),
					result  => q(ጡጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡንቻማ),
					result  => q(ጡንቻማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡንቸኛ),
					result  => q(ጡንቸኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡብ),
					result  => q(ጡብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡርነት),
					result  => q(ጡርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡረኛ),
					result  => q(ጡረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡል),
					result  => q(ጡል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጡሌ),
					result  => q(ጡሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠፍጣፋ),
					result  => q(ጠፍጣፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠፍ),
					result  => q(ጠፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠፋ),
					result  => q(ጠፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠፈፈ),
					result  => q(ጠፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠፈጠፈው),
					result  => q(ጠፈጠ፟ፈው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠፈረተኛ),
					result  => q(ጠፈረተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠፈረ),
					result  => q(ጠፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠጣ),
					result  => q(ጠጣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠጠተኝ),
					result  => q(ጠጠ፟ተኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠጠተ),
					result  => q(ጠጠ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠጋኝ),
					result  => q(ጠጋ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠጋቢስ),
					result  => q(ጠጋ፟ቢስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠጋ),
					result  => q(ጠጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠገገ),
					result  => q(ጠገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠገነ),
					result  => q(ጠገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠገበ),
					result  => q(ጠገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠጅ),
					result  => q(ጠጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠዳ),
					result  => q(ጠዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠደቀ),
					result  => q(ጠደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠይም),
					result  => q(ጠይ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠያፍ),
					result  => q(ጠያ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠያቂ),
					result  => q(ጠያ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠያር),
					result  => q(ጠያ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠየቀ),
					result  => q(ጠየ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠየመ),
					result  => q(ጠየ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠውላጋ),
					result  => q(ጠውላጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠወለገ),
					result  => q(ጠወለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠንካራ),
					result  => q(ጠንካ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠንባዛ),
					result  => q(ጠንባዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠንባሳ),
					result  => q(ጠንባሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠንባራ),
					result  => q(ጠንባራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠንቃቃ),
					result  => q(ጠንቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠንቀኛ),
					result  => q(ጠንቀኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠኔያም),
					result  => q(ጠኔ፟ያም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠኔ),
					result  => q(ጠኔ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠና),
					result  => q(ጠና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነፈፈ),
					result  => q(ጠነፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነዛ),
					result  => q(ጠነዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነነኝ),
					result  => q(ጠነ፟ነኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነነ),
					result  => q(ጠነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነባ),
					result  => q(ጠነባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነበዘ),
					result  => q(ጠነበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነቆለ),
					result  => q(ጠነቆ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነቀቀ),
					result  => q(ጠነቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠነሰሰ),
					result  => q(ጠነሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቦት),
					result  => q(ጠቦ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠብታ),
					result  => q(ጠብ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠብ),
					result  => q(ጠብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠባብ),
					result  => q(ጠባ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠባቂ),
					result  => q(ጠባ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠባ),
					result  => q(ጠባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠበደለ),
					result  => q(ጠበደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠበኛ),
					result  => q(ጠበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠበበ),
					result  => q(ጠበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠበቀ),
					result  => q(ጠበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠበሰቀ),
					result  => q(ጠበሰ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠበሰ),
					result  => q(ጠበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠበልተኛ),
					result  => q(ጠበልተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቆረ),
					result  => q(ጠቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቅላላውን),
					result  => q(ጠቅላላ፟ውን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቅላላ),
					result  => q(ጠቅላ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቀስ),
					result  => q(ጠቀ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቀሰ),
					result  => q(ጠቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቀመ),
					result  => q(ጠቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠቀለለ),
					result  => q(ጠቀለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠስቆ),
					result  => q(ጠስ፟ቆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠሰቀ),
					result  => q(ጠሰ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠርዛዛ),
					result  => q(ጠርዛዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠርባባ),
					result  => q(ጠርባባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠራ),
					result  => q(ጠራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረጴዛ),
					result  => q(ጠረጴ፟ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረገ),
					result  => q(ጠረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረዘ),
					result  => q(ጠረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረነቀ),
					result  => q(ጠረነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረበ),
					result  => q(ጠረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረቀመ),
					result  => q(ጠረቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረሰ),
					result  => q(ጠረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረረ),
					result  => q(ጠረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠረመሰ),
					result  => q(ጠረመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠምጣማ),
					result  => q(ጠምጣማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠምዛዛ),
					result  => q(ጠምዛዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠምባራ),
					result  => q(ጠምባራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠመደ),
					result  => q(ጠመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠመዝማዛ),
					result  => q(ጠመዝማዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠመዘዘ),
					result  => q(ጠመዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠመቀ),
					result  => q(ጠመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠመሰሰ),
					result  => q(ጠመሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠመረረ),
					result  => q(ጠመረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠመመ),
					result  => q(ጠመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠል),
					result  => q(ጠል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠላ),
					result  => q(ጠላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠለፈ),
					result  => q(ጠለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠለዘ),
					result  => q(ጠለ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠለቀ),
					result  => q(ጠለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጠለለ),
					result  => q(ጠለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕፋያ),
					result  => q(ጕፋያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕጕ),
					result  => q(ጕጕ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕዞኛ),
					result  => q(ጕዞኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕነጣ),
					result  => q(ጕነ፟ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕትቻ),
					result  => q(ጕትቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕትት),
					result  => q(ጕት፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕተታ),
					result  => q(ጕተ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕብኝት),
					result  => q(ጕብኝ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕስቈላ),
					result  => q(ጕስቈላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕሰማ),
					result  => q(ጕሰ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕልቻ),
					result  => q(ጕልቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕልት),
					result  => q(ጕል፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጕላይ),
					result  => q(ጕላ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓጓላ),
					result  => q(ጓጓ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓጓ),
					result  => q(ጓጓ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓጐጠ),
					result  => q(ጓጐ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓጐረ),
					result  => q(ጓጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓጐለ),
					result  => q(ጓጐ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓድ),
					result  => q(ጓድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓደኝነት),
					result  => q(ጓደ፟ኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓደኛሞች),
					result  => q(ጓደኛ፟ሞች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓደኛ),
					result  => q(ጓደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓያ),
					result  => q(ጓያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጓሮኛ),
					result  => q(ጓሮኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐፈየ),
					result  => q(ጐፈየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐጃም),
					result  => q(ጐጃ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐጃሜ),
					result  => q(ጐጃ፟ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐድጓዳ),
					result  => q(ጐድጓዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐደጐደ),
					result  => q(ጐደጐ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐደሪ),
					result  => q(ጐደሪ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐንዛላ),
					result  => q(ጐንዛላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐንበስ),
					result  => q(ጐንበስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐነፈ),
					result  => q(ጐነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐነጠ),
					result  => q(ጐነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐነጐነ),
					result  => q(ጐነጐ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐነቈለ),
					result  => q(ጐነቈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐተጐተ),
					result  => q(ጐተጐ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐተተ),
					result  => q(ጐተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐባን),
					result  => q(ጐባ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐበጠ),
					result  => q(ጐበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐበኘ),
					result  => q(ጐበኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐስቋላ),
					result  => q(ጐስቋላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐሰጐሰ),
					result  => q(ጐሰጐ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐሰቈለ),
					result  => q(ጐሰቈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐሰረ),
					result  => q(ጐሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐሰመ),
					result  => q(ጐሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐርዳዳ),
					result  => q(ጐርዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐርደድ),
					result  => q(ጐርደድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐርናና),
					result  => q(ጐርናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐረፈ),
					result  => q(ጐረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐረጐረ),
					result  => q(ጐረጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐረና),
					result  => q(ጐረና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐረበጠኝ),
					result  => q(ጐረበ፟ጠኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐረበጠ),
					result  => q(ጐረበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐመራ),
					result  => q(ጐመራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐልዳፋ),
					result  => q(ጐልዳፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐልማማ),
					result  => q(ጐልማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐላ),
					result  => q(ጐላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐለጐለ),
					result  => q(ጐለጐ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጐለተ),
					result  => q(ጐለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎፈነነ),
					result  => q(ጎፈነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎፈር),
					result  => q(ጎፈ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎፈረ),
					result  => q(ጎፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎጆና),
					result  => q(ጎጆ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎጆ),
					result  => q(ጎጆ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎዳኒሳ),
					result  => q(ጎዳኒሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎዳ),
					result  => q(ጎዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎደል),
					result  => q(ጎደ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎደለ),
					result  => q(ጎደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎዦ),
					result  => q(ጎዦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎዘጎዘ),
					result  => q(ጎዘ፟ጎ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎንደርኛ),
					result  => q(ጎንደርኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎን),
					result  => q(ጎን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎታች),
					result  => q(ጎታ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎበዘ),
					result  => q(ጎበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎበበ),
					result  => q(ጎበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎሽ),
					result  => q(ጎሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎሸመ),
					result  => q(ጎሸ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎርደድ),
					result  => q(ጎርደድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎራረደ),
					result  => q(ጎራረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎረደመ),
					result  => q(ጎረደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎረደ),
					result  => q(ጎረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎረበ),
					result  => q(ጎረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎረሰ),
					result  => q(ጎረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎረመሰ),
					result  => q(ጎረመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎምዛዛ),
					result  => q(ጎምዛ፟ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎምላላ),
					result  => q(ጎምላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎማሬ),
					result  => q(ጎማ፟ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎማህ),
					result  => q(ጎማ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎማ),
					result  => q(ጎማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎሚስታ),
					result  => q(ጎሚ፟ስታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎመጀ),
					result  => q(ጎመጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎመደ),
					result  => q(ጎመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎመዘዘ),
					result  => q(ጎመዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎመን),
					result  => q(ጎመ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎልማሳ),
					result  => q(ጎልማሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጎለመሰ),
					result  => q(ጎለመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግፊያ),
					result  => q(ግፊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግፊት),
					result  => q(ግፊ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግፈኛ),
					result  => q(ግፈኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግጥም),
					result  => q(ግጥ፟ም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግግር),
					result  => q(ግግ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግግ),
					result  => q(ግግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግድግዳ),
					result  => q(ግድግዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግድያ),
					result  => q(ግድያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግድብ),
					result  => q(ግድ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግድ),
					result  => q(ግድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግዴታ),
					result  => q(ግዴ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግዴ),
					result  => q(ግዴ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግዳጅ),
					result  => q(ግዳ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግዳይ),
					result  => q(ግዳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግዥ),
					result  => q(ግዥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግዞተኛ),
					result  => q(ግዞተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግዝት),
					result  => q(ግዝ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግኝት),
					result  => q(ግኝ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግንዲላ),
					result  => q(ግንዲላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግንዛቤ),
					result  => q(ግንዛ፟ቤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግንኙነት),
					result  => q(ግንኙ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግንበኛ),
					result  => q(ግንበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግትቻ),
					result  => q(ግትቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግትርትር),
					result  => q(ግትርትር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግትር),
					result  => q(ግት፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግብዣ),
					result  => q(ግብዣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግብዝና),
					result  => q(ግብዝና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግብዝ),
					result  => q(ግብ፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግብርና),
					result  => q(ግብርና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግቢ),
					result  => q(ግቢ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግሽር),
					result  => q(ግሽ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግስጋሴ),
					result  => q(ግስጋ፟ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግስላ),
					result  => q(ግስ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግሳንግስ),
					result  => q(ግሳ፟ንግስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግርፋት),
					result  => q(ግር፟ፋት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግርግር),
					result  => q(ግር፟ግር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግርድፍ),
					result  => q(ግርድ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግርድና),
					result  => q(ግርድና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግርዛት),
					result  => q(ግር፟ዛት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግር),
					result  => q(ግር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግራዋ),
					result  => q(ግራዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግራኝ),
					result  => q(ግራኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግረዛ),
					result  => q(ግረ፟ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግሦች),
					result  => q(ግሦ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግሥ),
					result  => q(ግሥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግሣጼ),
					result  => q(ግሣ፟ጼ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግሣዊ),
					result  => q(ግሣ፟ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግምት),
					result  => q(ግም፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግምበኛ),
					result  => q(ግምበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግምል),
					result  => q(ግም፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግም),
					result  => q(ግም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግማጭ),
					result  => q(ግማ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግማደ),
					result  => q(ግማ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግማሽ),
					result  => q(ግማ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልፍታም),
					result  => q(ግል፟ፍታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልፍተኛ),
					result  => q(ግልፍተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልፍ),
					result  => q(ግል፟ፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልፋፊ),
					result  => q(ግልፋ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልግል),
					result  => q(ግልግ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልብነት),
					result  => q(ግልብነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልባጭ),
					result  => q(ግል፟ባ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግልሙትና),
					result  => q(ግልሙትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግላጭ),
					result  => q(ግላ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግላዊ),
					result  => q(ግላ፟ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግለኛ),
					result  => q(ግለ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግለሂስ),
					result  => q(ግለ፟ሂስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጌጠኛ),
					result  => q(ጌጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጌጅ),
					result  => q(ጌጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጌቶች),
					result  => q(ጌቶች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጌትነት),
					result  => q(ጌትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋጠኝ),
					result  => q(ጋጠኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋጋ),
					result  => q(ጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋገረ),
					result  => q(ጋገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋየ),
					result  => q(ጋየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋንድያ),
					result  => q(ጋንድያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋብቻ),
					result  => q(ጋብቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋበዘ),
					result  => q(ጋበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋሽዬ),
					result  => q(ጋሽ፟ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋሼ),
					result  => q(ጋሼ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋሻ),
					result  => q(ጋሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋሸበ),
					result  => q(ጋሸ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋሬ),
					result  => q(ጋሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋራማ),
					result  => q(ጋራማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋረጠ),
					result  => q(ጋረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋረደ),
					result  => q(ጋረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋሜ),
					result  => q(ጋሜ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋማ),
					result  => q(ጋማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጋለበ),
					result  => q(ጋለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉጉት),
					result  => q(ጉጉ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉዶ),
					result  => q(ጉዶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉድለት),
					result  => q(ጉድ፟ለት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉድ),
					result  => q(ጉድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉዳይ),
					result  => q(ጉዳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉዳዬ),
					result  => q(ጉዳ፟ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉዳዩ),
					result  => q(ጉዳ፟ዩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉዳተኛ),
					result  => q(ጉዳተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉደኛ),
					result  => q(ጉደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉያ),
					result  => q(ጉያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉቶ),
					result  => q(ጉቶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉትያ),
					result  => q(ጉትያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉትቻ),
					result  => q(ጉትቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉተታ),
					result  => q(ጉተ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉቦኛ),
					result  => q(ጉቦ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉቦ),
					result  => q(ጉቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉብዝና),
					result  => q(ጉብዝና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉብታ),
					result  => q(ጉብ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉብ),
					result  => q(ጉብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉበኛ),
					result  => q(ጉበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉበት),
					result  => q(ጉበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉሮሮ),
					result  => q(ጉሮሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉርብትና),
					result  => q(ጉርብትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉርብርብ),
					result  => q(ጉርብርብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉርምስና),
					result  => q(ጉርምስ፟ና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉሬዛማ),
					result  => q(ጉሬዛማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉራጅ),
					result  => q(ጉራ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉራች),
					result  => q(ጉራ፟ች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉራቻ),
					result  => q(ጉራ፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉራሽ),
					result  => q(ጉራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉራ),
					result  => q(ጉራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉረኛ),
					result  => q(ጉረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉረኖ),
					result  => q(ጉረኖ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉረሮ),
					result  => q(ጉረሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉም),
					result  => q(ጉም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉማጅ),
					result  => q(ጉማ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉልቻ),
					result  => q(ጉል፟ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉልተኛ),
					result  => q(ጉልተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉልበተኛ),
					result  => q(ጉልበተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉልማ),
					result  => q(ጉልማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጉልላት),
					result  => q(ጉል፟ላት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገፋፋ),
					result  => q(ገፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገፋ),
					result  => q(ገፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገፈፋ),
					result  => q(ገፈፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገፈፈ),
					result  => q(ገፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገፈገፈ),
					result  => q(ገፈገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገፈተረ),
					result  => q(ገፈተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገጨኸኝ),
					result  => q(ገጨ፟ኸኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገጠጠ),
					result  => q(ገጠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገጠገጠ),
					result  => q(ገጠገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገገረ),
					result  => q(ገገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገገምተኛ),
					result  => q(ገገምተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዶኝ),
					result  => q(ገዶ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገድጋዳ),
					result  => q(ገድጋዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገድለኛ),
					result  => q(ገድለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገድ),
					result  => q(ገድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዴ),
					result  => q(ገዴ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዳዳ),
					result  => q(ገዳ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዳም),
					result  => q(ገዳ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዳማ),
					result  => q(ገዳ፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደፈ),
					result  => q(ገደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደገደ),
					result  => q(ገደገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደበ),
					result  => q(ገደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደርዳራ),
					result  => q(ገደርዳራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደላማ),
					result  => q(ገደላማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደለው),
					result  => q(ገደ፟ለው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደለ),
					result  => q(ገደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገደ),
					result  => q(ገደ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዝጋዛ),
					result  => q(ገዝጋዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዛ),
					result  => q(ገዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዘፈ),
					result  => q(ገዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዘገዘ),
					result  => q(ገዘገ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገዘተ),
					result  => q(ገዘ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገንታራ),
					result  => q(ገንታራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገንባሌ),
					result  => q(ገንባሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገና),
					result  => q(ገና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነፈለ),
					result  => q(ገነፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነገነ),
					result  => q(ገነገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነደሰ),
					result  => q(ገነደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነዘ),
					result  => q(ገነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነን),
					result  => q(ገነ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነነ),
					result  => q(ገነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነት),
					result  => q(ገነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነተረ),
					result  => q(ገነተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገነባ),
					result  => q(ገነባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገቻ),
					result  => q(ገቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገትጋታ),
					result  => q(ገትጋታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገታራ),
					result  => q(ገታ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገታ),
					result  => q(ገታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገተት),
					result  => q(ገተ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገተረ),
					result  => q(ገተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገብጋባ),
					result  => q(ገብጋ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገብ),
					result  => q(ገብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገባው),
					result  => q(ገባ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገባች),
					result  => q(ገባች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገባር),
					result  => q(ገባ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገቢና),
					result  => q(ገቢና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገበያተኛ),
					result  => q(ገበያተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገበየ),
					result  => q(ገበየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገበረ),
					result  => q(ገበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሸሽ),
					result  => q(ገሸሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሸረ),
					result  => q(ገሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሸለጠ),
					result  => q(ገሸለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሰገሰ),
					result  => q(ገሰገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሰሰ),
					result  => q(ገሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሰረ),
					result  => q(ገሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገርጋራ),
					result  => q(ገርጋራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገርጃፋ),
					result  => q(ገርጃፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገርባባ),
					result  => q(ገርባባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገርበብ),
					result  => q(ገርበብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገራም),
					result  => q(ገራ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገራ),
					result  => q(ገራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረፈ),
					result  => q(ገረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረገደ),
					result  => q(ገረ፟ገደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረገረ),
					result  => q(ገረገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረጀፈ),
					result  => q(ገረጀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረደፈ),
					result  => q(ገረደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረዘ),
					result  => q(ገረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረረ),
					result  => q(ገረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረመመ),
					result  => q(ገረመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገረመ),
					result  => q(ገረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሠጸ),
					result  => q(ገሠ፟ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሠጠ),
					result  => q(ገሠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሠሠ),
					result  => q(ገሠ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገምባሌ),
					result  => q(ገምባሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገማች),
					result  => q(ገማ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገማ),
					result  => q(ገማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመጠ),
					result  => q(ገመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመገመ),
					result  => q(ገመገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመደለ),
					result  => q(ገመደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመደ),
					result  => q(ገመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመተ),
					result  => q(ገመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመሰ),
					result  => q(ገመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመምተኛ),
					result  => q(ገመምተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገመለ),
					result  => q(ገመ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገልዋዳ),
					result  => q(ገልዋዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገላገለ),
					result  => q(ገላገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገላመጠ),
					result  => q(ገላመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገላለጠ),
					result  => q(ገላለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለፈፈ),
					result  => q(ገለፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለፈጠ),
					result  => q(ገለፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለጸ),
					result  => q(ገለ፟ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለጠ),
					result  => q(ገለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለጀጀ),
					result  => q(ገለጀ፟ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለበጠ),
					result  => q(ገለበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለበ),
					result  => q(ገለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለሞተ),
					result  => q(ገለሞ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለማ),
					result  => q(ገለማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለልተኛነት),
					result  => q(ገለልተኛ፟ነት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለልተኛ),
					result  => q(ገለልተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገለል),
					result  => q(ገለል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሀነም),
					result  => q(ገሀነ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገሀነመ),
					result  => q(ገሀነ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጆፍጆፌ),
					result  => q(ጆፍጆፌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጆፌ),
					result  => q(ጆፌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጆንያ),
					result  => q(ጆንያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅው),
					result  => q(ጅው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅዋጅዌ),
					result  => q(ጅዋ፟ጅዌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅንን),
					result  => q(ጅን፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅብ),
					result  => q(ጅብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅምር),
					result  => q(ጅም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅማት),
					result  => q(ጅማ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅማታም),
					result  => q(ጅማ፟ታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅልነት),
					result  => q(ጅልነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጅላንጅል),
					result  => q(ጅላንጅ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጃፓን),
					result  => q(ጃፓ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጃፓናዊ),
					result  => q(ጃፓ፟ናዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጃጀ),
					result  => q(ጃጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጃውሳ),
					result  => q(ጃው፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጃዊ),
					result  => q(ጃዊ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጃኬት),
					result  => q(ጃኬ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጂጌ),
					result  => q(ጂጌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀግንነት),
					result  => q(ጀግንነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀገነ),
					result  => q(ጀገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀቦነ),
					result  => q(ጀቦ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀብደኛ),
					result  => q(ጀብደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀበደ),
					result  => q(ጀበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀበበ),
					result  => q(ጀበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀሶ),
					result  => q(ጀሶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀረገገ),
					result  => q(ጀረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀምሮ),
					result  => q(ጀም፟ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ጀመረ),
					result  => q(ጀመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶፍዷፋ),
					result  => q(ዶፍዷፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶፈዶፈ),
					result  => q(ዶፈዶ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶዮ),
					result  => q(ዶዮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶኬ),
					result  => q(ዶኬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶመኛ),
					result  => q(ዶመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶልዷማ),
					result  => q(ዶልዷማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶልዷሌ),
					result  => q(ዶልዷሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶልዷላ),
					result  => q(ዶልዷላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶለዶመ),
					result  => q(ዶለዶ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዶለተ),
					result  => q(ዶለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድጕሳት),
					result  => q(ድጕ፟ሳት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድጎማ),
					result  => q(ድጎ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድግን),
					result  => q(ድግ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድግስ),
					result  => q(ድግ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድጋሚ),
					result  => q(ድጋ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድገና),
					result  => q(ድገ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድድቅ),
					result  => q(ድድ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድድር),
					result  => q(ድድ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድድ),
					result  => q(ድድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድዳም),
					result  => q(ድዳ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድውይ),
					result  => q(ድው፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድውር),
					result  => q(ድው፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድው),
					result  => q(ድው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድወላ),
					result  => q(ድወ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድኽነት),
					result  => q(ድኽነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድኩላ),
					result  => q(ድኩ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድኝ),
					result  => q(ድኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንግዝግዝ),
					result  => q(ድንግዝግዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንግልና),
					result  => q(ድንግል፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንጋጤ),
					result  => q(ድንጋ፟ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንጋጌ),
					result  => q(ድንጋ፟ጌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንገተኛ),
					result  => q(ድንገተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንክዬ),
					result  => q(ድንክዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንች),
					result  => q(ድን፟ች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንቡሎ),
					result  => q(ድንቡሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንበርተኛ),
					result  => q(ድንበርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንበረተኛ),
					result  => q(ድንበረተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንቅ),
					result  => q(ድን፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንቄም),
					result  => q(ድንቄም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድንቁርና),
					result  => q(ድንቁርና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድኅነት),
					result  => q(ድኅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድብኝት),
					result  => q(ድብኝ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድብን),
					result  => q(ድብ፟ን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድብት),
					result  => q(ድብ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድብብቆሽ),
					result  => q(ድብብ፟ቆሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድብቅ),
					result  => q(ድብ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድብልቅ),
					result  => q(ድብል፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድብ),
					result  => q(ድብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድባኖ),
					result  => q(ድባ፟ኖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድቡሽት),
					result  => q(ድቡ፟ሽት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድበብ),
					result  => q(ድበብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድበቃ),
					result  => q(ድበ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድቅን),
					result  => q(ድቅ፟ን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድቁስ),
					result  => q(ድቁ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርግም),
					result  => q(ድርግም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርጊት),
					result  => q(ድርጊ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርጅት),
					result  => q(ድርጅ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርጁ),
					result  => q(ድርጁ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርድር),
					result  => q(ድርድ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርና),
					result  => q(ድርና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርት),
					result  => q(ድር፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርብ),
					result  => q(ድር፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርቅና),
					result  => q(ድርቅና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድርቅ),
					result  => q(ድር፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድራሹ),
					result  => q(ድራ፟ሹ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድሪያ),
					result  => q(ድሪ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድምቡሼ),
					result  => q(ድምቡሼ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድምበረተኛ),
					result  => q(ድምበረተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድምር),
					result  => q(ድም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድማሪ),
					result  => q(ድማ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድመት),
					result  => q(ድመ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድመራ),
					result  => q(ድመ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድሎትኛ),
					result  => q(ድሎትኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድልድል),
					result  => q(ድልድ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድልዝ),
					result  => q(ድል፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድልኽ),
					result  => q(ድል፟ኽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድልኸ),
					result  => q(ድል፟ኸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድልል),
					result  => q(ድል፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድልህ),
					result  => q(ድል፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድል),
					result  => q(ድል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድለላ),
					result  => q(ድለ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ድህነት),
					result  => q(ድህነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳግመኛ),
					result  => q(ዳግመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳውላ),
					result  => q(ዳውላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳዋ),
					result  => q(ዳዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳክዬ),
					result  => q(ዳክ፟ዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳከረ),
					result  => q(ዳከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳኝነት),
					result  => q(ዳኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳኛ),
					result  => q(ዳኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳኘ),
					result  => q(ዳኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳንግሌ),
					result  => q(ዳንግሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳንሰኛ),
					result  => q(ዳንሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳተኛ),
					result  => q(ዳተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳቦ),
					result  => q(ዳቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳባ),
					result  => q(ዳባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳበሳ),
					result  => q(ዳበ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳበሰ),
					result  => q(ዳበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳበረ),
					result  => q(ዳበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳሸቀ),
					result  => q(ዳሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳሰሰ),
					result  => q(ዳሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳርና),
					result  => q(ዳርና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳርቻ),
					result  => q(ዳርቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳረገ),
					result  => q(ዳረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳመጠ),
					result  => q(ዳመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳመናም),
					result  => q(ዳመ፟ናም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳመናማ),
					result  => q(ዳመና፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳመና),
					result  => q(ዳመ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳመነ),
					result  => q(ዳመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳሌ),
					result  => q(ዳሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳለጠ),
					result  => q(ዳለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዳለቻ),
					result  => q(ዳለቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዲካ),
					result  => q(ዲካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዱብ),
					result  => q(ዱብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዱቤ),
					result  => q(ዱቤ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዱባ),
					result  => q(ዱባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዱርዬ),
					result  => q(ዱርዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዱላ),
					result  => q(ዱላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዱለኛ),
					result  => q(ዱለ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዱለቻ),
					result  => q(ዱለ፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፍ),
					result  => q(ደፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፋር),
					result  => q(ደፋ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፋ),
					result  => q(ደፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፈደፈ),
					result  => q(ደፈደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፈንፋና),
					result  => q(ደፈንፋና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፈነ),
					result  => q(ደፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፈቀ),
					result  => q(ደፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፈረሰ),
					result  => q(ደፈረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደፈረ),
					result  => q(ደፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጎባ),
					result  => q(ደጎ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጎመ),
					result  => q(ደጎ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደግፍ),
					result  => q(ደግ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደግዳጋ),
					result  => q(ደግዳጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደግነት),
					result  => q(ደግ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደግነቱ),
					result  => q(ደግ፟ነ፟ቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደግ),
					result  => q(ደግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጋፊ),
					result  => q(ደጋ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጋደግ),
					result  => q(ደጋ፟ደግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጉሰ),
					result  => q(ደጉ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደገፈ),
					result  => q(ደገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደገደገ),
					result  => q(ደገደ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደገኛ),
					result  => q(ደገኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደገነ),
					result  => q(ደገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደገሰ),
					result  => q(ደገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደገመ),
					result  => q(ደገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጅ),
					result  => q(ደጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጃፍ),
					result  => q(ደጃ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጃች),
					result  => q(ደጃ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደጀ),
					result  => q(ደጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደደብ),
					result  => q(ደደ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደደበ),
					result  => q(ደደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደደቀ),
					result  => q(ደደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደደረ),
					result  => q(ደደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደዋይ),
					result  => q(ደዋ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደወለ),
					result  => q(ደወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደኸየ),
					result  => q(ደኸየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደካማ),
					result  => q(ደካማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደከመ),
					result  => q(ደከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንጋዛ),
					result  => q(ደንጋዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንጋራ),
					result  => q(ደንጋራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንጉላ),
					result  => q(ደንጉላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንገሎ),
					result  => q(ደንገሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንዳኔ),
					result  => q(ደንዳኔ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንዳና),
					result  => q(ደንዳና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንደስ),
					result  => q(ደንደስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንደሳም),
					result  => q(ደንደ፟ሳ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንደሮ),
					result  => q(ደንደሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንባዛ),
					result  => q(ደንባዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንባራ),
					result  => q(ደንባራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንበኛ),
					result  => q(ደንበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደንቃፋ),
					result  => q(ደንቃፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደን),
					result  => q(ደን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደናሽ),
					result  => q(ደና፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደናማ),
					result  => q(ደና፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነፋፋ),
					result  => q(ደነፋ፟ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነፋ),
					result  => q(ደነፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነጎረ),
					result  => q(ደነጎ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነገጠ),
					result  => q(ደነገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነገገ),
					result  => q(ደነገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነገዘ),
					result  => q(ደነገ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነደነ),
					result  => q(ደነደነ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነዘዘ),
					result  => q(ደነዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነዘ),
					result  => q(ደነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነነ),
					result  => q(ደነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነባ),
					result  => q(ደነባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነበዘ),
					result  => q(ደነበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነበረ),
					result  => q(ደነበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነቆረ),
					result  => q(ደነቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነቆለ),
					result  => q(ደነቆ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነቀፈ),
					result  => q(ደነቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነቀረ),
					result  => q(ደነቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነቀ),
					result  => q(ደነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደነሰ),
					result  => q(ደነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደኅንነት),
					result  => q(ደኅንነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቦልቧላ),
					result  => q(ደቦልቧላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቦል),
					result  => q(ደቦ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቦለቦለ),
					result  => q(ደቦለቦ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደብዳቤ),
					result  => q(ደብዳቤ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደብዛዛ),
					result  => q(ደብዛዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደብሳሳ),
					result  => q(ደብሳሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደባች),
					result  => q(ደባ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደባበሰ),
					result  => q(ደባበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደባቃ),
					result  => q(ደባ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደባል),
					result  => q(ደባ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበደበ),
					result  => q(ደበደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበዘዘ),
					result  => q(ደበዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበነ),
					result  => q(ደበ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበተ),
					result  => q(ደበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበበ),
					result  => q(ደበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበቀ),
					result  => q(ደበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበስባሳ),
					result  => q(ደበስባሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበሰሰ),
					result  => q(ደበሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበልባላ),
					result  => q(ደበልባላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበላለቀ),
					result  => q(ደበላለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበለቀ),
					result  => q(ደበለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደበለለ),
					result  => q(ደበለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቋቆሰ),
					result  => q(ደቋቆ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቆስቋሳ),
					result  => q(ደቆስቋሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቆሰ),
					result  => q(ደቆ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቅደቂት),
					result  => q(ደቅደቂ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቃቅ),
					result  => q(ደቃ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቃቃ),
					result  => q(ደቃ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቃ),
					result  => q(ደቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቀደቀ),
					result  => q(ደቀደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቀነ),
					result  => q(ደቀ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቀቀ),
					result  => q(ደቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቀመዝሙር),
					result  => q(ደቀ፟መዝሙር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቀለ),
					result  => q(ደቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደቀ),
					result  => q(ደቀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደስታ),
					result  => q(ደስ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደስተኛ),
					result  => q(ደስ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደስ),
					result  => q(ደስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደሰሰ),
					result  => q(ደሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደሰመ),
					result  => q(ደሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደርካካ),
					result  => q(ደርካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደርባባ),
					result  => q(ደርባባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደርበብ),
					result  => q(ደርበብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደርሽ),
					result  => q(ደር፟ሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደራሲነት),
					result  => q(ደራሲነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደራ),
					result  => q(ደራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረገመ),
					result  => q(ደረገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረጀ),
					result  => q(ደረጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረደረ),
					result  => q(ደረደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረተ),
					result  => q(ደረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረበ),
					result  => q(ደረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረቀ),
					result  => q(ደረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረሰኝ),
					result  => q(ደረ፟ሰኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረሰበት),
					result  => q(ደረ፟ሰበት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረሰመ),
					result  => q(ደረሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረሰለት),
					result  => q(ደረ፟ሰለ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደረሰ),
					result  => q(ደረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደሞ),
					result  => q(ደሞ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደምበኛ),
					result  => q(ደምበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደም),
					result  => q(ደም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደማቅ),
					result  => q(ደማ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደማቃ),
					result  => q(ደማ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደማ),
					result  => q(ደማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመደመ),
					result  => q(ደመደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመወዝተኛ),
					result  => q(ደመወዝተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመኛ),
					result  => q(ደመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመና),
					result  => q(ደመ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመቀ),
					result  => q(ደመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመሰሰ),
					result  => q(ደመሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመረ),
					result  => q(ደመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደመመ),
					result  => q(ደመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደልዳላ),
					result  => q(ደልዳ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደልቃቃ),
					result  => q(ደልቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደላይ),
					result  => q(ደላ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደላላ),
					result  => q(ደላ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደላ),
					result  => q(ደላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደለፈሰ),
					result  => q(ደለፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደለደለ),
					result  => q(ደለደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደለዘ),
					result  => q(ደለ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደለኸ),
					result  => q(ደለ፟ኸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደለበ),
					result  => q(ደለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደለቀ),
					result  => q(ደለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ደለለ),
					result  => q(ደለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይግባኝ),
					result  => q(ይግባኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይውልህ),
					result  => q(ይውል፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይብላኝ),
					result  => q(ይብላኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይሻላል),
					result  => q(ይሻ፟ላል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይስጥልኝ),
					result  => q(ይስጥልኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይስጣኝ),
					result  => q(ይስጣኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይስጠን),
					result  => q(ይስጠን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይልቅስ),
					result  => q(ይልቅስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይልቁንስ),
					result  => q(ይልቁንስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይልቁንም),
					result  => q(ይልቁንም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይሉኝታ),
					result  => q(ይሉኝ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይሉኝ),
					result  => q(ይሉኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይህኛው),
					result  => q(ይህኛ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይህን),
					result  => q(ይህን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ይህም),
					result  => q(ይህም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያጎት),
					result  => q(ያጎ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያገለገለ),
					result  => q(ያገለገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያደረ),
					result  => q(ያደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያዝ),
					result  => q(ያዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያውኮ),
					result  => q(ያውኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያውና),
					result  => q(ያውና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያኛው),
					result  => q(ያኛ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያንን),
					result  => q(ያን፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያንማ),
					result  => q(ያን፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያን),
					result  => q(ያን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያኔ),
					result  => q(ያኔ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያች),
					result  => q(ያች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያቻትና),
					result  => q(ያቻ፟ትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያሳማ),
					result  => q(ያሳ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያም),
					result  => q(ያም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያመዋል),
					result  => q(ያመ፟ዋል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያልታሰበ),
					result  => q(ያልታሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያልተገራ),
					result  => q(ያልተገራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያልተወሰነ),
					result  => q(ያልተወሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያልተሟላ),
					result  => q(ያልተሟላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያለግምት),
					result  => q(ያለግም፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያለውድ),
					result  => q(ያለውድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ያለ),
					result  => q(ያለ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የፊጥኝ),
					result  => q(የፊጥ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የፊታችን),
					result  => q(የፊታች፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የፈሰሰ),
					result  => q(የፈሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጭቅና),
					result  => q(የጭቅ፟ና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጫማ),
					result  => q(የጫማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጥያቄ),
					result  => q(የጥያ፟ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጥቅል),
					result  => q(የጥቅ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጥሪ),
					result  => q(የጥሪ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጠረጴዛ),
					result  => q(የጠረጴ፟ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጠለቀ),
					result  => q(የጠለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጎደለበት),
					result  => q(የጎደ፟ለበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጎልማሶች),
					result  => q(የጎልማሶች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የግሥ),
					result  => q(የግሥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጋማ),
					result  => q(የጋማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የጉበት),
					result  => q(የጉበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የገዛ),
					result  => q(የገዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የድመት),
					result  => q(የድመ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የደስደስ),
					result  => q(የደስደስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የደራ),
					result  => q(የደራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የደምበኛ),
					result  => q(የደምበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የይ),
					result  => q(የይ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የዝናር),
					result  => q(የዝና፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የዋህነት),
					result  => q(የዋ፟ህነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የዋህ),
					result  => q(የዋ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የወንድም),
					result  => q(የወንድም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የወረገኑ),
					result  => q(የወረ፟ገኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የኮቴ),
					result  => q(የኮቴ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የክት),
					result  => q(የክት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የካቲት),
					result  => q(የካ፟ቲት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የከበረ),
					result  => q(የከበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የእጅ),
					result  => q(የእጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የአጋጣሚ),
					result  => q(የአጋጣ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የአየር),
					result  => q(የአየ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የአህያ),
					result  => q(የአህያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የንስሐ),
					result  => q(የንስ፟ሐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የናት),
					result  => q(የና፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የነጋዴዎች),
					result  => q(የነጋ፟ዴዎች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የነቃ),
					result  => q(የነቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የትየለሌ),
					result  => q(የትየ፟ለሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የትኛው),
					result  => q(የትኛ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የትና),
					result  => q(የትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የትም),
					result  => q(የትም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የታማ),
					result  => q(የታማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተጸውዖ),
					result  => q(የተጸው፟ዖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተጣራ),
					result  => q(የተጣራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተጣላ),
					result  => q(የተጣላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተጠላ),
					result  => q(የተጠላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተዛባ),
					result  => q(የተዛባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተወሰነ),
					result  => q(የተወሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተወለደ),
					result  => q(የተወ፟ለደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተንጠለጠለ),
					result  => q(የተንጠለጠ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተቀደሰ),
					result  => q(የተቀደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተሟጠጠ),
					result  => q(የተሟጠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተሟላ),
					result  => q(የተሟላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተለያየ),
					result  => q(የተለያየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የተለቀቀ),
					result  => q(የተለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የባሰበት),
					result  => q(የባሰበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የበቃ),
					result  => q(የበቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የበላይነት),
					result  => q(የበላይነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የበለጠ),
					result  => q(የበለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የቈላ),
					result  => q(የቈላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የቆየ),
					result  => q(የቆየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የቀረው),
					result  => q(የቀረ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የቀረች),
					result  => q(የቀረ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የቀረ),
					result  => q(የቀረ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሸማኔ),
					result  => q(የሸማ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሳቸው),
					result  => q(የሳ፟ቸ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሱ),
					result  => q(የሱ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሰራ),
					result  => q(የሰ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የርሳቸው),
					result  => q(የርሳቸ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የርሱ),
					result  => q(የርሱ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሩጫ),
					result  => q(የሩጫ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የረፋድ),
					result  => q(የረፋ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የረሳው),
					result  => q(የረሳ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የምስራች),
					result  => q(የምስ፟ራች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የምር),
					result  => q(የምር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የምሩን),
					result  => q(የምሩ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይጠዳው),
					result  => q(የማ፟ይጠዳው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይታጠፍ),
					result  => q(የማ፟ይታጠ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይበገር),
					result  => q(የማ፟ይበ፟ገ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይበቃ),
					result  => q(የማ፟ይበቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይቀር),
					result  => q(የማ፟ይቀር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይሻር),
					result  => q(የማ፟ይሻ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይረባ),
					result  => q(የማ፟ይረባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይል),
					result  => q(የማ፟ይል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይለው),
					result  => q(የማ፟ይለው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይለወጥ),
					result  => q(የማ፟ይለ፟ወ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማይሆን),
					result  => q(የማ፟ይሆን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማያዛልቅ),
					result  => q(የማ፟ያዛ፟ል፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማያከራክር),
					result  => q(የማ፟ያከ፟ራክ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማዘጋጃ),
					result  => q(የማዘ፟ጋጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የማን),
					result  => q(የማን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚጠልዝ),
					result  => q(የሚ፟ጠል፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚያከራክር),
					result  => q(የሚ፟ያከ፟ራክ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚያስተኛ),
					result  => q(የሚ፟ያስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚያስቅ),
					result  => q(የሚ፟ያስ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚያሰለች),
					result  => q(የሚ፟ያሰለች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚያመሰኳ),
					result  => q(የሚ፟ያመሰኳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚያህል),
					result  => q(የሚ፟ያህል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚዘለቅ),
					result  => q(የሚዘ፟ለ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚበቃ),
					result  => q(የሚ፟በቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሚመጣው),
					result  => q(የሚ፟መጣው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የመሸኛ),
					result  => q(የመሸኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የመረረ),
					result  => q(የመረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሕግ),
					result  => q(የሕግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሐሰት),
					result  => q(የሐሰ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሌለው),
					result  => q(የሌ፟ለ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የሌለ),
					result  => q(የሌለ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የለውም),
					result  => q(የለ፟ውም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የለኝም),
					result  => q(የለ፟ኝ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የለሽ),
					result  => q(የለ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የለም),
					result  => q(የለ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(የለለው),
					result  => q(የለለ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዦፌ),
					result  => q(ዦፌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዥው),
					result  => q(ዥው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዥዋዥዌ),
					result  => q(ዥዋ፟ዥዌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዥማት),
					result  => q(ዥማ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠብራራ),
					result  => q(ዠብራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠብረር),
					result  => q(ዠብረር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠበድ),
					result  => q(ዠበ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠበደ),
					result  => q(ዠበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠቀዠቀ),
					result  => q(ዠቀዠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠርጋጋ),
					result  => q(ዠርጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠርጋዳ),
					result  => q(ዠርጋዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠረገገ),
					result  => q(ዠረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠረር),
					result  => q(ዠረር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዠለጠ),
					result  => q(ዠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝግጅት),
					result  => q(ዝግጅ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝግጁ),
					result  => q(ዝግጁ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝግታ),
					result  => q(ዝግ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝግተኛ),
					result  => q(ዝግ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝግ),
					result  => q(ዝግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝይ),
					result  => q(ዝይ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝየዳ),
					result  => q(ዝየ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝየና),
					result  => q(ዝየ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝየራ),
					result  => q(ዝየ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝውውር),
					result  => q(ዝውው፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝክዝክ),
					result  => q(ዝክዝክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝንፋት),
					result  => q(ዝን፟ፋት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝንጅብል),
					result  => q(ዝንጅብል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝንባሌ),
					result  => q(ዝንባ፟ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝናቢስ),
					result  => q(ዝና፟ቢስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝናር),
					result  => q(ዝና፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝና),
					result  => q(ዝና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝነጣ),
					result  => q(ዝነ፟ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝነኛ),
					result  => q(ዝነ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝተት),
					result  => q(ዝተ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝተታም),
					result  => q(ዝተ፟ታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝብዝብ),
					result  => q(ዝብዝ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝቅተኛ),
					result  => q(ዝቅ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝቅ),
					result  => q(ዝቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝቃጭ),
					result  => q(ዝቃ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝቀታ),
					result  => q(ዝቀ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝርግፍ),
					result  => q(ዝርግፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝርግነት),
					result  => q(ዝርግነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝርያ),
					result  => q(ዝር፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝርዝር),
					result  => q(ዝርዝ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝርዛሪ),
					result  => q(ዝርዛ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝርክት),
					result  => q(ዝርክ፟ት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝርክርክ),
					result  => q(ዝርክርክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝር),
					result  => q(ዝር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝራጭ),
					result  => q(ዝራ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝምታ),
					result  => q(ዝም፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝም),
					result  => q(ዝም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝማሬ),
					result  => q(ዝማ፟ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝሙት),
					result  => q(ዝሙ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝሙተኛ),
					result  => q(ዝሙ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝመራ),
					result  => q(ዝመ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝልስ),
					result  => q(ዝል፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝልል),
					result  => q(ዝል፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝላይ),
					result  => q(ዝላ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዝሊያ),
					result  => q(ዝሊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዜንጠኛ),
					result  => q(ዜንጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዜመኛ),
					result  => q(ዜመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዛጎልማ),
					result  => q(ዛጎልማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዛዘነ),
					result  => q(ዛዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዛኒጋባ),
					result  => q(ዛኒጋባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዛቻ),
					result  => q(ዛቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዛተለ),
					result  => q(ዛተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዚቀኛ),
					result  => q(ዚቀኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዙጥ),
					result  => q(ዙጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘፍ),
					result  => q(ዘፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘፈዘፈ),
					result  => q(ዘፈዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘፈነ),
					result  => q(ዘፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘፈቀ),
					result  => q(ዘፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘጠኝ),
					result  => q(ዘጠኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘጠነኛ),
					result  => q(ዘጠነኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘጎነ),
					result  => q(ዘጎ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘጎርጓራ),
					result  => q(ዘጎርጓራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘግየት),
					result  => q(ዘግየት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘጋ),
					result  => q(ዘጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘገየ),
					result  => q(ዘገየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘገነነ),
					result  => q(ዘገነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘገነ),
					result  => q(ዘገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘገበ),
					result  => q(ዘገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘገረረ),
					result  => q(ዘገረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘገምተኛ),
					result  => q(ዘገምተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘዴኛ),
					result  => q(ዘዴኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘያጅ),
					result  => q(ዘያ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘየደ),
					result  => q(ዘየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘየነ),
					result  => q(ዘየ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘየረ),
					result  => q(ዘየ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘው),
					result  => q(ዘው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘዋራ),
					result  => q(ዘዋ፟ራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘወርዋራ),
					result  => q(ዘወርዋራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘወረ),
					result  => q(ዘወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘክዛካ),
					result  => q(ዘክዛካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘኬ),
					result  => q(ዘኬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘከዘከ),
					result  => q(ዘከዘ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘከረ),
					result  => q(ዘከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘንፋላ),
					result  => q(ዘንፋላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘንካታ),
					result  => q(ዘንካታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘንባላ),
					result  => q(ዘንባላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘናጭ),
					result  => q(ዘና፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘና),
					result  => q(ዘና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነፈ),
					result  => q(ዘነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነጋ),
					result  => q(ዘነጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነን),
					result  => q(ዘነን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነነ),
					result  => q(ዘነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነተረ),
					result  => q(ዘነተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነበ),
					result  => q(ዘነ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነቆለ),
					result  => q(ዘነቆ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነቀ),
					result  => q(ዘነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘነመ),
					result  => q(ዘነ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘብጥያ),
					result  => q(ዘብጥያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘብዛባ),
					result  => q(ዘብዛባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘባረቀ),
					result  => q(ዘባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘባ),
					result  => q(ዘባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበጠ),
					result  => q(ዘበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበዘበ),
					result  => q(ዘበዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበኛ),
					result  => q(ዘበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበናይነት),
					result  => q(ዘበናይነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበነ),
					result  => q(ዘበ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበተ),
					result  => q(ዘበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበራረቀ),
					result  => q(ዘበራረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘበለለ),
					result  => q(ዘበለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘቅዛቃ),
					result  => q(ዘቅዛቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘቀጠ),
					result  => q(ዘቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘቀዘቀ),
					result  => q(ዘቀዘ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘርፍና),
					result  => q(ዘርፍና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘርፋፋ),
					result  => q(ዘርፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘርዛራ),
					result  => q(ዘርዛራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘርካታ),
					result  => q(ዘርካታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘራፍ),
					result  => q(ዘራ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘራሽ),
					result  => q(ዘራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘራ),
					result  => q(ዘራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረፍራፋ),
					result  => q(ዘረፍራፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረፈ),
					result  => q(ዘረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረጋ),
					result  => q(ዘረጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረገፈ),
					result  => q(ዘረገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረዘረ),
					result  => q(ዘረዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረክራካ),
					result  => q(ዘረክራካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረከተ),
					result  => q(ዘረከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረኛ),
					result  => q(ዘረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረነቀ),
					result  => q(ዘረነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘረረ),
					result  => q(ዘረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘማዊ),
					result  => q(ዘማ፟ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘማ),
					result  => q(ዘማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘመዳሞች),
					result  => q(ዘመዳሞች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘመዘመ),
					result  => q(ዘመዘ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘመተ),
					result  => q(ዘመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘመረ),
					result  => q(ዘመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘመመ),
					result  => q(ዘመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘልዛልነት),
					result  => q(ዘልዛል፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘልዛላ),
					result  => q(ዘልዛ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘላን),
					result  => q(ዘላ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘላበደ),
					result  => q(ዘላበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለፈ),
					result  => q(ዘለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለግላጋ),
					result  => q(ዘለግላ፟ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለግ),
					result  => q(ዘለግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለዘለ),
					result  => q(ዘለዘ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለቀ),
					result  => q(ዘለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለሰኛ),
					result  => q(ዘለሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለሰ),
					result  => q(ዘለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለም),
					result  => q(ዘለም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለል),
					result  => q(ዘለል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዘለለ),
					result  => q(ዘለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕጮኛ),
					result  => q(ዕጮኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕውቀተኛ),
					result  => q(ዕውቀተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕውር),
					result  => q(ዕው፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕቅድ),
					result  => q(ዕቅ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕቃ),
					result  => q(ዕቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕቁብ),
					result  => q(ዕቁ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕቀዳ),
					result  => q(ዕቀ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕሴት),
					result  => q(ዕሴ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕምቅ),
					result  => q(ዕም፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዕልል),
					result  => q(ዕልል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዓለማዊነት),
					result  => q(ዓለማዊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዓለመኛ),
					result  => q(ዓለመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐይናማ),
					result  => q(ዐይናማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐየ),
					result  => q(ዐየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐውድማ),
					result  => q(ዐውድማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐወደኝ),
					result  => q(ዐወ፟ደኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐወደ),
					result  => q(ዐወ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐወቀ),
					result  => q(ዐወ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐበድ),
					result  => q(ዐበ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐበደ),
					result  => q(ዐበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐቃቤ),
					result  => q(ዐቃ፟ቤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐቃቢት),
					result  => q(ዐቃ፟ቢት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐቀደ),
					result  => q(ዐቀ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐራቢ),
					result  => q(ዐራ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐረፈ),
					result  => q(ዐረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐረገ),
					result  => q(ዐረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐረብኛ),
					result  => q(ዐረብኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐረበ),
					result  => q(ዐረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐረቀ),
					result  => q(ዐረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐሥር),
					result  => q(ዐሥ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐሥረኛ),
					result  => q(ዐሥረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐመፀኛ),
					result  => q(ዐመፀኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐመፀ),
					result  => q(ዐመ፟ፀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐመጠኛ),
					result  => q(ዐመጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐመጠ),
					result  => q(ዐመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐመቀ),
					result  => q(ዐመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዐልቅት),
					result  => q(ዐልቅ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውፋሬ),
					result  => q(ውፋ፟ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውጊያ),
					result  => q(ውጊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውድድር),
					result  => q(ውድድ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውድነት),
					result  => q(ውድ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውድ),
					result  => q(ውድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውዴላ),
					result  => q(ውዴ፟ላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውዳቂ),
					result  => q(ውዳ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውዳሴ),
					result  => q(ውዳ፟ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውደሳ),
					result  => q(ውደ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውይባት),
					result  => q(ውይ፟ባት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውዝፍ),
					result  => q(ውዝ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውዝዋዜ),
					result  => q(ውዝዋ፟ዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውክልና),
					result  => q(ውክ፟ልና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውከላ),
					result  => q(ውከ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውንድቢ),
					result  => q(ውንድቢ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውንብድና),
					result  => q(ውንብድና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውነተኛ),
					result  => q(ውነተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውትፍ),
					result  => q(ውት፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውቅራት),
					result  => q(ውቅ፟ራት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውቃጭ),
					result  => q(ውቃ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውቂያ),
					result  => q(ውቂ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውሽማ),
					result  => q(ውሽማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውሻነት),
					result  => q(ውሻ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውሻ),
					result  => q(ውሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውስልትና),
					result  => q(ውስልትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውሳኔ),
					result  => q(ውሳ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውርጅብኝ),
					result  => q(ውርጅብ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውርንጭላ),
					result  => q(ውርንጭላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውርርድ),
					result  => q(ውርር፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውርር),
					result  => q(ውር፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውር),
					result  => q(ውር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውራጅ),
					result  => q(ውራ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውራ),
					result  => q(ውራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውልክፍክፍ),
					result  => q(ውልክፍክፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውልታ),
					result  => q(ውል፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውልብ),
					result  => q(ውል፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውልቅ),
					result  => q(ውል፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውልቃት),
					result  => q(ውል፟ቃት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውል),
					result  => q(ውል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውላጅ),
					result  => q(ውላ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውላቂ),
					result  => q(ውላ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውለኛ),
					result  => q(ውለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ውሀማ),
					result  => q(ውሀማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋጀ),
					result  => q(ዋጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋዠ),
					result  => q(ዋዠ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋኘ),
					result  => q(ዋኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋና),
					result  => q(ዋና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋነኛ),
					result  => q(ዋነ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋነተኛ),
					result  => q(ዋነተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋተተ),
					result  => q(ዋተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋሻ),
					result  => q(ዋሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋሸ),
					result  => q(ዋሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋስትና),
					result  => q(ዋስትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ዋለለ),
					result  => q(ዋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወፋፈረ),
					result  => q(ወፋፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወፈፍተኛ),
					result  => q(ወፈፍተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወፈፌ),
					result  => q(ወፈፌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወፈፈ),
					result  => q(ወፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወፈር),
					result  => q(ወፈር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወፈረ),
					result  => q(ወፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጭማዳ),
					result  => q(ወጭማዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጥ),
					result  => q(ወጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጣች),
					result  => q(ወጣች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጣትነት),
					result  => q(ወጣ፟ትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጣራ),
					result  => q(ወጣ፟ራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጣ),
					result  => q(ወጣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጌሻ),
					result  => q(ወጌሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጋጋ),
					result  => q(ወጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወጋ),
					result  => q(ወጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወገግታ),
					result  => q(ወገ፟ግታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወገግ),
					result  => q(ወገግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወገኛ),
					result  => q(ወገኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወገረ),
					result  => q(ወገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዶ),
					result  => q(ወዶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዳጅነት),
					result  => q(ወዳጅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዳድ),
					result  => q(ወዳ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዲያልኝ),
					result  => q(ወዲያል፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደጎን),
					result  => q(ወደጎን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደድ),
					result  => q(ወደ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደደ),
					result  => q(ወደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደዚያ),
					result  => q(ወደዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደዚህ),
					result  => q(ወደዚ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደቀ),
					result  => q(ወደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደረኛ),
					result  => q(ወደረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደረ),
					result  => q(ወደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደመ),
					result  => q(ወደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደላ),
					result  => q(ወደላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወደለ),
					result  => q(ወደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዮታ),
					result  => q(ወዮ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዮ),
					result  => q(ወዮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወይንማ),
					result  => q(ወይንማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወይስ),
					result  => q(ወይስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወይም),
					result  => q(ወይም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወያላ),
					result  => q(ወያ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወየው),
					result  => q(ወየ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወየበ),
					result  => q(ወየ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዛደር),
					result  => q(ወዛደ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዛም),
					result  => q(ወዛ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዛ),
					result  => q(ወዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዘፈ),
					result  => q(ወዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዘወዘ),
					result  => q(ወዘወ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዘተ\.),
					result  => q(ወዘ፟ተ\.),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወዘተ),
					result  => q(ወዘ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወካይ),
					result  => q(ወካ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወኪል),
					result  => q(ወኪ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወከፍ),
					result  => q(ወከ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወከለ),
					result  => q(ወከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወንጀለኛ),
					result  => q(ወንጀለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወንድነት),
					result  => q(ወንድነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወንድም),
					result  => q(ወንድም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወንድማማችነት),
					result  => q(ወንድማ፟ማችነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወነጀለ),
					result  => q(ወነጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወነወነ),
					result  => q(ወነወ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወነከረ),
					result  => q(ወነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወነበደ),
					result  => q(ወነበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወትዋታ),
					result  => q(ወትዋ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወታፋ),
					result  => q(ወታ፟ፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወታደርነት),
					result  => q(ወታደ፟ርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወታደር),
					result  => q(ወታደ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወታደራዊ),
					result  => q(ወታ፟ደ፟ራዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወተፍታፋ),
					result  => q(ወተፍታፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወተፈ),
					result  => q(ወተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወተወተ),
					result  => q(ወተወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወቦ),
					result  => q(ወቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወባማ),
					result  => q(ወባማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወበቀ),
					result  => q(ወበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወበራ),
					result  => q(ወበራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወቃ),
					result  => q(ወቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወቀጠ),
					result  => q(ወቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወቀሳ),
					result  => q(ወቀሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወቀሰ),
					result  => q(ወቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወቀረ),
					result  => q(ወቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሽካታ),
					result  => q(ወሽካታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሽመላ),
					result  => q(ወሽመላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሻቃ),
					result  => q(ወሻ፟ቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሸከተ),
					result  => q(ወሸከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሸቀ),
					result  => q(ወሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሸመ),
					result  => q(ወሸ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሸለ),
					result  => q(ወሸ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወስዋሳ),
					result  => q(ወስዋሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወስላታ),
					result  => q(ወስላታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሳፍቻ),
					result  => q(ወሳ፟ፍቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሳኝ),
					result  => q(ወሳ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰድ),
					result  => q(ወሰድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰደው),
					result  => q(ወሰ፟ደው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰደ),
					result  => q(ወሰ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰወሰ),
					result  => q(ወሰወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰንተኛ),
					result  => q(ወሰንተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰን),
					result  => q(ወሰ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰነ),
					result  => q(ወሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰራ),
					result  => q(ወሰራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሰለተ),
					result  => q(ወሰለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሮበላ),
					result  => q(ወሮ፟በላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወርድና),
					result  => q(ወርድና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወርቃማ),
					result  => q(ወርቃማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሬኛ),
					result  => q(ወሬኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወራፊ),
					result  => q(ወራ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወራዳነት),
					result  => q(ወራ፟ዳ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወራዳ),
					result  => q(ወራ፟ዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወራረደ),
					result  => q(ወራረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረፈ),
					result  => q(ወረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረገኑ),
					result  => q(ወረ፟ገኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረደ),
					result  => q(ወረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረዛ),
					result  => q(ወረዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረወረ),
					result  => q(ወረወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረክራካ),
					result  => q(ወረክራካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረተኛ),
					result  => q(ወረተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረቦ),
					result  => q(ወረቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረሰ),
					result  => q(ወረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረርሽኝ),
					result  => q(ወረርሽኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወረረ),
					result  => q(ወረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወመቴ),
					result  => q(ወመ፟ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወሎ),
					result  => q(ወሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወልጋዳ),
					result  => q(ወልጋዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወልካፋ),
					result  => q(ወልካ፟ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወልማማ),
					result  => q(ወልማ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወላድ),
					result  => q(ወላ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወላይትኛ),
					result  => q(ወላይትኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወላይታ),
					result  => q(ወላይታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወላወለ),
					result  => q(ወላወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወላለደ),
					result  => q(ወላለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወላለቀ),
					result  => q(ወላለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለጋ),
					result  => q(ወለ፟ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለገደ),
					result  => q(ወለገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለድ),
					result  => q(ወለ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለደ),
					result  => q(ወለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለወለ),
					result  => q(ወለወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለቀ),
					result  => q(ወለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለም),
					result  => q(ወለም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ወለል),
					result  => q(ወለል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኵርፍተኛ),
					result  => q(ኵር፟ፍተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኵርፈኛ),
					result  => q(ኵርፈኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰናኝ),
					result  => q(ኰና፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰነነ),
					result  => q(ኰነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰስኳሳ),
					result  => q(ኰስኳሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰስታራ),
					result  => q(ኰስታራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰሳሳነት),
					result  => q(ኰሳሳነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰሳሳ),
					result  => q(ኰሳ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰሰኰሰ),
					result  => q(ኰሰኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰሰተረ),
					result  => q(ኰሰተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰሰሰ),
					result  => q(ኰሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰረፌ),
					result  => q(ኰረ፟ፌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰረፈ),
					result  => q(ኰረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰረዳ),
					result  => q(ኰረዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰረኰረ),
					result  => q(ኰረኰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰረኰመ),
					result  => q(ኰረኰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰረታተመ),
					result  => q(ኰረታተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰረተመ),
					result  => q(ኰረተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰመኰመ),
					result  => q(ኰመኰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰልኰሎ),
					result  => q(ኰልኰሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰልታፋ),
					result  => q(ኰልታፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰላ),
					result  => q(ኰላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰለል),
					result  => q(ኰለ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኰለለ),
					result  => q(ኰለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮፈኮፈ),
					result  => q(ኮፈኮ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮዳ),
					result  => q(ኮዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮትቻ),
					result  => q(ኮትቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮቴ),
					result  => q(ኮቴ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮተኮተ),
					result  => q(ኮተኮ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮበለለ),
					result  => q(ኮበለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮሸሽ),
					result  => q(ኮሸሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮስታራ),
					result  => q(ኮስታራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮስማና),
					result  => q(ኮስማና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮሰመነ),
					result  => q(ኮሰመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮርቻ),
					result  => q(ኮርቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮርማታ),
					result  => q(ኮርማታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮራ),
					result  => q(ኮራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮረጠ),
					result  => q(ኮረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮረጀ),
					result  => q(ኮረ፟ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮረብታማ),
					result  => q(ኮረብታማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮረሸመ),
					result  => q(ኮረሸ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኮምፓስ),
					result  => q(ኮምፓስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክፍያ),
					result  => q(ክፍያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክፍት),
					result  => q(ክፍ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክፍ),
					result  => q(ክፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክፋይ),
					result  => q(ክፋ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክፋተኛ),
					result  => q(ክፋተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክፉኛ),
					result  => q(ክፉኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክጀላ),
					result  => q(ክጀ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክውትት),
					result  => q(ክውትት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክው),
					result  => q(ክው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክክ),
					result  => q(ክክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክካም),
					result  => q(ክካ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክንውን),
					result  => q(ክንው፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክችች),
					result  => q(ክች፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክትካች),
					result  => q(ክትካ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክትትል),
					result  => q(ክትት፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክትባት),
					result  => q(ክት፟ባት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክትር),
					result  => q(ክት፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክት),
					result  => q(ክት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክብነት),
					result  => q(ክብ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክብብ),
					result  => q(ክብብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክብርና),
					result  => q(ክብርና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክብልል),
					result  => q(ክብልል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክብ),
					result  => q(ክብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክስ),
					result  => q(ክስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክርፍፍ),
					result  => q(ክርፍፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክርድ),
					result  => q(ክርድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክርክር),
					result  => q(ክርክ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክርክም),
					result  => q(ክርክ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክርስትና),
					result  => q(ክርስትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክር),
					result  => q(ክር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክምችት),
					result  => q(ክምች፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክምቹ),
					result  => q(ክምቹ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክምር),
					result  => q(ክም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክመራ),
					result  => q(ክመ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክልብሽታ),
					result  => q(ክል፟ብሽታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክልብሽ),
					result  => q(ክልብሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክልስ),
					result  => q(ክል፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክልል),
					result  => q(ክል፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ክለሳ),
					result  => q(ክለ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኬላ),
					result  => q(ኬላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካፖርት),
					result  => q(ካፖ፟ርት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካፒታሊዝም),
					result  => q(ካፒ፟ታሊዝም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካፍያ),
					result  => q(ካፍ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካፊያ),
					result  => q(ካፊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካዳሚ),
					result  => q(ካዳ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካደመ),
					result  => q(ካደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካውያ),
					result  => q(ካውያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካካ),
					result  => q(ካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካንዴላ),
					result  => q(ካንዴላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካች),
					result  => q(ካች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካቻምና),
					result  => q(ካቻ፟ምና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካቦ),
					result  => q(ካቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካቤላ),
					result  => q(ካቤላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ካባ),
					result  => q(ካባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኪራየተኛ),
					result  => q(ኪራየተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩፍኝ),
					result  => q(ኩፍ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩፍ),
					result  => q(ኩፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩይሳ),
					result  => q(ኩይ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩብኩባ),
					result  => q(ኩብኩባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩብ),
					result  => q(ኩብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩባያ),
					result  => q(ኩባ፟ያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩርትምትም),
					result  => q(ኩርትምትም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩርትም),
					result  => q(ኩርትም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩርምትምት),
					result  => q(ኩርምትምት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩርምት),
					result  => q(ኩርምት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩራዝ),
					result  => q(ኩራ፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩራተኛ),
					result  => q(ኩራተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩረጃ),
					result  => q(ኩረ፟ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩምትርትር),
					result  => q(ኩምትርትር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩልሽት),
					result  => q(ኩልሽ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኩሊነት),
					result  => q(ኩሊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፍታ),
					result  => q(ከፍ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፍተኛ),
					result  => q(ከፍ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፍራራ),
					result  => q(ከፍራ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፍ),
					result  => q(ከፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፋፈተ),
					result  => q(ከፋፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፋፈለ),
					result  => q(ከፋፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፋኝ),
					result  => q(ከፋ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፋ),
					result  => q(ከፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፈፈ),
					result  => q(ከፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፈከፈ),
					result  => q(ከፈከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፈነ),
					result  => q(ከፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፈተ),
					result  => q(ከፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከፈለ),
					result  => q(ከፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከጀለ),
					result  => q(ከጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከዳተኛ),
					result  => q(ከዳተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከዳ),
					result  => q(ከዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከደነ),
					result  => q(ከደ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከዚያ),
					result  => q(ከዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከዚህም),
					result  => q(ከዚ፟ህም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከዚህ),
					result  => q(ከዚ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከውካዋ),
					result  => q(ከውካዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከውታታ),
					result  => q(ከውታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከካ),
					result  => q(ከካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከንቱነት),
					result  => q(ከንቱነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነፈ),
					result  => q(ከነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነዳ),
					result  => q(ከነዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነከነ),
					result  => q(ከነከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነአካቴው),
					result  => q(ከነ፟አካ፟ቴው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነነ),
					result  => q(ከነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነተረ),
					result  => q(ከነተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነቤተሰቡ),
					result  => q(ከነ፟ቤተሰቡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከነበለ),
					result  => q(ከነበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከች),
					result  => q(ከች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከቻራ),
					result  => q(ከቻራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከቸቸ),
					result  => q(ከቸ፟ቸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከቸረ),
					result  => q(ከቸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከቶውንም),
					result  => q(ከቶ፟ውንም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከቶ),
					result  => q(ከቶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከትቢያ),
					result  => q(ከትቢ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከት),
					result  => q(ከት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተፈ),
					result  => q(ከተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተከተ),
					result  => q(ከተከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተተ),
					result  => q(ከተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተበ),
					result  => q(ከተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተረ),
					result  => q(ከተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተመ),
					result  => q(ከተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተል),
					result  => q(ከተ፟ል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከተለበ),
					result  => q(ከተለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከባድ),
					result  => q(ከባ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከባዳ),
					result  => q(ከባ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከበደ),
					result  => q(ከበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከበተ),
					result  => q(ከበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከበበ),
					result  => q(ከበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከበሰ),
					result  => q(ከበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከበርቴ),
					result  => q(ከበ፟ርቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከበረ),
					result  => q(ከበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሸፈ),
					result  => q(ከሸ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሸነ),
					result  => q(ከሸ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሳይ),
					result  => q(ከሳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሳራ),
					result  => q(ከሳ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሳ),
					result  => q(ከሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሲታ),
					result  => q(ከሲ፟ታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሰከሰ),
					result  => q(ከሰከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሰበ),
					result  => q(ከሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሰሰ),
					result  => q(ከሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሰረ),
					result  => q(ከሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሰመ),
					result  => q(ከሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሰልማ),
					result  => q(ከሰልማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሰለ),
					result  => q(ከሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከርፋፋ),
					result  => q(ከርፋ፟ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከርዳዳ),
					result  => q(ከርዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከርከሮ),
					result  => q(ከርከሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከርታታ),
					result  => q(ከርታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረፋ),
					result  => q(ከረፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረደደ),
					result  => q(ከረደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረከረ),
					result  => q(ከረከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረከመ),
					result  => q(ከረከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረተፈ),
					result  => q(ከረተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረበተ),
					result  => q(ከረበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረረ),
					result  => q(ከረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከረመ),
					result  => q(ከረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሠተበት),
					result  => q(ከሠ፟ተበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሠተለት),
					result  => q(ከሠ፟ተለ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሠተ),
					result  => q(ከሠ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሞላ),
					result  => q(ከሞላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከማሪ),
					result  => q(ከማ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከመከመ),
					result  => q(ከመከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከመቼውም),
					result  => q(ከመቼ፟ውም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከመቼ),
					result  => q(ከመቼ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከመረ),
					result  => q(ከመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከል),
					result  => q(ከል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከላባ),
					result  => q(ከላ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከላሽ),
					result  => q(ከላ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለፍላፋ),
					result  => q(ከለፍላፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለፈ),
					result  => q(ከለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለከለ),
					result  => q(ከለከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለቻ),
					result  => q(ከለ፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለበሰ),
					result  => q(ከለ፟በ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለበ),
					result  => q(ከለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለሰ),
					result  => q(ከለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለላ),
					result  => q(ከለ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከለለ),
					result  => q(ከለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ከሁሉ),
					result  => q(ከሁሉ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፎይታ),
					result  => q(እፎ፟ይታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፎይ),
					result  => q(እፎ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፍግፍግ),
					result  => q(እፍግፍግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፍግ),
					result  => q(እፍ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፍኝ),
					result  => q(እፍ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፍ),
					result  => q(እፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፋፊ),
					result  => q(እፋ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፋሽ),
					result  => q(እፋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፊያ),
					result  => q(እፊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እፉኝት),
					result  => q(እፉኝ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጭድ),
					result  => q(እጭ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጥቤ),
					result  => q(እጥ፟ቤ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እግድ),
					result  => q(እግ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እግረኛ),
					result  => q(እግረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እገዳ),
					result  => q(እገ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እገዛ),
					result  => q(እገ፟ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጅግ),
					result  => q(እጅግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጅጌ),
					result  => q(እጅ፟ጌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጅጉን),
					result  => q(እጅ፟ጉን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጅና),
					result  => q(እጅ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጅብ),
					result  => q(እጅ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጅ),
					result  => q(እጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጄ),
					result  => q(እጄ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጁን),
					result  => q(እጁ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጀታ),
					result  => q(እጀ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እጀ),
					result  => q(እጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እድርተኛ),
					result  => q(እድ፟ርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እድር),
					result  => q(እድ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እድመኛ),
					result  => q(እድመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እድል),
					result  => q(እድ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እድለ),
					result  => q(እድ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እዳሪ),
					result  => q(እዳ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እደሳ),
					result  => q(እደ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እያደር),
					result  => q(እያ፟ደ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እያንዳንዱ),
					result  => q(እያ፟ንዳንዱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እየተጠና),
					result  => q(እየተጠና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እየቅሉ),
					result  => q(እየ፟ቅሉ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እየመጣ),
					result  => q(እየ፟መጣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እዚያ),
					result  => q(እዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እዚህ),
					result  => q(እዚ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እውነትም),
					result  => q(እውነትም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እውነተኛነት),
					result  => q(እውነተኛ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እውነተኛ),
					result  => q(እውነተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እውልኛ),
					result  => q(እውል፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እኮ),
					result  => q(እኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እክል),
					result  => q(እክ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እክላም),
					result  => q(እክ፟ላም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እኩያ),
					result  => q(እኩ፟ያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እኩል),
					result  => q(እኩ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እኩሌታ),
					result  => q(እኩ፟ሌታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እኩለ),
					result  => q(እኩ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እኝኝ),
					result  => q(እኝ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እኛ),
					result  => q(እኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንፍሌ),
					result  => q(እንፍሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጕርጕሮ),
					result  => q(እንጕርጕ፟ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጐቻ),
					result  => q(እንጐቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንግዲያስ),
					result  => q(እንግዲያስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንግዲማ),
					result  => q(እንግዲማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንግልት),
					result  => q(እንግልት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንግሊዘኛ),
					result  => q(እንግሊዘኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጆሪ),
					result  => q(እንጆሪ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጃባቱ),
					result  => q(እንጃባ፟ቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጃልኝ),
					result  => q(እንጃል፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጃልሽ),
					result  => q(እንጃል፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጃልህ),
					result  => q(እንጃል፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንጃለት),
					result  => q(እንጃለ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንዲሁም),
					result  => q(እንዲሁም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንደገና),
					result  => q(እንደገ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንደልብ),
					result  => q(እንደልብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንኮኮ),
					result  => q(እንኮኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንክብካቤ),
					result  => q(እንክብካ፟ቤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንክብል),
					result  => q(እንክብል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንክርት),
					result  => q(እንክር፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንቺ),
					result  => q(እንቺ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንትፍ),
					result  => q(እንትፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንትና),
					result  => q(እንትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንብርክ),
					result  => q(እንብርክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንቆቆ),
					result  => q(እንቆቆ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንቆቅልሽ),
					result  => q(እንቆቅል፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንቅጥቃጤ),
					result  => q(እንቅጥቃ፟ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንቅስቃሴ),
					result  => q(እንቅስ፟ቃ፟ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንቃቅላ),
					result  => q(እንቃቅላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንስትነት),
					result  => q(እንስትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እንስሳነት),
					result  => q(እንስሳነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እናትና),
					result  => q(እና፟ትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እናትነት),
					result  => q(እና፟ትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እናት),
					result  => q(እና፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እና),
					result  => q(እና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እነዚያ),
					result  => q(እነ፟ዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እነኛ),
					result  => q(እነ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እነኋት),
					result  => q(እነ፟ኋት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እነማን),
					result  => q(እነ፟ማን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እነሆ),
					result  => q(እነ፟ሆ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እነ),
					result  => q(እነ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እችግር),
					result  => q(እችግ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እትፍታ),
					result  => q(እት፟ፍታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እትፍ),
					result  => q(እት፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እትዬ),
					result  => q(እትዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እትም),
					result  => q(እት፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እትማማችነት),
					result  => q(እትማ፟ማችነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እትማማች),
					result  => q(እትማ፟ማች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እቴዋ),
					result  => q(እቴዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እብስ),
					result  => q(እብ፟ስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እብሪተኛ),
					result  => q(እብሪተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እባጭ),
					result  => q(እባ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እባክዎን),
					result  => q(እባክ፟ዎን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እባክሽ),
					result  => q(እባክ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እባክህ),
					result  => q(እባክ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እባካችሁ),
					result  => q(እባካ፟ች፟ሁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እቡይ),
					result  => q(እቡ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እበት),
					result  => q(እበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እቅፍ),
					result  => q(እቅ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እቀጭታ),
					result  => q(እቀ፟ጭ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሽግ),
					result  => q(እሽ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሽቅድድም),
					result  => q(እሽቅድድ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሽሩሩ),
					result  => q(እሽ፟ሩሩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሽም),
					result  => q(እሽ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሽ),
					result  => q(እሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሺ),
					result  => q(እሺ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሹሩሩ),
					result  => q(እሹ፟ሩሩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሸትነት),
					result  => q(እሸትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እስፓንኛ),
					result  => q(እስፓንኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እስከዚያ),
					result  => q(እስከዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እስከዚህ),
					result  => q(እስከዚ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እስከናካቴው),
					result  => q(እስከና፟ካ፟ቴው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እስከነ),
					result  => q(እስከነ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እስልምና),
					result  => q(እስልምና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሳቸው),
					result  => q(እሳ፟ቸ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሳትና),
					result  => q(እሳትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሳት),
					result  => q(እሳ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሳ),
					result  => q(እሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሰይ),
					result  => q(እሰ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሮምታ),
					result  => q(እሮ፟ምታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እርግፍ),
					result  => q(እርግፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እርግጠኛ),
					result  => q(እርግጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እርግዝና),
					result  => q(እርግዝና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እርጅና),
					result  => q(እርጅና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እርይ),
					result  => q(እር፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እርምጃ),
					result  => q(እርምጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እርማት),
					result  => q(እር፟ማት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እራሽ),
					result  => q(እራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እራሪ),
					result  => q(እራ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እረኝነት),
					result  => q(እረ፟ኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እረኛ),
					result  => q(እረ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሥር),
					result  => q(እሥ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሥራት),
					result  => q(እሥ፟ራት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሥረኛ),
					result  => q(እሥረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እምዬ),
					result  => q(እም፟ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እምቦሳ),
					result  => q(እምቦሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እምብዛም),
					result  => q(እምብዛም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እምቢተኛ),
					result  => q(እምቢተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እምቢልተኛ),
					result  => q(እምቢልተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እምስ),
					result  => q(እም፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እምር),
					result  => q(እም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እሜቴ),
					result  => q(እሜ፟ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እማሆይ),
					result  => q(እማ፟ሆይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እመጫት),
					result  => q(እመ፟ጫት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እመት),
					result  => q(እመ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እመቤት),
					result  => q(እመ፟ቤት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እመቤታችን),
					result  => q(እመ፟ቤታች፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እመር),
					result  => q(እመ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እመምተኛ),
					result  => q(እመምተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እመ),
					result  => q(እመ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልፍኝ),
					result  => q(እልፍኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልፊት),
					result  => q(እልፊት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልክ),
					result  => q(እል፟ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልከኛ),
					result  => q(እል፟ከኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልባት),
					result  => q(እል፟ባት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልቅና),
					result  => q(እልቅና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልቅት),
					result  => q(እል፟ቅት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልቅ),
					result  => q(እልቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልቂት),
					result  => q(እልቂት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እልም),
					result  => q(እል፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(እላቂ),
					result  => q(እላ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኤክዌተር),
					result  => q(ኤክ፟ዌተር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢጣልያኛ),
					result  => q(ኢጣልያኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢዮቤልዩ),
					result  => q(ኢዮ፟ቤልዩ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢየሱስ),
					result  => q(ኢየ፟ሱስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢየሱሳዊ),
					result  => q(ኢየ፟ሱሳዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢየሩሳሌም),
					result  => q(ኢየ፟ሩሳሌም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢትዮጵያዊት),
					result  => q(ኢትዮጵ፟ያዊት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢትዮጲያዊ),
					result  => q(ኢትዮጲ፟ያዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኢትዮጲያ),
					result  => q(ኢትዮጲ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፓርትማ),
					result  => q(አፓ፟ርትማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፎካከረ),
					result  => q(አፎ፟ካከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፍኖ),
					result  => q(አፍ፟ኖ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፍንጫማ),
					result  => q(አፍንጫማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፍታታ),
					result  => q(አፍታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፍለኛ),
					result  => q(አፍለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፍለቀለቀ),
					result  => q(አፍለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋፋመ),
					result  => q(አፋ፟ፋመ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋጨ),
					result  => q(አፋ፟ጨ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋጣኝ),
					result  => q(አፋ፟ጣኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋጠጠ),
					result  => q(አፋ፟ጠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋጠነ),
					result  => q(አፋ፟ጠ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋጀ),
					result  => q(አፋ፟ጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋደሰ),
					result  => q(አፋደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋዘዘ),
					result  => q(አፋ፟ዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋኝ),
					result  => q(አፋ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋታ),
					result  => q(አፋ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋተገ),
					result  => q(አፋ፟ተ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋተለ),
					result  => q(አፋ፟ተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋቀረ),
					result  => q(አፋ፟ቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋሸገ),
					result  => q(አፋሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋሰሰ),
					result  => q(አፋ፟ሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋር),
					result  => q(አፋ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋራም),
					result  => q(አፋ፟ራም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋረደ),
					result  => q(አፋ፟ረደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋለገ),
					result  => q(አፋ፟ለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋለሰ),
					result  => q(አፋ፟ለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፋለመ),
					result  => q(አፋ፟ለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈፍ),
					result  => q(አፈፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈፈ),
					result  => q(አፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈገፈገ),
					result  => q(አፈገፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈገመ),
					result  => q(አፈገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈገ),
					result  => q(አፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈዘዘ),
					result  => q(አፈዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈካ),
					result  => q(አፈካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈከፈ),
					result  => q(አፈከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈኛ),
					result  => q(አፈኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈናጠጠ),
					result  => q(አፈ፟ናጠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈናጠረ),
					result  => q(አፈ፟ናጠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈናቀለ),
					result  => q(አፈ፟ናቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈነፈነ),
					result  => q(አፈነፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈነገጠ),
					result  => q(አፈነገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈነዳ),
					result  => q(አፈነዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈነደደ),
					result  => q(አፈነደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈነ),
					result  => q(አፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈታተነ),
					result  => q(አፈ፟ታተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈታበት),
					result  => q(አፈታ፟በ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈተለከ),
					result  => q(አፈተለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈቀረ),
					result  => q(አፈ፟ቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈሰሰ),
					result  => q(አፈ፟ሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈሰ),
					result  => q(አፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈራረሰ),
					result  => q(አፈራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈራ),
					result  => q(አፈራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈረጠው),
					result  => q(አፈረ፟ጠው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈረጠ),
					result  => q(አፈረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈረ),
					result  => q(አፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈላ),
					result  => q(አፈላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈለቀ),
					result  => q(አፈለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አፈለሰ),
					result  => q(አፈለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጽናና),
					result  => q(አጽናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጸዳ),
					result  => q(አጸዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጸደቀ),
					result  => q(አጸደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጸያፊ),
					result  => q(አጸ፟ያ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጸየፈ),
					result  => q(አጸ፟የ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጸና),
					result  => q(አጸና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጸለየ),
					result  => q(አጸ፟ለ፟የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጭበረበረ),
					result  => q(አጭበረበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጫወተ),
					result  => q(አጫ፟ወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጫረተ),
					result  => q(አጫ፟ረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጫረሰ),
					result  => q(አጫ፟ረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨናገፈ),
					result  => q(አጨ፟ናገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨነጎለ),
					result  => q(አጨ፟ነጎ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨነቆረ),
					result  => q(አጨነቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨባበጠ),
					result  => q(አጨ፟ባበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨቀየ),
					result  => q(አጨቀየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨራመደ),
					result  => q(አጨ፟ራመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨራመመ),
					result  => q(አጨ፟ራመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨማደደ),
					result  => q(አጨ፟ማደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨማተረ),
					result  => q(አጨ፟ማተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨማለቀ),
					result  => q(አጨ፟ማለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨለገ),
					result  => q(አጨለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጨለመ),
					result  => q(አጨለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥፊና),
					result  => q(አጥፊና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥወለወለ),
					result  => q(አጥወለወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥናና),
					result  => q(አጥናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥበረበረ),
					result  => q(አጥበረበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥመዘመዘ),
					result  => q(አጥመዘመ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥመለመለ),
					result  => q(አጥመለመ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥላላ),
					result  => q(አጥላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጥለቀለቀ),
					result  => q(አጥለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣፋ),
					result  => q(አጣ፟ፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣፈጠ),
					result  => q(አጣፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣፈረ),
					result  => q(አጣ፟ፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣገበ),
					result  => q(አጣ፟ገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣደፈ),
					result  => q(አጣ፟ደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣየቀ),
					result  => q(አጣ፟የ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣብቂኝ),
					result  => q(አጣ፟ብቂኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣበበ),
					result  => q(አጣ፟በ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣበቀ),
					result  => q(አጣ፟በ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣቀሰ),
					result  => q(አጣ፟ቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣራ),
					result  => q(አጣ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣመደ),
					result  => q(አጣመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣመረ),
					result  => q(አጣመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣመመ),
					result  => q(አጣመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጣላ),
					result  => q(አጣ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠፋ),
					result  => q(አጠፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠፈፈ),
					result  => q(አጠፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠጋጋ),
					result  => q(አጠ፟ጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠገበ),
					result  => q(አጠገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠያየፈ),
					result  => q(አጠ፟ያየ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠየቀ),
					result  => q(አጠየ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠናጋ),
					result  => q(አጠናጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠናከረ),
					result  => q(አጠ፟ናከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠናቀቀ),
					result  => q(አጠ፟ናቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠናቀረ),
					result  => q(አጠ፟ናቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠና),
					result  => q(አጠና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠነፈፈ),
					result  => q(አጠነፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠነከረ),
					result  => q(አጠነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠነነ),
					result  => q(አጠነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠነባ),
					result  => q(አጠነባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠባ),
					result  => q(አጠባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠበበ),
					result  => q(አጠበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠበቀ),
					result  => q(አጠበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠቆረ),
					result  => q(አጠቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠቃለለ),
					result  => q(አጠ፟ቃለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠቃ),
					result  => q(አጠቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠቀሰ),
					result  => q(አጠቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠራቀመ),
					result  => q(አጠ፟ራቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠራ),
					result  => q(አጠራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠረኝ),
					result  => q(አጠ፟ረኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠረሰ),
					result  => q(አጠረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠማ),
					result  => q(አጠማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠመቀ),
					result  => q(አጠመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠለቀው),
					result  => q(አጠለ፟ቀው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠለቀ),
					result  => q(አጠለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጠለለ),
					result  => q(አጠለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጕተመተመ),
					result  => q(አጕተመተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጕረጠረጠ),
					result  => q(አጕረጠረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጕረመረመ),
					result  => q(አጕረመረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጕመተመተ),
					result  => q(አጕመተመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጓጓዘ),
					result  => q(አጓ፟ጓዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጓጐለ),
					result  => q(አጓጐ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጓደደ),
					result  => q(አጓ፟ደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጓት),
					result  => q(አጓ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጓራ),
					result  => q(አጓራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጓመጠ),
					result  => q(አጓመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐደጐደ),
					result  => q(አጐደጐ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐነበሰ),
					result  => q(አጐነበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐነቈለ),
					result  => q(አጐነቈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐተነ),
					result  => q(አጐተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐበጠ),
					result  => q(አጐበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐበጐበ),
					result  => q(አጐበጐ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐበደደ),
					result  => q(አጐበደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐሳቈለ),
					result  => q(አጐሳቈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐራ),
					result  => q(አጐራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐረና),
					result  => q(አጐረና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐረ),
					result  => q(አጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጐላ),
					result  => q(አጐላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎፈረ),
					result  => q(አጎፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎደለ),
					result  => q(አጎደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎናጠፈ),
					result  => q(አጎ፟ናጠ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎት),
					result  => q(አጎ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎራበተ),
					result  => q(አጎ፟ራበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎረሰ),
					result  => q(አጎረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎመዘዘ),
					result  => q(አጎመዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎላማሽ),
					result  => q(አጎ፟ላማሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጎላመሰ),
					result  => q(አጎላመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አግፈለፈለ),
					result  => q(አግፈለፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አግጣጫ),
					result  => q(አግጣጫ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አግዶኝ),
					result  => q(አግዶ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አግተለተለ),
					result  => q(አግተለተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አግበሰበሰ),
					result  => q(አግበሰበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋፋሪ),
					result  => q(አጋ፟ፋሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋፈጠ),
					result  => q(አጋ፟ፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋፈረ),
					result  => q(አጋ፟ፈረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋጨ),
					result  => q(አጋ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋጣሚ),
					result  => q(አጋ፟ጣሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋጠመ),
					result  => q(አጋ፟ጠ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋጋመ),
					result  => q(አጋ፟ጋመ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋጋለ),
					result  => q(አጋ፟ጋለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋጅ),
					result  => q(አጋ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋደደ),
					result  => q(አጋ፟ደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋደመ),
					result  => q(አጋ፟ደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋደለ),
					result  => q(አጋደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋየ),
					result  => q(አጋየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋዥ),
					result  => q(አጋ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋዛ),
					result  => q(አጋ፟ዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋኖ),
					result  => q(አጋ፟ኖ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋነነ),
					result  => q(አጋ፟ነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋተረ),
					result  => q(አጋ፟ተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋባ),
					result  => q(አጋ፟ባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋበሰ),
					result  => q(አጋበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋሰስ),
					result  => q(አጋሰ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋሰሰ),
					result  => q(አጋሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋር),
					result  => q(አጋ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋራ),
					result  => q(አጋ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋሪ),
					result  => q(አጋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋማሽ),
					result  => q(አጋ፟ማሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋሚ),
					result  => q(አጋ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋመሰ),
					result  => q(አጋ፟መ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጋለጠ),
					result  => q(አጋ፟ለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገጫጨ),
					result  => q(አገ፟ጫጨ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገጋሚ),
					result  => q(አገጋ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገገመ),
					result  => q(አገገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገድ),
					result  => q(አገ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገደፈ),
					result  => q(አገደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገደመ),
					result  => q(አገደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገደ),
					result  => q(አገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገዝ),
					result  => q(አገ፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገዘ),
					result  => q(አገ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገኘ),
					result  => q(አገኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገናዛቢ),
					result  => q(አገ፟ናዛቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገናዘበ),
					result  => q(አገ፟ናዘበ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገናኝ),
					result  => q(አገ፟ናኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገናኘ),
					result  => q(አገናኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገነፋ),
					result  => q(አገነፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገተ),
					result  => q(አገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገባደደ),
					result  => q(አገ፟ባደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገባት),
					result  => q(አገባ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገባብ),
					result  => q(አገ፟ባብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገባ),
					result  => q(አገባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገሸሸ),
					result  => q(አገሸ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገረሸበት),
					result  => q(አገረሸ፟በ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገረሸ),
					result  => q(አገረሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገሣ),
					result  => q(አገሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገማ),
					result  => q(አገማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገመ),
					result  => q(አገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገላበጠ),
					result  => q(አገ፟ላበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገለገለ),
					result  => q(አገለ፟ገለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገለደመ),
					result  => q(አገለደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገለሞተ),
					result  => q(አገለሞ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አገለለ),
					result  => q(አገለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጅሬ),
					result  => q(አጅ፟ሬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጃገነ),
					result  => q(አጃ፟ገነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጃጃለ),
					result  => q(አጃ፟ጃለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጃቢ),
					result  => q(አጃ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጃ),
					result  => q(አጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጀበ),
					result  => q(አጀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አጀለ),
					result  => q(አጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዶለዶመ),
					result  => q(አዶለዶ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዶ),
					result  => q(አዶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድፋፋ),
					result  => q(አድፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድፈነፈነ),
					result  => q(አድፈነፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድቦለቦለ),
					result  => q(አድቦለቦ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድበሰበሰ),
					result  => q(አድበሰበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድበለበለ),
					result  => q(አድበለበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድራሻ),
					result  => q(አድራሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድረገ),
					result  => q(አድረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድመኛ),
					result  => q(አድመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አድሎኛ),
					result  => q(አድሎኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳፍኔ),
					result  => q(አዳ፟ፍኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳፋ),
					result  => q(አዳ፟ፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳፈነ),
					result  => q(አዳፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳገተ),
					result  => q(አዳገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳደሰ),
					result  => q(አዳደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳደለ),
					result  => q(አዳደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳይ),
					result  => q(አዳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳወረ),
					result  => q(አዳወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳከመ),
					result  => q(አዳ፟ከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳኝ),
					result  => q(አዳ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳነቀ),
					result  => q(አዳነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳባይ),
					result  => q(አዳ፟ባይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳበረ),
					result  => q(አዳበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳበለ),
					result  => q(አዳ፟በ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳቀቀ),
					result  => q(አዳ፟ቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳቀለ),
					result  => q(አዳ፟ቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳሽ),
					result  => q(አዳ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳራሽ),
					result  => q(አዳ፟ራሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳረሰ),
					result  => q(አዳ፟ረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳምና),
					result  => q(አዳ፟ምና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳም),
					result  => q(አዳ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳማቂ),
					result  => q(አዳ፟ማ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳሚ),
					result  => q(አዳ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳመጠ),
					result  => q(አዳ፟መ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳመቀ),
					result  => q(አዳ፟መ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳመረ),
					result  => q(አዳ፟መ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳላ),
					result  => q(አዳ፟ላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዳለጠ),
					result  => q(አዳለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዲስ),
					result  => q(አዲ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዱኛ),
					result  => q(አዱ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደፋፈረ),
					result  => q(አደ፟ፋፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደፈጠ),
					result  => q(አደፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደፈረሰ),
					result  => q(አደ፟ፈረሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደፈ),
					result  => q(አደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደግ),
					result  => q(አደ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደገደ),
					result  => q(አደገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደገኛ),
					result  => q(አደገኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደገ),
					result  => q(አደ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደደበ),
					result  => q(አደደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደዘደዘ),
					result  => q(አደዘደ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደኸየ),
					result  => q(አደኸየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደከመ),
					result  => q(አደከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደንጓሬ),
					result  => q(አደንጓሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደን),
					result  => q(አደ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደናጋሪ),
					result  => q(አደ፟ናጋሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደናገጠ),
					result  => q(አደ፟ናገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደናገረ),
					result  => q(አደ፟ናገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደናባሪ),
					result  => q(አደ፟ናባሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደናበረ),
					result  => q(አደ፟ናበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደናቀፈ),
					result  => q(አደ፟ናቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደነጋገረ),
					result  => q(አደ፟ነጋገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደነዘዘ),
					result  => q(አደነዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደነዘ),
					result  => q(አደነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደነቆረ),
					result  => q(አደነቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደነቀ),
					result  => q(አደነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደነ),
					result  => q(አደ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደብ),
					result  => q(አደ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደባየ),
					result  => q(አደባየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደባባይ),
					result  => q(አደ፟ባባይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደባለቀ),
					result  => q(አደባለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደባ),
					result  => q(አደ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደበዘዘ),
					result  => q(አደበዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደበነ),
					result  => q(አደበ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደበ),
					result  => q(አደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደቀቀ),
					result  => q(አደቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደሸደሸ),
					result  => q(አደሸደ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደሰ),
					result  => q(አደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደርክ),
					result  => q(አደ፟ርክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደር),
					result  => q(አደ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደራጅ),
					result  => q(አደ፟ራጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደራጀ),
					result  => q(አደራጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደራደረ),
					result  => q(አደ፟ራደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደራረግ),
					result  => q(አደ፟ራረግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደራ),
					result  => q(አደራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደረገው),
					result  => q(አደረ፟ገው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደረገ),
					result  => q(አደ፟ረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደረሰ),
					result  => q(አደረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደረ),
					result  => q(አደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደማ),
					result  => q(አደማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደመጠ),
					result  => q(አደመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደመቀ),
					result  => q(አደመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደመ),
					result  => q(አደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደላዳይ),
					result  => q(አደ፟ላዳይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደላደለ),
					result  => q(አደ፟ላደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደላ),
					result  => q(አደላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደለበ),
					result  => q(አደለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አደለ),
					result  => q(አደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አይጥማ),
					result  => q(አይጥማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አይገባኝም),
					result  => q(አይገባኝ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አይደለም),
					result  => q(አይደለ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አይቀርም),
					result  => q(አይቀርም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አይልም),
					result  => q(አይልም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አያያዝ),
					result  => q(አያ፟ያዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አያያዘ),
					result  => q(አያ፟ያዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አያያ),
					result  => q(አያ፟ያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አያሌ),
					result  => q(አያ፟ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አያ),
					result  => q(አያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አየው),
					result  => q(አየ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አየር),
					result  => q(አየ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አየለ),
					result  => q(አየ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አየ),
					result  => q(አየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዥጐረጐረ),
					result  => q(አዥጐረጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዥጎደጎደ),
					result  => q(አዥጎደጎ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዥጎረጎረ),
					result  => q(አዥጎረጎ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዠለጠ),
					result  => q(አዠ፟ለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዠ),
					result  => q(አዠ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዞ),
					result  => q(አዞ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝጎረጎረ),
					result  => q(አዝጎረጎረ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝናና),
					result  => q(አዝናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝረፈረፈ),
					result  => q(አዝረፈረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝረጠረጠ),
					result  => q(አዝረጠረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝረከረከ),
					result  => q(አዝረከረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝረበረበ),
					result  => q(አዝረበ፟ረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝማሚያ),
					result  => q(አዝማሚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዝለገለገ),
					result  => q(አዝለገለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛፈነ),
					result  => q(አዛ፟ፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛጋ),
					result  => q(አዛ፟ጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛዥ),
					result  => q(አዛ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛዘነ),
					result  => q(አዛዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛወረ),
					result  => q(አዛ፟ወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛነፈ),
					result  => q(አዛ፟ነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛባ),
					result  => q(አዛ፟ባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛቀ),
					result  => q(አዛ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛማጅ),
					result  => q(አዛ፟ማጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛማች),
					result  => q(አዛ፟ማች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛመደ),
					result  => q(አዛ፟መ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛመተ),
					result  => q(አዛ፟መ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዛለቀ),
					result  => q(አዛ፟ለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘፈነ),
					result  => q(አዘ፟ፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘፈቀ),
					result  => q(አዘፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘጠዘጠ),
					result  => q(አዘጠዘ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘጋገመ),
					result  => q(አዘጋገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘጋጀ),
					result  => q(አዘ፟ጋጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘጋ),
					result  => q(አዘ፟ጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘገጀ),
					result  => q(አዘ፟ገጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘገየ),
					result  => q(አዘገየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘገነ),
					result  => q(አዘ፟ገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘገመ),
					result  => q(አዘገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘዘ),
					result  => q(አዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘወተረ),
					result  => q(አዘወተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘወረ),
					result  => q(አዘ፟ወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘከዘከ),
					result  => q(አዘ፟ከዘ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘከረ),
					result  => q(አዘከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘንተኛ),
					result  => q(አዘንተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘናጋ),
					result  => q(አዘ፟ናጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘናከተ),
					result  => q(አዘ፟ናከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘነጠለ),
					result  => q(አዘ፟ነጠ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘነጋ),
					result  => q(አዘነጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘነበለ),
					result  => q(አዘነበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘነበ),
					result  => q(አዘነ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘነ),
					result  => q(አዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘባነነ),
					result  => q(አዘ፟ባነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘባረቀ),
					result  => q(አዘ፟ባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘበራረቀ),
					result  => q(አዘ፟በራረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘቀጠ),
					result  => q(አዘቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘቀዘቀ),
					result  => q(አዘቀዘ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘራ),
					result  => q(አዘ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘረፈ),
					result  => q(አዘ፟ረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘረጠጠ),
					result  => q(አዘ፟ረጠጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘረጠ),
					result  => q(አዘረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘረጋጋ),
					result  => q(አዘ፟ረጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘረጋ),
					result  => q(አዘ፟ረጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘረገፈ),
					result  => q(አዘ፟ረገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘረዘረ),
					result  => q(አዘ፟ረዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘመተ),
					result  => q(አዘመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘመረ),
					result  => q(አዘመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘመመ),
					result  => q(አዘመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘለፈ),
					result  => q(አዘ፟ለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘለቀ),
					result  => q(አዘለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘለለ),
					result  => q(አዘ፟ለለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዘለ),
					result  => q(አዘ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውጫጭኝ),
					result  => q(አውጫጭ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውድማ),
					result  => q(አውድማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውደለደለ),
					result  => q(አውደለደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውታታ),
					result  => q(አውታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውተፈተፈ),
					result  => q(አውተፈተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውተረተረ),
					result  => q(አውተረተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውሮፕላን),
					result  => q(አውሮፕ፟ላን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውሮፓ),
					result  => q(አውሮፓ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውሬነት),
					result  => q(አውሬነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውራጃ),
					result  => q(አውራ፟ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውላላ),
					result  => q(አውላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አውለበለበ),
					result  => q(አውለበለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋጪ),
					result  => q(አዋ፟ጪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋጣ),
					result  => q(አዋ፟ጣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋጠረ),
					result  => q(አዋ፟ጠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋጋ),
					result  => q(አዋ፟ጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋጊ),
					result  => q(አዋ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋደደ),
					result  => q(አዋ፟ደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋየ),
					result  => q(አዋ፟የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋዛ),
					result  => q(አዋ፟ዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋዋይ),
					result  => q(አዋ፟ዋይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋዋለ),
					result  => q(አዋ፟ዋለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋኪ),
					result  => q(አዋ፟ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋቃ),
					result  => q(አዋ፟ቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋቀጠ),
					result  => q(አዋ፟ቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋሸከ),
					result  => q(አዋ፟ሸ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋሳኝ),
					result  => q(አዋ፟ሳኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋሰደ),
					result  => q(አዋ፟ሰ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋሰነ),
					result  => q(አዋ፟ሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋራ),
					result  => q(አዋ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋረደ),
					result  => q(አዋ፟ረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋሐደ),
					result  => q(አዋ፟ሐደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋልደጌሻ),
					result  => q(አዋልደጌሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋላጅ),
					result  => q(አዋ፟ላጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አዋለደ),
					result  => q(አዋ፟ለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወፈረ),
					result  => q(አወፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወጣጣ),
					result  => q(አወ፟ጣጣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወጣ),
					result  => q(አወጣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወጋ),
					result  => q(አወጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወዳዳሪ),
					result  => q(አወ፟ዳዳሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወዳደረ),
					result  => q(አወ፟ዳደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወደሰ),
					result  => q(አወደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወደመ),
					result  => q(አወደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወደለ),
					result  => q(አወደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወዛወዘ),
					result  => q(አወ፟ዛወ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወካ),
					result  => q(አወካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወከ),
					result  => q(አወ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወናፈለ),
					result  => q(አወ፟ናፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወናከረ),
					result  => q(አወ፟ናከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወናባጅ),
					result  => q(አወ፟ናባ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወናበደ),
					result  => q(አወ፟ናበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወበቀ),
					result  => q(አወበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወሳ),
					result  => q(አወሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወሰለተ),
					result  => q(አወሰለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወራጨ),
					result  => q(አወ፟ራጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወራረደ),
					result  => q(አወራረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወራረሰ),
					result  => q(አወራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወራ),
					result  => q(አወራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወረደ),
					result  => q(አወረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወረዛ),
					result  => q(አወረዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወረሰ),
					result  => q(አወረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወላገደ),
					result  => q(አወ፟ላገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወላወለ),
					result  => q(አወ፟ላወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወላካፊ),
					result  => q(አወ፟ላካፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወላከፈ),
					result  => q(አወ፟ላከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወላመመ),
					result  => q(አወ፟ላመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወላለቀ),
					result  => q(አወላለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወለጋገደ),
					result  => q(አወ፟ለጋገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወለወለ),
					result  => q(አወለወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አወለቀ),
					result  => q(አወለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኳሰሰ),
					result  => q(አኳሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኳሁዋን),
					result  => q(አኳ፟ሁዋን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኰቴት),
					result  => q(አኰ፟ቴት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኰበኰበ),
					result  => q(አኰበኰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኰሰሰ),
					result  => q(አኰሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኰረተ),
					result  => q(አኰረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮበለለ),
					result  => q(አኮበለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮሰመነ),
					result  => q(አኮሰመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮራመተ),
					result  => q(አኮ፟ራመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮራ),
					result  => q(አኮራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮረፈ),
					result  => q(አኮረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮማተረ),
					result  => q(አኮ፟ማተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮመታተረ),
					result  => q(አኮ፟መታተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኮላሸ),
					result  => q(አኮ፟ላሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አክታ),
					result  => q(አክ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አክለፈለፈ),
					result  => q(አክለፈለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አክ),
					result  => q(አክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካፋይ),
					result  => q(አካ፟ፋይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካፋ),
					result  => q(አካፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካፈለ),
					result  => q(አካ፟ፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካደነ),
					result  => q(አካ፟ደ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካካሰ),
					result  => q(አካ፟ካሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካከከ),
					result  => q(አካከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካቴ),
					result  => q(አካ፟ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካተተ),
					result  => q(አካ፟ተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካባቢ),
					result  => q(አካ፟ባቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካበተ),
					result  => q(አካበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካበበ),
					result  => q(አካ፟በ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካሰሰ),
					result  => q(አካ፟ሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካሚ),
					result  => q(አካ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካመረ),
					result  => q(አካ፟መ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካለሰ),
					result  => q(አካ፟ለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አካለለ),
					result  => q(አካ፟ለለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከፋፋይ),
					result  => q(አከ፟ፋፋይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከፋፈለ),
					result  => q(አከ፟ፋፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከፋ),
					result  => q(አከፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከፈለ),
					result  => q(አከፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከድዬ),
					result  => q(አከ፟ድዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከከ),
					result  => q(አከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከናወነ),
					result  => q(አከ፟ናወ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከናወ),
					result  => q(አከ፟ና፟ወ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከናነበ),
					result  => q(አከ፟ናነ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከነፈ),
					result  => q(አከነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከነነ),
					result  => q(አከነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከታተለ),
					result  => q(አከ፟ታተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከተመ),
					result  => q(አከተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከተ),
					result  => q(አከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከባበር),
					result  => q(አከ፟ባበር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከባበረ),
					result  => q(አከባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከበደ),
					result  => q(አከበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከበረ),
					result  => q(አከበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከሳ),
					result  => q(አከሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከሰከሰ),
					result  => q(አከሰከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከሰረ),
					result  => q(አከሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከሰመ),
					result  => q(አከሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከሰለ),
					result  => q(አከሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከራየ),
					result  => q(አከ፟ራየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከራካሪ),
					result  => q(አከ፟ራካሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከረፋ),
					result  => q(አከረፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከረረ),
					result  => q(አከረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከረመ),
					result  => q(አከረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከማቸ),
					result  => q(አከ፟ማቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከመቻቸ),
					result  => q(አከመቻቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከመ),
					result  => q(አከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከል),
					result  => q(አከ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከላከለ),
					result  => q(አከ፟ላከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አከለ),
					result  => q(አከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኢሉባቦር),
					result  => q(አኢሉባ፟ቦር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አኘከ),
					result  => q(አኘ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንፏቃቂ),
					result  => q(አንፏቃ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንፏቀቀ),
					result  => q(አንፏቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንፈቀፈቀ),
					result  => q(አንፈቀፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንፈራፈረ),
					result  => q(አንፈራፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንፈራገጠ),
					result  => q(አንፈራገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጸባረቀ),
					result  => q(አንጸባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጨረፈፈ),
					result  => q(አንጨረፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጥረኛ),
					result  => q(አንጥረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጠራወዘ),
					result  => q(አንጠራወ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጠራራኝ),
					result  => q(አንጠራራኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጠራራ),
					result  => q(አንጠራ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጕራጐረ),
					result  => q(አንጕራጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጓለለ),
					result  => q(አንጓለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጐደጐደ),
					result  => q(አንጐደጐ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጐራጐረ),
					result  => q(አንጐራጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጐራደደ),
					result  => q(አንጐራደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንግዋለለ),
					result  => q(አንግዋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጋፋ),
					result  => q(አንጋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጋጋ),
					result  => q(አንጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጋደደ),
					result  => q(አንጋደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጋሬ),
					result  => q(አንጋሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጋለለ),
					result  => q(አንጋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገፈገፈ),
					result  => q(አንገፈገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገጫገጨ),
					result  => q(አንገጫገ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገዳገደ),
					result  => q(አንገዳገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገደገደ),
					result  => q(አንገደገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገዋለለ),
					result  => q(አንገዋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገበገበ),
					result  => q(አንገበገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገሸገሸ),
					result  => q(አንገሸገ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገራገረ),
					result  => q(አንገራገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገረገበ),
					result  => q(አንገረገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንገላታ),
					result  => q(አንገላታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጀተ),
					result  => q(አንጀ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንጀረገገ),
					result  => q(አንጀረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንድነት),
					result  => q(አንድነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንድም),
					result  => q(አንድም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዳች),
					result  => q(አንዳች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንደፋደፈ),
					result  => q(አንደፋደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንደኛ),
					result  => q(አንደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንደባለለ),
					result  => q(አንደባለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንደበደበ),
					result  => q(አንደበደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንደቀደቀ),
					result  => q(አንደቀደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንደረበበ),
					result  => q(አንደረበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንደላቀቀ),
					result  => q(አንደላቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዣባቢ),
					result  => q(አንዣባ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዣበበ),
					result  => q(አንዣበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዠቀዠቀ),
					result  => q(አንዠቀዠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዠቀዘቀ),
					result  => q(አንዠቀዘ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዛዛ),
					result  => q(አንዛዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዛረጠ),
					result  => q(አንዛረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዘፈዘፈ),
					result  => q(አንዘፈዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዘረፈፈ),
					result  => q(አንዘረፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዘረፈጠ),
					result  => q(አንዘረፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንዘላዘለ),
					result  => q(አንዘላዘ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንኳኳ),
					result  => q(አንኳኳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንኳሰሰ),
					result  => q(አንኳሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንካሴ),
					result  => q(አንካሴ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንካሳ),
					result  => q(አንካሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንካላ),
					result  => q(አንካላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከፈረረ),
					result  => q(አንከፈረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከታከተ),
					result  => q(አንከታከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከተከተ),
					result  => q(አንከተከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከባከበ),
					result  => q(አንከባከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከባለለ),
					result  => q(አንከባለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከበከበ),
					result  => q(አንከበከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከራተተ),
					result  => q(አንከራተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንከረፈፈ),
					result  => q(አንከረፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቺዬ),
					result  => q(አንቺዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንተገተገ),
					result  => q(አንተገተ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንተከተከ),
					result  => q(አንተከተ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንተረከከ),
					result  => q(አንተረከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንተላከሰ),
					result  => q(አንተላከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቦጫቦጨ),
					result  => q(አንቦጫ፟ቦ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቦጨቦጨ),
					result  => q(አንቦጨ፟ቦ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቦገቦገ),
					result  => q(አንቦገቦ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቦራቀቀ),
					result  => q(አንቦራቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንበሸበሸ),
					result  => q(አንበሸበ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንበሳ),
					result  => q(አንበሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንበረከከ),
					result  => q(አንበረከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንበለበለ),
					result  => q(አንበለበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቋሸሸ),
					result  => q(አንቋሸ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቆረቆረ),
					result  => q(አንቆረቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቃረረ),
					result  => q(አንቃረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀጠቀጠ),
					result  => q(አንቀጠቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀዋለለ),
					result  => q(አንቀዋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀባረረ),
					result  => q(አንቀባረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀሳቀሰ),
					result  => q(አንቀሳቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀሰቀሰ),
					result  => q(አንቀሰቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀረፈፈ),
					result  => q(አንቀረፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀረበበ),
					result  => q(አንቀረበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀላፋ),
					result  => q(አንቀላፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንቀለቀለ),
					result  => q(አንቀለቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሿካኪ),
					result  => q(አንሿካ፟ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሿከከ),
					result  => q(አንሿከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሾካሾከ),
					result  => q(አንሾካሾከ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሻፈፈ),
					result  => q(አንሻፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሻተተ),
					result  => q(አንሻተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሸዋረረ),
					result  => q(አንሸዋረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሸረሸረ),
					result  => q(አንሸረሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አንሰፈሰፈ),
					result  => q(አንሰፈሰ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናፋ),
					result  => q(አናፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናፈሰ),
					result  => q(አና፟ፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጢነት),
					result  => q(አናጢነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጠፈ),
					result  => q(አና፟ጠፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጠበ),
					result  => q(አና፟ጠ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጠቀ),
					result  => q(አና፟ጠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጋሽ),
					result  => q(አና፟ጋሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጋሪ),
					result  => q(አና፟ጋሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጋ),
					result  => q(አና፟ጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናጊ),
					result  => q(አና፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናገረ),
					result  => q(አና፟ገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናገሠ),
					result  => q(አና፟ገ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናዳጅ),
					result  => q(አና፟ዳጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናዳ),
					result  => q(አና፟ዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናደፈ),
					result  => q(አና፟ደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናደደ),
					result  => q(አና፟ደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናዛዥ),
					result  => q(አና፟ዛዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናዘዘ),
					result  => q(አና፟ዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናካ),
					result  => q(አና፟ካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናኪ),
					result  => q(አና፟ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናከሰ),
					result  => q(አና፟ከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናባቢ),
					result  => q(አና፟ባቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናበበ),
					result  => q(አና፟በ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናቀለ),
					result  => q(አና፟ቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አናረ),
					result  => q(አና፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነፋፈሰ),
					result  => q(አነፋፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነፋረቀ),
					result  => q(አነ፟ፋረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነፈነፈ),
					result  => q(አነፈነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነፈነ),
					result  => q(አነ፟ፈነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነፈሰ),
					result  => q(አነፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነፈረቀ),
					result  => q(አነፈረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነፈረ),
					result  => q(አነፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጻጸረ),
					result  => q(አነ፟ጻጸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጫነጨ),
					result  => q(አነጫነ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጣጣሪ),
					result  => q(አነ፟ጣጣሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጣጠረ),
					result  => q(አነ፟ጣጠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጣጠለ),
					result  => q(አነ፟ጣጠ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጠነጠ),
					result  => q(አነጠነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጠ),
					result  => q(አነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጐድ),
					result  => q(አነጐ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጐተ),
					result  => q(አነጐ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጐረ),
					result  => q(አነጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጋጋሪ),
					result  => q(አነ፟ጋጋሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጋጋ),
					result  => q(አነጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጋገር),
					result  => q(አነ፟ጋገር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነጋ),
					result  => q(አነጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነገተ),
					result  => q(አነገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነገበ),
					result  => q(አነገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነገሠ),
					result  => q(አነገ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነዳድ),
					result  => q(አነ፟ዳድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነደደ),
					result  => q(አነደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነዘረ),
					result  => q(አነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነወረ),
					result  => q(አነወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነኳኰተ),
					result  => q(አነኳኰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነኰተ),
					result  => q(አነኰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነኰረ),
					result  => q(አነኰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነካካ),
					result  => q(አነ፟ካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነካኪ),
					result  => q(አነ፟ካኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነካከሰ),
					result  => q(አነካከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነከተ),
					result  => q(አነከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነከሰ),
					result  => q(አነከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነኈለለ),
					result  => q(አነኈለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነታረከ),
					result  => q(አነ፟ታረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነባበበ),
					result  => q(አነባበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነባበሮ),
					result  => q(አነ፟ባበሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነባበረ),
					result  => q(አነ፟ባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነባ),
					result  => q(አነባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነበዘ),
					result  => q(አነበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነበነበ),
					result  => q(አነበነ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነበበ),
					result  => q(አነበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቈረ),
					result  => q(አነቈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቃናቂ),
					result  => q(አነ፟ቃናቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቃነቀ),
					result  => q(አነ፟ቃነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቃቃ),
					result  => q(አነ፟ቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቃቂ),
					result  => q(አነ፟ቃቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቃ),
					result  => q(አነቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቀፈ),
					result  => q(አነቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቀዘ),
					result  => q(አነቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነቀ),
					result  => q(አነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነስተኛ),
					result  => q(አነስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነሰረ),
					result  => q(አነሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነሰ),
					result  => q(አነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነሣሽ),
					result  => q(አነ፟ሣሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነሣሣ),
					result  => q(አነ፟ሣሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አነሣ),
					result  => q(አነሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቻኳይ),
					result  => q(አቻ፟ኳይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቻቻለ),
					result  => q(አቻ፟ቻለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቻምና),
					result  => q(አቻ፟ምና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቻ),
					result  => q(አቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቸነፈ),
					result  => q(አቸ፟ነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቶፈቶፈ),
					result  => q(አቶፈቶ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቶሰቶሰ),
					result  => q(አቶሰቶ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አትጠራጠር),
					result  => q(አት፟ጠ፟ራጠር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አትክልተኛ),
					result  => q(አትክልተ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አትራ),
					result  => q(አት፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታጋይ),
					result  => q(አታ፟ጋይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታገለ),
					result  => q(አታ፟ገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታከተ),
					result  => q(አታከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታከለ),
					result  => q(አታ፟ከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታች),
					result  => q(አታ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታቢ),
					result  => q(አታ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታሚ),
					result  => q(አታ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታላይ),
					result  => q(አታ፟ላይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አታለለ),
					result  => q(አታ፟ለለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተኰሰ),
					result  => q(አተኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተኮረ),
					result  => q(አተኮ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተከነ),
					result  => q(አተከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተኛኝ),
					result  => q(አተ፟ኛኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተኛኘት),
					result  => q(አተ፟ኛኘት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተተ),
					result  => q(አተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተበ),
					result  => q(አተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተራተረ),
					result  => q(አተ፟ራተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተራረፈ),
					result  => q(አተራረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተራማሽ),
					result  => q(አተ፟ራማሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተራመሰ),
					result  => q(አተ፟ራመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተረፈ),
					result  => q(አተረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተረማመሰ),
					result  => q(አተ፟ረማመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተመተመ),
					result  => q(አተመተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተመ),
					result  => q(አተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አተላ),
					result  => q(አተላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቧደነ),
					result  => q(አቧ፟ደ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቧራማ),
					result  => q(አቧራ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቧለተ),
					result  => q(አቧለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቦዘነ),
					result  => q(አቦዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቦካ),
					result  => q(አቦካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቦነነ),
					result  => q(አቦነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቦ),
					result  => q(አቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብዛኛውን),
					result  => q(አብዛኛ፟ውን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብዛኛው),
					result  => q(አብዛኛ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብነት),
					result  => q(አብነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብቃቃ),
					result  => q(አብቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብሰለሰለ),
					result  => q(አብሰለሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብራራ),
					result  => q(አብራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብረከረከ),
					result  => q(አብረከረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብረቀረቀ),
					result  => q(አብረቀረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አብላላ),
					result  => q(አብላ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባጨጓሬ),
					result  => q(አባ፟ጨጓ፟ሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባዳ),
					result  => q(አባ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባይነት),
					result  => q(አባይነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባይ),
					result  => q(አባ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባዬ),
					result  => q(አባ፟ዬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባዥ),
					result  => q(አባ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባዛ),
					result  => q(አባዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባወራ),
					result  => q(አባ፟ወራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባካኝ),
					result  => q(አባካኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባከነ),
					result  => q(አባከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባነነ),
					result  => q(አባነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባት),
					result  => q(አባ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባቴ),
					result  => q(አባ፟ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባባሰ),
					result  => q(አባ፟ባሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባባል),
					result  => q(አባ፟ባል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባባለ),
					result  => q(አባ፟ባለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባባ),
					result  => q(አባ፟ባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባበጠ),
					result  => q(አባበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባበለ),
					result  => q(አባበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባቃ),
					result  => q(አባቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባራሪ),
					result  => q(አባ፟ራሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባራ),
					result  => q(አባራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባረቀ),
					result  => q(አባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባረረ),
					result  => q(አባ፟ረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባልነት),
					result  => q(አባልነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባላ),
					result  => q(አባላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባለጠ),
					result  => q(አባለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባለገ),
					result  => q(አባለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አባ),
					result  => q(አባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበጣባጭ),
					result  => q(አበ፟ጣባጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበጣበጠ),
					result  => q(አበ፟ጣበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበጠ),
					result  => q(አበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበገነ),
					result  => q(አበገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበጃጀ),
					result  => q(አበጃጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበጀ),
					result  => q(አበጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበዳሪ),
					result  => q(አበዳ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበደረ),
					result  => q(አበደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበዛ),
					result  => q(አበዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበካከነ),
					result  => q(አበካከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበከተ),
					result  => q(አበከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበታተነ),
					result  => q(አበ፟ታተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበባማ),
					result  => q(አበባማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበበ),
					result  => q(አበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበቃቃ),
					result  => q(አበ፟ቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበቃ),
					result  => q(አበቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበቀለ),
					result  => q(አበቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሻቀጠ),
					result  => q(አበ፟ሻቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሸቀጠ),
					result  => q(አበ፟ሸቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሸቀ),
					result  => q(አበሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሳጨ),
					result  => q(አበ፟ሳጨ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሰበሰ),
					result  => q(አበሰበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሰረ),
					result  => q(አበሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሰለ),
					result  => q(አበሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበሰ),
					result  => q(አበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበር),
					result  => q(አበ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበራየ),
					result  => q(አበራየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበራከተ),
					result  => q(አበ፟ራከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበራ),
					result  => q(አበራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበረገገ),
					result  => q(አበረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበረደ),
					result  => q(አበረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበረከተ),
					result  => q(አበረከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበረታ),
					result  => q(አበረታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበረረ),
					result  => q(አበረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበረ),
					result  => q(አበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበል),
					result  => q(አበል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበላሸ),
					result  => q(አበላሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበላለጠ),
					result  => q(አበላለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበላ),
					result  => q(አበላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበለጠ),
					result  => q(አበለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበለዘ),
					result  => q(አበለ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አበለ),
					result  => q(አበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋፈረ),
					result  => q(አቋ፟ፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋቋም),
					result  => q(አቋ፟ቋም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋቋሚ),
					result  => q(አቋ፟ቋሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋቋመ),
					result  => q(አቋ፟ቋመ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋራጭ),
					result  => q(አቋ፟ራጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋረጠ),
					result  => q(አቋ፟ረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋመጠ),
					result  => q(አቋመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቋለፈ),
					result  => q(አቋ፟ለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈጣጠረ),
					result  => q(አቈ፟ጣጠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈነሰ),
					result  => q(አቈነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈሳሰለ),
					result  => q(አቈሳሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈሰለ),
					result  => q(አቈሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈራረጠ),
					result  => q(አቈ፟ራረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈራመደ),
					result  => q(አቈ፟ራመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈረፈደ),
					result  => q(አቈረፈ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈረበ),
					result  => q(አቈረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈረቈዘ),
					result  => q(አቈረቈ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈላለፈ),
					result  => q(አቈላለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቈለቈለ),
					result  => q(አቈለቈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆጠቆጠ),
					result  => q(አቆጠቆ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆየ),
					result  => q(አቆየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆነጀ),
					result  => q(አቆነጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆሸሸ),
					result  => q(አቆሸ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆራኘ),
					result  => q(አቆ፟ራኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆላመጠ),
					result  => q(አቆ፟ላመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆላለፈ),
					result  => q(አቆ፟ላለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቆለቆለ),
					result  => q(አቆለቆ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቅጣጫ),
					result  => q(አቅጣጫ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቅነዘነዘ),
					result  => q(አቅነዘነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቅበዘበዘ),
					result  => q(አቅበዘበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቅራቢያ),
					result  => q(አቅራቢ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቅማማ),
					result  => q(አቅማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቅለበለበ),
					result  => q(አቅለበለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቅለሸለሸ),
					result  => q(አቅለሸለ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃጣሪ),
					result  => q(አቃ፟ጣሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃጠፈ),
					result  => q(አቃ፟ጠ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃጠረ),
					result  => q(አቃ፟ጠረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃጠለ),
					result  => q(አቃ፟ጠ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃዠ),
					result  => q(አቃዠ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃዋሽ),
					result  => q(አቃ፟ዋሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃወሰ),
					result  => q(አቃወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃና),
					result  => q(አቃ፟ና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃነሰ),
					result  => q(አቃ፟ነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃባ),
					result  => q(አቃ፟ባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃበረ),
					result  => q(አቃ፟በ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃሰተ),
					result  => q(አቃሰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃራመ),
					result  => q(አቃ፟ራ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃረበ),
					result  => q(አቃ፟ረበ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃመሰ),
					result  => q(አቃመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቃለለ),
					result  => q(አቃ፟ለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቁነጠነጠ),
					result  => q(አቁነጠነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቁላላ),
					result  => q(አቁላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቁለጨለጨ),
					result  => q(አቁለጨለ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀፍ),
					result  => q(አቀ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀፈ),
					result  => q(አቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀጣጠነ),
					result  => q(አቀ፟ጣጠነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀጣጠረ),
					result  => q(አቀ፟ጣጠረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀዳጀ),
					result  => q(አቀዳጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀያየጠ),
					result  => q(አቀ፟ያየ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀያየደ),
					result  => q(አቀያየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀያየረ),
					result  => q(አቀ፟ያየ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀዛቀዘ),
					result  => q(አቀ፟ዛቀዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀዘቀዘ),
					result  => q(አቀዘቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀናነሰ),
					result  => q(አቀ፟ናነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀናባሪ),
					result  => q(አቀ፟ናባሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀናበር),
					result  => q(አቀ፟ናበ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀናበረ),
					result  => q(አቀ፟ናበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀና),
					result  => q(አቀና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀነባባሪ),
					result  => q(አቀ፟ነባባ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀነባበረ),
					result  => q(አቀ፟ነባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀነበጠ),
					result  => q(አቀነበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀነቀነ),
					result  => q(አቀነቀ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀባይ),
					result  => q(አቀባ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀባባይ),
					result  => q(አቀ፟ባባይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀባበረ),
					result  => q(አቀ፟ባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀባበለ),
					result  => q(አቀ፟ባበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀበጠ),
					result  => q(አቀበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀበለ),
					result  => q(አቀበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀሰሰ),
					result  => q(አቀሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀራረበ),
					result  => q(አቀ፟ራረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀረጣጠፈ),
					result  => q(አቀ፟ረጣጠ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀረና),
					result  => q(አቀረና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀረበ),
					result  => q(አቀረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀረቀረ),
					result  => q(አቀረቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀረረ),
					result  => q(አቀረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀማጠለ),
					result  => q(አቀ፟ማጠ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀማመጥ),
					result  => q(አቀ፟ማመጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀመሰ),
					result  => q(አቀመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀላጠፈ),
					result  => q(አቀ፟ላጠ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀላቀለ),
					result  => q(አቀ፟ላቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀላል),
					result  => q(አቀ፟ላል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀላ),
					result  => q(አቀላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀለጠ),
					result  => q(አቀለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀለመ),
					result  => q(አቀለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አቀለለ),
					result  => q(አቀለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሾከሾከ),
					result  => q(አሾከሾ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሾመ),
					result  => q(አሾ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሾላቂ),
					result  => q(አሾላ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሾለከ),
					result  => q(አሾለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሾለቀ),
					result  => q(አሾለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽኮረመመ),
					result  => q(አሽኮረመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽካካ),
					result  => q(አሽካ፟ካ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽከርነት),
					result  => q(አሽከርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽከረከረ),
					result  => q(አሽከረከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽታ),
					result  => q(አሽ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽበለበለ),
					result  => q(አሽበለበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽቆጠቆጠ),
					result  => q(አሽቆጠቆ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽቀዳደመ),
					result  => q(አሽቀዳደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽሟጣጭነት),
					result  => q(አሽሟጣጭነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሽሙረኛ),
					result  => q(አሽሙረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻፈደ),
					result  => q(አሻፈ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻፈረኝ),
					result  => q(አሻፈ፟ረኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻገተ),
					result  => q(አሻገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻገረ),
					result  => q(አሻገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻከረ),
					result  => q(አሻከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻንጉሊት),
					result  => q(አሻንጉሊ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻቀበ),
					result  => q(አሻቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻሻጭ),
					result  => q(አሻ፟ሻጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻሻጠ),
					result  => q(አሻ፟ሻጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻሻለ),
					result  => q(አሻ፟ሻለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻሸ),
					result  => q(አሻሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻረከ),
					result  => q(አሻ፟ረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻረ),
					result  => q(አሻ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻማ),
					result  => q(አሻ፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሻለ),
					result  => q(አሻ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸፈነ),
					result  => q(አሸ፟ፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸፈተ),
					result  => q(አሸፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸጠ),
					result  => q(አሸ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸጋገረ),
					result  => q(አሸ፟ጋገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸጋሸገ),
					result  => q(አሸ፟ጋሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸገ),
					result  => q(አሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸዋነት),
					result  => q(አሸዋነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸዋማ),
					result  => q(አሸዋማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸካሸከ),
					result  => q(አሸ፟ካሸ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸከመ),
					result  => q(አሸ፟ከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸኛኘት),
					result  => q(አሸ፟ኛኘት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸኘ),
					result  => q(አሸ፟ኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸናፊ),
					result  => q(አሸ፟ና፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸና),
					result  => q(አሸ፟ና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸነፈ),
					result  => q(አሸ፟ነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸነሸነ),
					result  => q(አሸ፟ነሸ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸተተ),
					result  => q(አሸተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸባሪ),
					result  => q(አሸ፟ባ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸበተ),
					result  => q(አሸበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸበበ),
					result  => q(አሸ፟በ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸበሸበ),
					result  => q(አሸበሸ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸበረቀ),
					result  => q(አሸበረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸበረ),
					result  => q(አሸ፟በ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸቀበ),
					result  => q(አሸቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸቀለ),
					result  => q(አሸ፟ቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸሸገ),
					result  => q(አሸ፟ሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸሸ),
					result  => q(አሸ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸረፈ),
					result  => q(አሸረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸረጠ),
					result  => q(አሸረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸረሞጠ),
					result  => q(አሸረሞ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸመጠጠ),
					result  => q(አሸ፟መጠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸመገለ),
					result  => q(አሸመገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸመተ),
					result  => q(አሸመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸመ),
					result  => q(አሸ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸለተ),
					result  => q(አሸ፟ለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸለበ),
					result  => q(አሸለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸለቀቀ),
					result  => q(አሸ፟ለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸለመ),
					result  => q(አሸለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸለለ),
					result  => q(አሸ፟ለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሸ),
					result  => q(አሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሶመሰመ),
					result  => q(አሶመሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፋፋ),
					result  => q(አስፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈጀ),
					result  => q(አስፈጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈታ),
					result  => q(አስፈታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈተገ),
					result  => q(አስፈተ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈተነ),
					result  => q(አስፈተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈተሸ),
					result  => q(አስፈተ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈቀደ),
					result  => q(አስፈቀ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈሳው),
					result  => q(አስፈሳ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈሳ),
					result  => q(አስፈሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈራራ),
					result  => q(አስፈራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈራ),
					result  => q(አስፈራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈሪ),
					result  => q(አስፈሪ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈረደ),
					result  => q(አስፈ፟ረደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈረመ),
					result  => q(አስፈረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈላ),
					result  => q(አስፈላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈለፈለ),
					result  => q(አስፈለፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈለገኝ),
					result  => q(አስፈለ፟ገኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስፈለገ),
					result  => q(አስፈለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጸያፊ),
					result  => q(አስጸ፟ያ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጸየፈ),
					result  => q(አስጸ፟የ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጨፈረ),
					result  => q(አስጨፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጨፈለቀ),
					result  => q(አስጨፈለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጨናቂ),
					result  => q(አስጨና፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጨነቀ),
					result  => q(አስጨነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጨበጨበ),
					result  => q(አስጨበጨ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጨመቀ),
					result  => q(አስጨመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጨመረ),
					result  => q(አስጨመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠጋ),
					result  => q(አስጠጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠገነ),
					result  => q(አስጠገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠይ),
					result  => q(አስጠይ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠያፊ),
					result  => q(አስጠያ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠየፈ),
					result  => q(አስጠየ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠኚ),
					result  => q(አስጠኚ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠና),
					result  => q(አስጠና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠነቀቀ),
					result  => q(አስጠነቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠቃ),
					result  => q(አስጠቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠራ),
					result  => q(አስጠራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠማ),
					result  => q(አስጠማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠመደ),
					result  => q(አስጠመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠላ),
					result  => q(አስጠላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጠለለ),
					result  => q(አስጠለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጐነበሰ),
					result  => q(አስጐነበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጐበኘ),
					result  => q(አስጐበኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጎመጀ),
					result  => q(አስጎመጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገደፈ),
					result  => q(አስገደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገደደ),
					result  => q(አስገደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገደለ),
					result  => q(አስገደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገዘተ),
					result  => q(አስገዘ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገኘ),
					result  => q(አስገኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገነዘበ),
					result  => q(አስገነዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገባ),
					result  => q(አስገባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገራሚ),
					result  => q(አስገራ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገራ),
					result  => q(አስገራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገረዘ),
					result  => q(አስገረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገረመ),
					result  => q(አስገረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገመገመ),
					result  => q(አስገመገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገመተ),
					result  => q(አስገመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገመሰ),
					result  => q(አስገመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስገለበጠ),
					result  => q(አስገለበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስጀመረ),
					result  => q(አስጀመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደፈጠ),
					result  => q(አስደፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደፈነ),
					result  => q(አስደፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደፈቀ),
					result  => q(አስደፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደፈረ),
					result  => q(አስደፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደገደገ),
					result  => q(አስደገደ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደገሰ),
					result  => q(አስደገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደገመ),
					result  => q(አስደገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደወለ),
					result  => q(አስደወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደናቂ),
					result  => q(አስደና፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደነገጠ),
					result  => q(አስደነገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደነበረ),
					result  => q(አስደነበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደነቀ),
					result  => q(አስደነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደነሰ),
					result  => q(አስደነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደባለቀ),
					result  => q(አስደባለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደበቀ),
					result  => q(አስደበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደበለቀ),
					result  => q(አስደበለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደቀቀ),
					result  => q(አስደቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደሳች),
					result  => q(አስደሳ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደሰተ),
					result  => q(አስደሰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደራጊ),
					result  => q(አስደራ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደረገ),
					result  => q(አስደረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደረደረ),
					result  => q(አስደረደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደረተ),
					result  => q(አስደረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደመሰሰ),
					result  => q(አስደመሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደመረ),
					result  => q(አስደመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስደለደለ),
					result  => q(አስደለደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስዋኘ),
					result  => q(አስዋኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወጋ),
					result  => q(አስወጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወገደ),
					result  => q(አስወገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወገረ),
					result  => q(አስወገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወደደ),
					result  => q(አስወደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወነጀለ),
					result  => q(አስወነጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወተፈ),
					result  => q(አስወተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወቃ),
					result  => q(አስወቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወቀጠ),
					result  => q(አስወቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወቀረ),
					result  => q(አስወቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወሰደ),
					result  => q(አስወሰ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወሰነ),
					result  => q(አስወሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወራ),
					result  => q(አስወራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወረደ),
					result  => q(አስወረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወረወረ),
					result  => q(አስወረወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወረረ),
					result  => q(አስወረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወለደ),
					result  => q(አስወለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስወለቀ),
					result  => q(አስወለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስኰናኝ),
					result  => q(አስኰና፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስኰነነ),
					result  => q(አስኰነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስኮተኮተ),
					result  => q(አስኮተኮ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስኮበለለ),
					result  => q(አስኮበለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስኮረፈ),
					result  => q(አስኮረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስኮረጀ),
					result  => q(አስኮረ፟ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስኮላሸ),
					result  => q(አስኮላሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስካካ),
					result  => q(አስካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከፋ),
					result  => q(አስከፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከፊ),
					result  => q(አስከፊ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከፈፈ),
					result  => q(አስከፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከፈከፈ),
					result  => q(አስከፈከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከፈነ),
					result  => q(አስከፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከፈለ),
					result  => q(አስከፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከዳ),
					result  => q(አስከዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከደነ),
					result  => q(አስከደ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከነዳ),
					result  => q(አስከነ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከተከተ),
					result  => q(አስከተከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከተተ),
					result  => q(አስከተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከተበ),
					result  => q(አስከተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከተረ),
					result  => q(አስከተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከተለ),
					result  => q(አስከተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከባሪ),
					result  => q(አስከባ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከበበ),
					result  => q(አስከበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከበረ),
					result  => q(አስከበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከሰከሰ),
					result  => q(አስከሰከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከሰሰ),
					result  => q(አስከሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከሰለ),
					result  => q(አስከሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከረከመ),
					result  => q(አስከረከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከረተፈ),
					result  => q(አስከረተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከመረ),
					result  => q(አስከመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከለከለ),
					result  => q(አስከለከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከለበሰ),
					result  => q(አስከለበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስከለለ),
					result  => q(አስከለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነፋ),
					result  => q(አስነፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነፈሰ),
					result  => q(አስነፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነጐረ),
					result  => q(አስነጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነጋ),
					result  => q(አስነጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነገደ),
					result  => q(አስነገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነገተ),
					result  => q(አስነገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነገረ),
					result  => q(አስነገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነዳ),
					result  => q(አስነዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነደፈ),
					result  => q(አስነደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነደለ),
					result  => q(አስነደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነዋሪ),
					result  => q(አስነዋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነወረ),
					result  => q(አስነወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነካ),
					result  => q(አስነካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነከሰ),
					result  => q(አስነከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነከረ),
					result  => q(አስነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነበበ),
					result  => q(አስነበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነቃፊ),
					result  => q(አስነቃ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነቀፈ),
					result  => q(አስነቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነቀሰ),
					result  => q(አስነቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነቀለ),
					result  => q(አስነቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነሺ),
					result  => q(አስነሺ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነሰነሰ),
					result  => q(አስነሰነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነረተ),
					result  => q(አስነረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስነሣ),
					result  => q(አስነ፟ሣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቸጋሪ),
					result  => q(አስቸጋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቸገረ),
					result  => q(አስቸገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቸኳይ),
					result  => q(አስቸኳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቸኰለ),
					result  => q(አስቸኰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቸከለ),
					result  => q(አስቸከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቸነከረ),
					result  => q(አስቸነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቸረቸረ),
					result  => q(አስቸ፟ረቸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስታጐለ),
					result  => q(አስታጐ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስታገሠ),
					result  => q(አስታገ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስታወቀ),
					result  => q(አስታወ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስታወሰ),
					result  => q(አስታወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስታከከ),
					result  => q(አስታከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስታቀፈ),
					result  => q(አስታቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስታረቀ),
					result  => q(አስታረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተፋ),
					result  => q(አስተፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተጋባ),
					result  => q(አስተጋባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተዳደረ),
					result  => q(አስተዳደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተያየ),
					result  => q(አስተያየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተዛዘበ),
					result  => q(አስተዛዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተዋወቀ),
					result  => q(አስተዋወ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተኰሰ),
					result  => q(አስተኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተካከለ),
					result  => q(አስተካከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተከዘ),
					result  => q(አስተከ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተኛ),
					result  => q(አስተ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተናገደ),
					result  => q(አስተናገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተናበረ),
					result  => q(አስተናበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተነፈሰ),
					result  => q(አስተነፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተነተነ),
					result  => q(አስተነተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተቸ),
					result  => q(አስተቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተባበረ),
					result  => q(አስተባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተባበለ),
					result  => q(አስተባበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተሻሸ),
					result  => q(አስተሻሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተሳሰበ),
					result  => q(አስተሳሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተራረሰ),
					result  => q(አስተራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተረጐመ),
					result  => q(አስተረጐ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተረተረ),
					result  => q(አስተረተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተሣሠረ),
					result  => q(አስተሣሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተማረ),
					result  => q(አስተማ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተማመነ),
					result  => q(አስተማመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተመተመ),
					result  => q(አስተመተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተላለፈ),
					result  => q(አስተላለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተላለቀ),
					result  => q(አስተላለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስተለተለ),
					result  => q(አስተለተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስባረከ),
					result  => q(አስባረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበጠበጠ),
					result  => q(አስበጠበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበጂ),
					result  => q(አስበጂ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበዳ),
					result  => q(አስበዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበደለ),
					result  => q(አስበደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበየደ),
					result  => q(አስበየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበየነ),
					result  => q(አስበየ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበዘበዘ),
					result  => q(አስበዘበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበከለ),
					result  => q(አስበከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበተነ),
					result  => q(አስበተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበሰለ),
					result  => q(አስበሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበራ),
					result  => q(አስበራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበረገገ),
					result  => q(አስበረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበረደ),
					result  => q(አስበረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበረዘ),
					result  => q(አስበረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበረበረ),
					result  => q(አስበረበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበረቀሰ),
					result  => q(አስበረቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስበላ),
					result  => q(አስበላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቈራ),
					result  => q(አስቈራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቈረጠ),
					result  => q(አስቈረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቈረበ),
					result  => q(አስቈረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቈረቈረ),
					result  => q(አስቈረቈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቈለመመ),
					result  => q(አስቈለመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቆፈረ),
					result  => q(አስቆፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቆየ),
					result  => q(አስቆየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቆረሰ),
					result  => q(አስቆረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቆላ),
					result  => q(አስቆላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቆለፈ),
					result  => q(አስቆለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቆለለ),
					result  => q(አስቆለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቃረመ),
					result  => q(አስቃረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቂኝ),
					result  => q(አስ፟ቂኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀፈደደ),
					result  => q(አስቀፈደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀፈቀፈ),
					result  => q(አስቀፈቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀጠቀጠ),
					result  => q(አስቀጠቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀድሞ),
					result  => q(አስቀድ፟ሞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀዳሽ),
					result  => q(አስቀዳ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀዳ),
					result  => q(አስቀዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀደደ),
					result  => q(አስቀደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀደሰ),
					result  => q(አስቀደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀደመ),
					result  => q(አስቀደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀያሚ),
					result  => q(አስቀያ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀየጠ),
					result  => q(አስቀየ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀየደ),
					result  => q(አስቀየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀየሠ),
					result  => q(አስቀየ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀየመ),
					result  => q(አስቀየ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀዘፈ),
					result  => q(አስቀዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀዘነ),
					result  => q(አስቀዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀና),
					result  => q(አስቀና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀነሰ),
					result  => q(አስቀነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀባ),
					result  => q(አስቀባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀበቀበ),
					result  => q(አስቀበቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀበረ),
					result  => q(አስቀበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀበለ),
					result  => q(አስቀበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀቀለ),
					result  => q(አስቀቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀሳፈተ),
					result  => q(አስቀሳፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀሰተ),
					result  => q(አስቀሰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀረፈ),
					result  => q(አስቀረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀረጸ),
					result  => q(አስቀረ፟ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀረጠ),
					result  => q(አስቀረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀረደደ),
					result  => q(አስቀረደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀረ),
					result  => q(አስቀረ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀሠፈ),
					result  => q(አስቀሠ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀማ),
					result  => q(አስቀማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀመጠ),
					result  => q(አስቀመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀመቀመ),
					result  => q(አስቀመቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀመሰ),
					result  => q(አስቀመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀመመ),
					result  => q(አስቀመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀመለ),
					result  => q(አስቀመ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀለጠ),
					result  => q(አስቀለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀለበሰ),
					result  => q(አስቀለበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስቀለሰ),
					result  => q(አስቀለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረፈደ),
					result  => q(አስረፈ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረገፈ),
					result  => q(አስረገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረገጠ),
					result  => q(አስረገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረገዘ),
					result  => q(አስረገ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረገመ),
					result  => q(አስረገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረጀ),
					result  => q(አስረጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረዳ),
					result  => q(አስረዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረካቢ),
					result  => q(አስረካ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረከበ),
					result  => q(አስረከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረበረበ),
					result  => q(አስረበረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረቀቀ),
					result  => q(አስረቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረሳ),
					result  => q(አስረሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስረረ),
					result  => q(አስ፟ረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስሞጨለፈ),
					result  => q(አስሞጨለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስሞገተ),
					result  => q(አስሞገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስሞከተ),
					result  => q(አስሞከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስሞረደ),
					result  => q(አስሞረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስሞላ),
					result  => q(አስሞላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስማገረ),
					result  => q(አስማገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስማተኛ),
					result  => q(አስማተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስማማ),
					result  => q(አስማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመጠወተ),
					result  => q(አስመጠወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመገበ),
					result  => q(አስመገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመደበ),
					result  => q(አስመደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመዘገበ),
					result  => q(አስመዘገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመዘዘ),
					result  => q(አስመዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመዘነ),
					result  => q(አስመዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመከረ),
					result  => q(አስመከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመኘ),
					result  => q(አስመኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመነዘረ),
					result  => q(አስመነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመነኰሰ),
					result  => q(አስመነኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመነነ),
					result  => q(አስመነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመነታ),
					result  => q(አስመነታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመታ),
					result  => q(አስመታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመተረ),
					result  => q(አስመተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመሸገ),
					result  => q(አስመሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመሸ),
					result  => q(አስመሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመሳይ),
					result  => q(አስመሳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመሰገነ),
					result  => q(አስመሰገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመሰከረ),
					result  => q(አስመሰከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመሰለ),
					result  => q(አስመሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመራ),
					result  => q(አስመራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመረጠ),
					result  => q(አስመረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመረገ),
					result  => q(አስመረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመረዘ),
					result  => q(አስመረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመረቀ),
					result  => q(አስመረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመረረ),
					result  => q(አስመረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመረመረ),
					result  => q(አስመረመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመሠረተ),
					result  => q(አስመሠ፟ረተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመለጠ),
					result  => q(አስመለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመለከተ),
					result  => q(አስመለከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስመለሰ),
					result  => q(አስመለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለፋ),
					result  => q(አስለፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለፈፈ),
					result  => q(አስለፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለፈለፈ),
					result  => q(አስለፈለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለጎመ),
					result  => q(አስለጎ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለበጠ),
					result  => q(አስለበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለበደ),
					result  => q(አስለበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለበበ),
					result  => q(አስለበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለበሰ),
					result  => q(አስለበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለበለበ),
					result  => q(አስለበለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለቃሽ),
					result  => q(አስለቃ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለቀቀ),
					result  => q(አስለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለቀሰ),
					result  => q(አስለቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለቀመ),
					result  => q(አስለቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለቀለቀ),
					result  => q(አስለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለሰነ),
					result  => q(አስለሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለማጅ),
					result  => q(አስለማ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለማ),
					result  => q(አስለማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለመደ),
					result  => q(አስለመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አስለመነ),
					result  => q(አስለመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳፋሪ),
					result  => q(አሳ፟ፋሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳፈነ),
					result  => q(አሳፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳፈሰ),
					result  => q(አሳፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳፈረ),
					result  => q(አሳ፟ፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳጪ),
					result  => q(አሳ፟ጪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳጣ),
					result  => q(አሳ፟ጣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳገደ),
					result  => q(አሳገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳጀበ),
					result  => q(አሳጀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳጀለ),
					result  => q(አሳጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳዳጊ),
					result  => q(አሳዳ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳዳጅ),
					result  => q(አሳ፟ዳጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳደፈ),
					result  => q(አሳደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳደገ),
					result  => q(አሳደ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳደደ),
					result  => q(አሳ፟ደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳደለ),
					result  => q(አሳደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳየ),
					result  => q(አሳየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳዛኝ),
					result  => q(አሳዛ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳዘዘ),
					result  => q(አሳዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳዘነ),
					result  => q(አሳዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳወቀ),
					result  => q(አሳወ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳካሚ),
					result  => q(አሳካ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳካ),
					result  => q(አሳ፟ካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳከከ),
					result  => q(አሳከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳከተ),
					result  => q(አሳከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳከረ),
					result  => q(አሳ፟ከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳከመ),
					result  => q(አሳከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳከለ),
					result  => q(አሳከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳነፈ),
					result  => q(አሳ፟ነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳነጠ),
					result  => q(አሳነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳነቀ),
					result  => q(አሳነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳነሰ),
					result  => q(አሳነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳች),
					result  => q(አሳ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳቻ),
					result  => q(አሳ፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳታሚ),
					result  => q(አሳታ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳተፈ),
					result  => q(አሳ፟ተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳተመ),
					result  => q(አሳተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳተ),
					result  => q(አሳ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳብ),
					result  => q(አሳ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳባቂ),
					result  => q(አሳ፟ባቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳባሪ),
					result  => q(አሳ፟ባሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳቢ),
					result  => q(አሳ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳበጠ),
					result  => q(አሳበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳበደ),
					result  => q(አሳበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳበበ),
					result  => q(አሳ፟በ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳበቀ),
					result  => q(አሳ፟በ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳበረ),
					result  => q(አሳ፟በ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳበ),
					result  => q(አሳ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳቀፈ),
					result  => q(አሳቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳቀደ),
					result  => q(አሳቀ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳቀቀ),
					result  => q(አሳ፟ቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳቀለ),
					result  => q(አሳ፟ቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳቀ),
					result  => q(አሳ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሸገ),
					result  => q(አሳሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሸ),
					result  => q(አሳሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሳች),
					result  => q(አሳ፟ሳች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሳተ),
					result  => q(አሳ፟ሳተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሳቢ),
					result  => q(አሳሳ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሳበ),
					result  => q(አሳ፟ሳበ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሳቀ),
					result  => q(አሳ፟ሳቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሳመ),
					result  => q(አሳ፟ሳመ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሰበ),
					result  => q(አሳሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳራሽ),
					result  => q(አሳራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳራሪ),
					result  => q(አሳ፟ራሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳራ),
					result  => q(አሳራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳረፈ),
					result  => q(አሳረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳረደ),
					result  => q(አሳረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳረሰ),
					result  => q(አሳረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳረረ),
					result  => q(አሳ፟ረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳረመ),
					result  => q(አሳረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳሠረ),
					result  => q(አሳሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳማኝ),
					result  => q(አሳማ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳመነ),
					result  => q(አሳመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳመቀ),
					result  => q(አሳመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳመሰ),
					result  => q(አሳመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳመመ),
					result  => q(አሳመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳመ),
					result  => q(አሳ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳለፈ),
					result  => q(አሳለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳለበ),
					result  => q(አሳለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሳለ),
					result  => q(አሳ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰፋ),
					result  => q(አሰ፟ፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰፈፈ),
					result  => q(አሰፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰፈሰፈ),
					result  => q(አሰፈሰ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰፈረ),
					result  => q(አሰ፟ፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰጠ),
					result  => q(አሰ፟ጠ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰገገ),
					result  => q(አሰገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰገደ),
					result  => q(አሰ፟ገደ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰዳቢ),
					result  => q(አሰዳ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰደበ),
					result  => q(አሰ፟ደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰየፈ),
					result  => q(አሰ፟የ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰካ),
					result  => q(አሰ፟ካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰከነ),
					result  => q(አሰከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰከረ),
					result  => q(አሰከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰኘው),
					result  => q(አሰ፟ኘ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰኘ),
					result  => q(አሰ፟ኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰናጅ),
					result  => q(አሰ፟ናጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰናዳ),
					result  => q(አሰ፟ናዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰናካይ),
					result  => q(አሰ፟ናካይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰናከለ),
					result  => q(አሰ፟ናከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰናበተ),
					result  => q(አሰ፟ናበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰነፈ),
					result  => q(አሰነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰነጠቀ),
					result  => q(አሰ፟ነጠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰነዳዳ),
					result  => q(አሰ፟ነዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰነካከለ),
					result  => q(አሰ፟ነካከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰነበተ),
					result  => q(አሰነበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰነቀ),
					result  => q(አሰ፟ነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰት),
					result  => q(አሰ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰባጠረ),
					result  => q(አሰ፟ባጠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰባሰበ),
					result  => q(አሰ፟ባሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰባ),
					result  => q(አሰባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰበጣጠረ),
					result  => q(አሰ፟በጣጠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰበከ),
					result  => q(አሰበ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰበረ),
					result  => q(አሰ፟በ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰበ),
					result  => q(አሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰቃየ),
					result  => q(አሰ፟ቃየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰቃቂ),
					result  => q(አሰ፟ቃ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰቀቀ),
					result  => q(አሰ፟ቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰቀለ),
					result  => q(አሰ፟ቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰሳ),
					result  => q(አሰ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰሰ),
					result  => q(አሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰራጨ),
					result  => q(አሰ፟ራጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰረዘ),
					result  => q(አሰ፟ረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰረቀ),
					result  => q(አሰ፟ረቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰረ),
					result  => q(አሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰማ),
					result  => q(አሰ፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰላፊ),
					result  => q(አሰ፟ላ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰላይ),
					result  => q(አሰ፟ላ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰላሰለ),
					result  => q(አሰ፟ላሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰላ),
					result  => q(አሰላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰለፈ),
					result  => q(አሰለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰለቸ),
					result  => q(አሰለቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰለበ),
					result  => q(አሰ፟ለበ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰለሰለ),
					result  => q(አሰለሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰለመ),
					result  => q(አሰለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሰለለ),
					result  => q(አሰ፟ለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሯሯጠ),
					result  => q(አሯ፟ሯጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርጩሜ),
					result  => q(አርጩሜ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርገበገበ),
					result  => q(አርገበገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርከፈከፈ),
					result  => q(አርከፈከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርአያነት),
					result  => q(አርአያነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርነት),
					result  => q(አርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርባኛ),
					result  => q(አርባኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርበደበደ),
					result  => q(አርበደበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርበኝነት),
					result  => q(አርበኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርበኛነት),
					result  => q(አርበኛ፟ነት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርበኛ),
					result  => q(አርበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርበተበተ),
					result  => q(አርበተበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አርመጠመጠ),
					result  => q(አርመጠመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራጋፊ),
					result  => q(አራ፟ጋ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራገፈ),
					result  => q(አራ፟ገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራገበ),
					result  => q(አራ፟ገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራት),
					result  => q(አራት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራተኛ),
					result  => q(አራተ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራባ),
					result  => q(አራ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራቈተ),
					result  => q(አራ፟ቈተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራራቀ),
					result  => q(አራ፟ራቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራራ),
					result  => q(አራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራረሰ),
					result  => q(አራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራሚ),
					result  => q(አራ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራሙቻ),
					result  => q(አራ፟ሙቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራመደ),
					result  => q(አራ፟መ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አራ),
					result  => q(አራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረፋፈደ),
					result  => q(አረፋ፟ፈደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረፈደ),
					result  => q(አረፈ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረጠረጠ),
					result  => q(አረጠረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረጠ),
					result  => q(አረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረጋጋ),
					result  => q(አረ፟ጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረጋገፈ),
					result  => q(አረ፟ጋገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረጋገጠ),
					result  => q(አረ፟ጋገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረጋ),
					result  => q(አረጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረገፈ),
					result  => q(አረገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረገደ),
					result  => q(አረገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረገዘ),
					result  => q(አረገ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረገበ),
					result  => q(አረገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረገረገ),
					result  => q(አረገረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረጀ),
					result  => q(አረጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረዳ),
					result  => q(አረዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረደ),
					result  => q(አረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረዘመ),
					result  => q(አረዘ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረካካቢ),
					result  => q(አረ፟ካካቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረካከበ),
					result  => q(አረ፟ካከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረካ),
					result  => q(አረካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረከሰ),
					result  => q(አረከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረባጅ),
					result  => q(አረባ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረባ),
					result  => q(አረባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረበደ),
					result  => q(አረ፟በ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረቀቀ),
					result  => q(አረቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረቀ),
					result  => q(አረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረሳሳ),
					result  => q(አረሳሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረሰ),
					result  => q(አረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረመኔነት),
					result  => q(አረመኔነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አረመ),
					result  => q(አረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሣረኛ),
					result  => q(አሣረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሣሣ),
					result  => q(አሣሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠጋገር),
					result  => q(አሠ፟ጋገር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠጋ),
					result  => q(አሠጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠገረ),
					result  => q(አሠገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠየመ),
					result  => q(አሠየ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠዋ),
					result  => q(አሠ፟ዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠረ),
					result  => q(አሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠሠ),
					result  => q(አሠ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠማመረ),
					result  => q(አሠማመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠመረ),
					result  => q(አሠመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠልጣኝ),
					result  => q(አሠልጣኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሠለሰ),
					result  => q(አሠለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟጋች),
					result  => q(አሟ፟ጋች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟገተ),
					result  => q(አሟ፟ገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟከረ),
					result  => q(አሟ፟ከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟሸ),
					result  => q(አሟሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟረተ),
					result  => q(አሟረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟሟቂ),
					result  => q(አሟ፟ሟቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟሟቀ),
					result  => q(አሟ፟ሟቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሟላ),
					result  => q(አሟ፟ላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞጠሞጠ),
					result  => q(አሞጠሞ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞጋገሰ),
					result  => q(አሞጋገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞጋሽ),
					result  => q(አሞጋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞገሰ),
					result  => q(አሞገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞካከረ),
					result  => q(አሞ፟ካከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞኘ),
					result  => q(አሞኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞቀሞቀ),
					result  => q(አሞቀሞ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞላቀቀ),
					result  => q(አሞላቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞላላ),
					result  => q(አሞ፟ላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞላ),
					result  => q(አሞላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሞለጨ),
					result  => q(አሞለ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምዘገዘገ),
					result  => q(አምዘገዘ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምነሸነሸ),
					result  => q(አምነሸነ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምታታ),
					result  => q(አምታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምቧቧ),
					result  => q(አምቧቧ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምቦጨቦጨ),
					result  => q(አምቦጨቦ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምቦረቀቀ),
					result  => q(አምቦረቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምቦልክ),
					result  => q(አምቦልክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምባጋሮኛ),
					result  => q(አምባጋሮኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምባሻ),
					result  => q(አምባሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምባረቀ),
					result  => q(አምባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምቡላ),
					result  => q(አምቡላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምበል),
					result  => q(አምበል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምስት),
					result  => q(አም፟ስት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምስተኛ),
					result  => q(አም፟ስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምሳያ),
					result  => q(አምሳያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አምሳኛ),
					result  => q(አምሳኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሜተኛ),
					result  => q(አሜተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማጭ),
					result  => q(አማ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማጣ),
					result  => q(አማ፟ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማገጠ),
					result  => q(አማገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማገረ),
					result  => q(አማ፟ገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማካኝ),
					result  => q(አማ፟ካኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማካሪ),
					result  => q(አማ፟ካሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማከረ),
					result  => q(አማከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማች),
					result  => q(አማ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማታ),
					result  => q(አማ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማተበ),
					result  => q(አማ፟ተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማሽ),
					result  => q(አማ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማሺ),
					result  => q(አማ፟ሺ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማሸ),
					result  => q(አማ፟ሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማሰለ),
					result  => q(አማ፟ሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማርኛ),
					result  => q(አማርኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማራጭ),
					result  => q(አማ፟ራጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማራሪ),
					result  => q(አማ፟ራሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማሪኛው),
					result  => q(አማሪኛ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማረጠ),
					result  => q(አማ፟ረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማረገ),
					result  => q(አማ፟ረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማረዘ),
					result  => q(አማ፟ረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማረረ),
					result  => q(አማ፟ረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማመመ),
					result  => q(አማመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማላጅነት),
					result  => q(አማ፟ላጅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማላጅ),
					result  => q(አማ፟ላጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማለደ),
					result  => q(አማ፟ለደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አማ),
					result  => q(አማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመጻደቀ),
					result  => q(አመ፟ጻደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመጣጠነ),
					result  => q(አመ፟ጣጠ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመጋገብ),
					result  => q(አመ፟ጋገብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመገለ),
					result  => q(አመ፟ገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመገ),
					result  => q(አመ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመዛዛኝ),
					result  => q(አመ፟ዛዛኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመዛዘነ),
					result  => q(አመ፟ዛዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመዘነ),
					result  => q(አመዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመካኘ),
					result  => q(አመ፟ካኘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመከነ),
					result  => q(አመከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመናጨቀ),
					result  => q(አመ፟ናጨ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመናቀረ),
					result  => q(አመ፟ናቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነጫጨቀ),
					result  => q(አመ፟ነጫጨ፟ቀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነዘረ),
					result  => q(አመነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነኰሰ),
					result  => q(አመነኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነቸከ),
					result  => q(አመነቸ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነታታ),
					result  => q(አመነታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነታ),
					result  => q(አመነታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነቃቀረ),
					result  => q(አመ፟ነቃቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነመነ),
					result  => q(አመነመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመነ),
					result  => q(አመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመቻቸ),
					result  => q(አመ፟ቻቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመቺ),
					result  => q(አመቺ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመቸ),
					result  => q(አመቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመቀ),
					result  => q(አመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሸህ),
					result  => q(አመሸ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሸ),
					result  => q(አመ፟ሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሳካሪ),
					result  => q(አመ፟ሳካሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሳከረ),
					result  => q(አመ፟ሳከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሳቀለ),
					result  => q(አመ፟ሳቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሳሰል),
					result  => q(አመ፟ሳሰል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሰጋገነ),
					result  => q(አመሰጋገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሰገነ),
					result  => q(አመሰገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሰኳ),
					result  => q(አመሰኳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሰቃቃይ),
					result  => q(አመ፟ሰቃቃይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሰቃቀለ),
					result  => q(አመ፟ሰቃቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሰ),
					result  => q(አመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመራር),
					result  => q(አመ፟ራር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመራማሪ),
					result  => q(አመ፟ራማሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመራመር),
					result  => q(አመ፟ራመር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመራመረ),
					result  => q(አመ፟ራመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመራ),
					result  => q(አመራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመረተ),
					result  => q(አመረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመረቀዘ),
					result  => q(አመረቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመረረ),
					result  => q(አመረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመሠራረት),
					result  => q(አመ፟ሠራረት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመመ),
					result  => q(አመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመላላሽ),
					result  => q(አመ፟ላላ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመላለስ),
					result  => q(አመ፟ላለ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመለጠው),
					result  => q(አመለ፟ጠው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመለጠ),
					result  => q(አመለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመለከተ),
					result  => q(አመለከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመለከ),
					result  => q(አመለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመለኛ),
					result  => q(አመለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አመለመለ),
					result  => q(አመለመ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሎሎ),
					result  => q(አሎሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልፈሰፈሰ),
					result  => q(አልፈሰፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልጫ),
					result  => q(አል፟ጫ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልጨረሰም),
					result  => q(አልጨረ፟ሰም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልጐመጐመ),
					result  => q(አልጐመጐ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልገባኝም),
					result  => q(አልገባ፟ኝ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልኮሰኮሰ),
					result  => q(አልኮሰኮ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልከሰከሰ),
					result  => q(አልከሰከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልባነት),
					result  => q(አልባነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልባሌ),
					result  => q(አልባ፟ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አልቃሻ),
					result  => q(አልቃሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላፊነት),
					result  => q(አላፊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላጋጭ),
					result  => q(አላ፟ጋጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላጋ),
					result  => q(አላ፟ጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላቆጠ),
					result  => q(አላቆ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላቃሽ),
					result  => q(አላ፟ቃሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላቀቀ),
					result  => q(አላ፟ቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላቀሰ),
					result  => q(አላ፟ቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላቀመ),
					result  => q(አላ፟ቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላሸቀ),
					result  => q(አላሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላሸ),
					result  => q(አላሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላሰነ),
					result  => q(አላ፟ሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላማኝ),
					result  => q(አላ፟ማኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላሚ),
					result  => q(አላ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላመጠ),
					result  => q(አላ፟መ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላመደ),
					result  => q(አላ፟መደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላመነ),
					result  => q(አላ፟መ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላላከ),
					result  => q(አላ፟ላከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላላም),
					result  => q(አላ፟ላም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አላላ),
					result  => q(አላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለፋጨቀ),
					result  => q(አለ፟ፋጨ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለፋ),
					result  => q(አለፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለፈበት),
					result  => q(አለ፟ፈበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለፈ),
					result  => q(አለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለጠለጠ),
					result  => q(አለጠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለጠ),
					result  => q(አለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለጐመ),
					result  => q(አለጐ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለጎመ),
					result  => q(አለጎ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለያየ),
					result  => q(አለ፟ያ፟የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለዘበ),
					result  => q(አለዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለው),
					result  => q(አለ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለከለከ),
					result  => q(አለከለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለኝታ),
					result  => q(አለ፟ኝ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለብኝ),
					result  => q(አለ፟ብ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለባበሰ),
					result  => q(አለባበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለበት),
					result  => q(አለ፟በት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለበሰ),
					result  => q(አለ፟በ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለበለዚያ),
					result  => q(አለበለ፟ዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለበ),
					result  => q(አለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለቅነት),
					result  => q(አለቅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለቃቀሰ),
					result  => q(አለቃቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለቃለቀ),
					result  => q(አለ፟ቃለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለቀሰ),
					result  => q(አለቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለቀመ),
					result  => q(አለቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለቀለቀ),
					result  => q(አለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለቀ),
					result  => q(አለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለሳለስ),
					result  => q(አለ፟ሳለስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለማመደ),
					result  => q(አለ፟ማመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለማመነ),
					result  => q(አለ፟ማመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለማለም),
					result  => q(አለ፟ማለ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለማ),
					result  => q(አለማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለመጠ),
					result  => q(አለመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለመደ),
					result  => q(አለመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለመለመ),
					result  => q(አለመለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለመ),
					result  => q(አለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለሎ),
					result  => q(አለሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለል),
					result  => q(አለል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለለ),
					result  => q(አለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለሁ),
					result  => q(አለ፟ሁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አለ),
					result  => q(አለ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አህያ),
					result  => q(አህያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሁንስ),
					result  => q(አሁንስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሁንም),
					result  => q(አሁንም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(አሁኑኑ),
					result  => q(አሁኑ፟ኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንፋሽ),
					result  => q(ንፋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንፊት),
					result  => q(ንፊ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንጽሕና),
					result  => q(ንጽሕና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንጹሕነት),
					result  => q(ንጹሕነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንግግር),
					result  => q(ንግግ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንግርት),
					result  => q(ንግ፟ርት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንግርተኛ),
					result  => q(ንግ፟ርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንግር),
					result  => q(ንግ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንገዳ),
					result  => q(ንገ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንዴት),
					result  => q(ንዴ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንዴታም),
					result  => q(ንዴ፟ታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንዴተኛ),
					result  => q(ንዴተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንዝራት),
					result  => q(ንዝ፟ራት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንኳቸ),
					result  => q(ንኳ፟ቸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንክክ),
					result  => q(ንክክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንክኪት),
					result  => q(ንክኪ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንክስ),
					result  => q(ንክ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንክሳት),
					result  => q(ንክ፟ሳት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንትርክ),
					result  => q(ንትር፟ክ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንብዝብዝ),
					result  => q(ንብዝብዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንብዝ),
					result  => q(ንብ፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንብብር),
					result  => q(ንብብ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንቅናቄ),
					result  => q(ንቅና፟ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንቅሳት),
					result  => q(ንቅ፟ሳት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንቅሳታም),
					result  => q(ንቅ፟ሳታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንቅል),
					result  => q(ንቅ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንቃይ),
					result  => q(ንቃ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንቃሽ),
					result  => q(ንቃ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ንስሐ),
					result  => q(ንስ፟ሐ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ናፈቀ),
					result  => q(ናፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ናዋዥ),
					result  => q(ናዋ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ናወዘ),
					result  => q(ናወ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ናኘ),
					result  => q(ናኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ናችሁ),
					result  => q(ናች፟ሁ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ናቸው),
					result  => q(ናቸ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ናሙና),
					result  => q(ናሙ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፍጠኛ),
					result  => q(ነፍጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፍናፋ),
					result  => q(ነፍናፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፍራቃ),
					result  => q(ነፍራቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፍላላ),
					result  => q(ነፍላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፋፋ),
					result  => q(ነፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፋፈሰ),
					result  => q(ነፋፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፋሻ),
					result  => q(ነፋ፟ሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፋ),
					result  => q(ነፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፊ),
					result  => q(ነፊ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፈገ),
					result  => q(ነፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፈነፈ),
					result  => q(ነፈነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፈሰበት),
					result  => q(ነፈ፟ሰበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፈሰ),
					result  => q(ነፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፈረቀ),
					result  => q(ነፈረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፈረ),
					result  => q(ነፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነፈለለ),
					result  => q(ነፈለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጻነት),
					result  => q(ነጻነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጐረ),
					result  => q(ነጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጋጋ),
					result  => q(ነጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጋገደ),
					result  => q(ነጋገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጋገረ),
					result  => q(ነጋገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጋድራስ),
					result  => q(ነጋ፟ድራስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጋዴ),
					result  => q(ነጋ፟ዴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነጋ),
					result  => q(ነጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነገደ),
					result  => q(ነገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነገረው),
					result  => q(ነገ፟ረው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነገረኝ),
					result  => q(ነገ፟ረኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነገረኛ),
					result  => q(ነገረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነገረ),
					result  => q(ነገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነገሠ),
					result  => q(ነገ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነዳደፈ),
					result  => q(ነዳደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነዳደለ),
					result  => q(ነዳደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነዳ),
					result  => q(ነዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነደፈ),
					result  => q(ነደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነደደ),
					result  => q(ነደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነደለ),
					result  => q(ነደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነዝናዛ),
					result  => q(ነዝናዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነዛ),
					result  => q(ነዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነዘነዘ),
					result  => q(ነዘነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነዘረ),
					result  => q(ነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነውረኛ),
					result  => q(ነውረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነኰተ),
					result  => q(ነኰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነክ),
					result  => q(ነክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነካካ),
					result  => q(ነካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነካከሰ),
					result  => q(ነካከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነካ),
					result  => q(ነካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነከተ),
					result  => q(ነከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነከስ),
					result  => q(ነከስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነከሰ),
					result  => q(ነከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነከረ),
					result  => q(ነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነኝ),
					result  => q(ነኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነኈለለ),
					result  => q(ነኈለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነኁላላ),
					result  => q(ነኁላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነተበ),
					result  => q(ነተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነተረከ),
					result  => q(ነተረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቦጨ),
					result  => q(ነቦ፟ጨ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነብርማ),
					result  => q(ነብርማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነባር),
					result  => q(ነባ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቢይ),
					result  => q(ነቢይ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነበዘ),
					result  => q(ነበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነበበ),
					result  => q(ነበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነበር),
					result  => q(ነበ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነበረ),
					result  => q(ነበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቈጠ),
					result  => q(ነቈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቃቃ),
					result  => q(ነቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቃቀፈ),
					result  => q(ነቃቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቃቀዘ),
					result  => q(ነቃቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቃቀለ),
					result  => q(ነቃቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቃ),
					result  => q(ነቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቀዘ),
					result  => q(ነቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቀሰ),
					result  => q(ነቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነቀለ),
					result  => q(ነቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነሸጠ),
					result  => q(ነሸ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነሳነሰ),
					result  => q(ነሳነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነሰነሰ),
					result  => q(ነሰነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነሰረ),
					result  => q(ነሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነረተ),
					result  => q(ነረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ነሣ),
					result  => q(ነሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኋለኛ),
					result  => q(ኋለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅጢአተኝነት),
					result  => q(ኅጢአተኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅጢአተኛ),
					result  => q(ኅጢአተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅዳግ),
					result  => q(ኅዳ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅይለኝነት),
					result  => q(ኅይለኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅይለኛ),
					result  => q(ኅይለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅያል),
					result  => q(ኅያ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅብረተሰብአዊነት),
					result  => q(ኅብረተሰብአዊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ኅሊና),
					result  => q(ኅሊ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችፍግ),
					result  => q(ችፍ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችፍቻፊ),
					result  => q(ችፍቻ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችፍርግ),
					result  => q(ችፍርግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችፍ),
					result  => q(ችፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችግኝ),
					result  => q(ችግ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችግር),
					result  => q(ችግ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችግረኛ),
					result  => q(ችግ፟ረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችኰላ),
					result  => q(ችኰ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችኮ),
					result  => q(ችኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችክል),
					result  => q(ችክ፟ል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችክ),
					result  => q(ችክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችኩል),
					result  => q(ችኩ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችቦ),
					result  => q(ችቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችስ),
					result  => q(ችስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ችላ),
					result  => q(ችላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸፍግ),
					result  => q(ቸፍ፟ግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸፈገ),
					result  => q(ቸፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸፈቸፈ),
					result  => q(ቸፈቸ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸገረ),
					result  => q(ቸገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸኳይ),
					result  => q(ቸኳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸኰለ),
					result  => q(ቸኰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸከለ),
					result  => q(ቸከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸነከረ),
					result  => q(ቸነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸብቸቦ),
					result  => q(ቸብቸቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸበቸበ),
					result  => q(ቸበቸ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸሰሰ),
					result  => q(ቸሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸርነት),
					result  => q(ቸርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸርቻማ),
					result  => q(ቸርቻማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸረቸረ),
					result  => q(ቸረቸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸረቸመ),
					result  => q(ቸረቸ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸልታ),
					result  => q(ቸል፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸልተኛ),
					result  => q(ቸል፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸል),
					result  => q(ቸል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸለሰ),
					result  => q(ቸለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቸለል),
					result  => q(ቸለል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቶስቷሳ),
					result  => q(ቶስቷሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትጥቅና),
					result  => q(ትጥቅና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትግያ),
					result  => q(ትግያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትግርኛ),
					result  => q(ትግርኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትግሥተኛ),
					result  => q(ትግሥተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትይዩ),
					result  => q(ትይዩ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትዝታ),
					result  => q(ትዝ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትዝብት),
					result  => q(ትዝ፟ብት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትዝ),
					result  => q(ትዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትዕይንት),
					result  => q(ትዕይ፟ንት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትውልድ),
					result  => q(ትውልድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትክዝ),
					result  => q(ትክ፟ዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትክት),
					result  => q(ትክ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትክል),
					result  => q(ትክ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትክለኛ),
					result  => q(ትክለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትክ),
					result  => q(ትክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትካዜ),
					result  => q(ትካ፟ዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትኩስ),
					result  => q(ትኩ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትኩሳት),
					result  => q(ትኩ፟ሳት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትከሻም),
					result  => q(ትከሻ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትከሻማ),
					result  => q(ትከሻ፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትከሻ),
					result  => q(ትከሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትእግሥተኛ),
					result  => q(ትእግሥተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትእቢተኛ),
					result  => q(ትእቢተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትንፋሽ),
					result  => q(ትንፋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትንኝ),
					result  => q(ትንኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትንቢተኛ),
					result  => q(ትንቢተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትንሽ),
					result  => q(ትን፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትናጋ),
					result  => q(ትና፟ጋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትናንትና),
					result  => q(ትናንትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትችት),
					result  => q(ትች፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትብትብ),
					result  => q(ትብትብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትብብር),
					result  => q(ትብብ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትቢያ),
					result  => q(ትቢ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትቢተኛ),
					result  => q(ትቢተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትሻለህ),
					result  => q(ትሻለ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትርኳሽ),
					result  => q(ትርኳ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትርክክ),
					result  => q(ትርክክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትርታ),
					result  => q(ትር፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትርምስ),
					result  => q(ትርም፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትር),
					result  => q(ትር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትራፊ),
					result  => q(ትራ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትምክህተኛ),
					result  => q(ትምክህተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትምትም),
					result  => q(ትምትም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትምቡሽ),
					result  => q(ትምቡሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትሕትና),
					result  => q(ትሕትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትልቅነት),
					result  => q(ትል፟ቅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትልቅ),
					result  => q(ትል፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትላንትና),
					result  => q(ትላንትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ትሉግሉግ),
					result  => q(ትሉግሉግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቴፕ),
					result  => q(ቴፕ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቴሌስኮፕ),
					result  => q(ቴሌስኮፕ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታፋሪ),
					result  => q(ታፋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታፈገ),
					result  => q(ታፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታፈነ),
					result  => q(ታፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታፈረ),
					result  => q(ታፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታጐረ),
					result  => q(ታጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታጋሽ),
					result  => q(ታጋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታገደ),
					result  => q(ታገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታገሠ),
					result  => q(ታገ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታገለ),
					result  => q(ታገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታጀበ),
					result  => q(ታጀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታጀለ),
					result  => q(ታጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዳጊ),
					result  => q(ታዳ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዲያስ),
					result  => q(ታዲያስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዲያሳ),
					result  => q(ታዲያሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታደገ),
					result  => q(ታደ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታደመ),
					result  => q(ታደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታደለ),
					result  => q(ታደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታየ),
					result  => q(ታየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዛዥ),
					result  => q(ታዛ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዛቢ),
					result  => q(ታዛ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዘዘ),
					result  => q(ታዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዘበ),
					result  => q(ታዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታዘለ),
					result  => q(ታዘ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታወከ),
					result  => q(ታወ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታወቀ),
					result  => q(ታወ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታወሰው),
					result  => q(ታወ፟ሰው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታወረ),
					result  => q(ታወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታካሚ),
					result  => q(ታካ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታከከ),
					result  => q(ታከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታከተ),
					result  => q(ታከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታከመ),
					result  => q(ታከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታከለ),
					result  => q(ታከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታኘከ),
					result  => q(ታኘ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታንከኛ),
					result  => q(ታንከኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታናሽ),
					result  => q(ታና፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታነጠ),
					result  => q(ታነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታነቀ),
					result  => q(ታነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታታ),
					result  => q(ታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታተተ),
					result  => q(ታተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታተረ),
					result  => q(ታተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታተመ),
					result  => q(ታተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታበየ),
					result  => q(ታበ፟የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታበለ),
					result  => q(ታበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታቀፈ),
					result  => q(ታቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታቀደ),
					result  => q(ታቀ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታሸገ),
					result  => q(ታሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታሸመ),
					result  => q(ታሸ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታሸ),
					result  => q(ታሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታስቦ),
					result  => q(ታስ፟ቦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታሰበ),
					result  => q(ታሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታሪከኛ),
					result  => q(ታሪከኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታረደ),
					result  => q(ታረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታረዘ),
					result  => q(ታረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታረቀ),
					result  => q(ታረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታረሰ),
					result  => q(ታረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታረመ),
					result  => q(ታረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታሠረ),
					result  => q(ታሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታሠሠ),
					result  => q(ታሠ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታምር),
					result  => q(ታም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታምራታዊ),
					result  => q(ታም፟ራታዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታምረኛ),
					result  => q(ታም፟ረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታማኝ),
					result  => q(ታማ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታማ),
					result  => q(ታማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታመነ),
					result  => q(ታመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታመቀ),
					result  => q(ታመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታመሰ),
					result  => q(ታመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታመመ),
					result  => q(ታመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታላቅ),
					result  => q(ታላ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታለፈ),
					result  => q(ታለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ታለበ),
					result  => q(ታለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱፋሕ),
					result  => q(ቱፋ፟ሕ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱግ),
					result  => q(ቱግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱታ),
					result  => q(ቱታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱቦ),
					result  => q(ቱቦ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱባ),
					result  => q(ቱባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱሽ),
					result  => q(ቱሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱስ),
					result  => q(ቱስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቱር),
					result  => q(ቱር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፎካከረ),
					result  => q(ተፎካከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፍታታ),
					result  => q(ተፍታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፍረጠረጠ),
					result  => q(ተፍረጠረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፍረከረከ),
					result  => q(ተፍረከረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፍረቀረቀ),
					result  => q(ተፍረቀረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፍለከለከ),
					result  => q(ተፍለከለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፍለቀለቀ),
					result  => q(ተፍለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፍ),
					result  => q(ተፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፌ),
					result  => q(ተፌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋፈገ),
					result  => q(ተፋፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋፈነ),
					result  => q(ተፋፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋጀ),
					result  => q(ተፋጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋዘዘ),
					result  => q(ተፋዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋታ),
					result  => q(ተፋታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋተገ),
					result  => q(ተፋተ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋቀረ),
					result  => q(ተፋቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋሰሰ),
					result  => q(ተፋሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋረደ),
					result  => q(ተፋረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋረሰ),
					result  => q(ተፋረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋለሰ),
					result  => q(ተፋለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋለመ),
					result  => q(ተፋለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፋ),
					result  => q(ተፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈጋፈገ),
					result  => q(ተፈጋፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈገፈገ),
					result  => q(ተፈገፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈጀ),
					result  => q(ተፈጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈወሰ),
					result  => q(ተፈወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈናፈነ),
					result  => q(ተፈናፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈናከተ),
					result  => q(ተፈናከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈናቀለ),
					result  => q(ተፈናቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈነገለ),
					result  => q(ተፈነገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈነከተ),
					result  => q(ተፈነከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈነቸረ),
					result  => q(ተፈነቸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈነቀለ),
					result  => q(ተፈነቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈታኝ),
					result  => q(ተፈታ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈታተነ),
					result  => q(ተፈታ፟ተነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈታተሸ),
					result  => q(ተፈታተ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈታ),
					result  => q(ተፈታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈተገ),
					result  => q(ተፈተ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈተነ),
					result  => q(ተፈተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈተሸ),
					result  => q(ተፈተ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈተለከ),
					result  => q(ተፈተለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈተለ),
					result  => q(ተፈተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈቃቀደ),
					result  => q(ተፈቃቀ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈቃቀረ),
					result  => q(ተፈቃቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈራራ),
					result  => q(ተፈራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈራረመ),
					result  => q(ተፈራረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈራ),
					result  => q(ተፈራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈረፈረ),
					result  => q(ተፈረፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈረደ),
					result  => q(ተፈረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈረከሰ),
					result  => q(ተፈረከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈረመ),
					result  => q(ተፈረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈላጭ),
					result  => q(ተፈላ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈላጊ),
					result  => q(ተፈላ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈላሰፈ),
					result  => q(ተፈላሰ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈላለገ),
					result  => q(ተፈላለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈላ),
					result  => q(ተፈላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈለፈለ),
					result  => q(ተፈለፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈለጠ),
					result  => q(ተፈለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈለገ),
					result  => q(ተፈለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፈለቀቀ),
					result  => q(ተፈለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተፀነሰ),
					result  => q(ተፀነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጽናና),
					result  => q(ተጽናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጻረረ),
					result  => q(ተጻረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጸዳዳ),
					result  => q(ተጸዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጸየፈ),
					result  => q(ተጸየ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጸናወተ),
					result  => q(ተጸናወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጸለየ),
					result  => q(ተጸለ፟የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጭበረበረ),
					result  => q(ተጭበረበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጫፈረ),
					result  => q(ተጫፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጫወተበት),
					result  => q(ተጫወ፟ተበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጫወተ),
					result  => q(ተጫወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጫረሰ),
					result  => q(ተጫ፟ረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጫማ),
					result  => q(ተጫማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨፋፈቀ),
					result  => q(ተጨፋፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨፋጨፈ),
					result  => q(ተጨፋጨ፟ፈ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨፈለቀ),
					result  => q(ተጨፈለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨዋወተ),
					result  => q(ተጨዋወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨካከነ),
					result  => q(ተጨካከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨናጎለ),
					result  => q(ተጨናጎ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨናገፈ),
					result  => q(ተጨናገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨናነቀ),
					result  => q(ተጨናነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨነቀ),
					result  => q(ተጨነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨባጭ),
					result  => q(ተጨባ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨባበጡ),
					result  => q(ተጨባበ፟ጡ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨባበጠ),
					result  => q(ተጨባበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨበጨበለት),
					result  => q(ተጨበጨ፟በለ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨበተ),
					result  => q(ተጨበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨቋኝ),
					result  => q(ተጨቋ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨቆነ),
					result  => q(ተጨቆ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨራመደ),
					result  => q(ተጨራመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨራመተ),
					result  => q(ተጨራመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨራመመ),
					result  => q(ተጨራመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨረሰ),
					result  => q(ተጨ፟ረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨማደደ),
					result  => q(ተጨማደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨማተረ),
					result  => q(ተጨማተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨማሪ),
					result  => q(ተጨማ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨማለቀ),
					result  => q(ተጨማለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨመታተረ),
					result  => q(ተጨመታተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨመቀ),
					result  => q(ተጨመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨመረ),
					result  => q(ተጨ፟መ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨመላለቀ),
					result  => q(ተጨመላለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጨለጠ),
					result  => q(ተጨለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጧጧፈ),
					result  => q(ተጧጧ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጥናና),
					result  => q(ተጥናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጥመዘመዘ),
					result  => q(ተጥመዘመ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጥመሰመሰ),
					result  => q(ተጥመሰመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጥመለመለ),
					result  => q(ተጥመለመ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጥለቀለቀ),
					result  => q(ተጥለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣፋ),
					result  => q(ተጣፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣዳ),
					result  => q(ተጣዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣደፈ),
					result  => q(ተጣደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣባ),
					result  => q(ተጣባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣበበ),
					result  => q(ተጣበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣበቀ),
					result  => q(ተጣበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣራ),
					result  => q(ተጣራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣረረ),
					result  => q(ተጣረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣመደ),
					result  => q(ተጣመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣመረ),
					result  => q(ተጣመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣመመ),
					result  => q(ተጣመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጣላ),
					result  => q(ተጣ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠፋፋ),
					result  => q(ተጠፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠጋጋ),
					result  => q(ተጠጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠጋገነ),
					result  => q(ተጠጋገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠጋ),
					result  => q(ተጠጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠያፊ),
					result  => q(ተጠያ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠያየቀ),
					result  => q(ተጠያየ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠያቂ),
					result  => q(ተጠያ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠየፈ),
					result  => q(ተጠየ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠየቅ),
					result  => q(ተጠየ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠየቀ),
					result  => q(ተጠየ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠናወተ),
					result  => q(ተጠናወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠናከረ),
					result  => q(ተጠናከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠናበሰ),
					result  => q(ተጠናበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠናቆለ),
					result  => q(ተጠናቆ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠናቀቀ),
					result  => q(ተጠናቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠና),
					result  => q(ተጠና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠነቀቀ),
					result  => q(ተጠነቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠባበቀ),
					result  => q(ተጠባበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠበበ),
					result  => q(ተጠበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠበቀ),
					result  => q(ተጠበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠቆመ),
					result  => q(ተጠቆ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠቃቀሰ),
					result  => q(ተጠቃቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠቃሽ),
					result  => q(ተጠቃ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠቃሚ),
					result  => q(ተጠቃ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠቃለለ),
					result  => q(ተጠቃለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠቃ),
					result  => q(ተጠቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠቀመ),
					result  => q(ተጠቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠራቀመ),
					result  => q(ተጠራቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠራ),
					result  => q(ተጠራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠረቃቀመ),
					result  => q(ተጠረቃቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠረመሰ),
					result  => q(ተጠረመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠማዘዘ),
					result  => q(ተጠማዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠማ),
					result  => q(ተጠማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠመደ),
					result  => q(ተጠመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠመዘዘ),
					result  => q(ተጠመዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠመቀ),
					result  => q(ተጠመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠላላፊ),
					result  => q(ተጠላላ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠላ),
					result  => q(ተጠላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠለፈ),
					result  => q(ተጠለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጠለለ),
					result  => q(ተጠለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጕመጠመጠ),
					result  => q(ተጕመጠመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጓደደ),
					result  => q(ተጓደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጓደለ),
					result  => q(ተጓደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጓተተ),
					result  => q(ተጓተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐናዘለ),
					result  => q(ተጐናዘ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐነጐነ),
					result  => q(ተጐነጐ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐታች),
					result  => q(ተጐታ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐተተ),
					result  => q(ተጐተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐሳቈለ),
					result  => q(ተጐሳቈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐላደፈ),
					result  => q(ተጐላደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐላመመ),
					result  => q(ተጐላመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጐለተ),
					result  => q(ተጐለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጎዳኘ),
					result  => q(ተጎዳኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጎዳ),
					result  => q(ተጎዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጎራበተ),
					result  => q(ተጎራበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጎማዘዘ),
					result  => q(ተጎማዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጎማለለ),
					result  => q(ተጎማለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተግፈለፈለ),
					result  => q(ተግፈለፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተግደረደረ),
					result  => q(ተግደረደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተግተረተረ),
					result  => q(ተግተረተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተግተለተለ),
					result  => q(ተግተለተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተግባባ),
					result  => q(ተግባባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተግማማ),
					result  => q(ተግማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተግ),
					result  => q(ተግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋፋ),
					result  => q(ተጋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋፈጠ),
					result  => q(ተጋፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋገዘ),
					result  => q(ተጋገ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋገረ),
					result  => q(ተጋገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋደለ),
					result  => q(ተጋደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋዛ),
					result  => q(ተጋዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋዘ),
					result  => q(ተጋዘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋነነ),
					result  => q(ተጋነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋተረ),
					result  => q(ተጋተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋባ),
					result  => q(ተጋባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋበዘ),
					result  => q(ተጋበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋራ),
					result  => q(ተጋራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋረጠ),
					result  => q(ተጋረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋረደ),
					result  => q(ተጋረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋማ),
					result  => q(ተጋማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋመሰ),
					result  => q(ተጋመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋለጠ),
					result  => q(ተጋለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጋ),
					result  => q(ተጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጉረበረበ),
					result  => q(ተጉረበረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጉመጠመጠ),
					result  => q(ተጉመጠመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገፋፋ),
					result  => q(ተገፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገፋተረ),
					result  => q(ተገፋተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገፋ),
					result  => q(ተገፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገፈፈ),
					result  => q(ተገፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገደደ),
					result  => q(ተገደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገደለ),
					result  => q(ተገደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገዛዛ),
					result  => q(ተገዛ፟ዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገዛ),
					result  => q(ተገዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገዘተ),
					result  => q(ተገዘ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገኘ),
					result  => q(ተገኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገናዘበ),
					result  => q(ተገናዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገናኘ),
					result  => q(ተገናኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገነጣጠለ),
					result  => q(ተገነጣጠ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገነዘበ),
					result  => q(ተገነዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገታተረ),
					result  => q(ተገታተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገታ),
					result  => q(ተገታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገባደደ),
					result  => q(ተገባደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገቢ),
					result  => q(ተገቢ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገበያየ),
					result  => q(ተገበያየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገሸረ),
					result  => q(ተገሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገሸለጠ),
					result  => q(ተገሸለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገሰሰ),
					result  => q(ተገሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገራ),
					result  => q(ተገራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገረፈ),
					result  => q(ተገረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገረዘ),
					result  => q(ተገረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገረመ),
					result  => q(ተገረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገመገመ),
					result  => q(ተገመገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገመደለ),
					result  => q(ተገመደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገመተ),
					result  => q(ተገመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገመሰ),
					result  => q(ተገመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገላገለ),
					result  => q(ተገላገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገላበጠ),
					result  => q(ተገላበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገላመጠ),
					result  => q(ተገላመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገለፈፈ),
					result  => q(ተገለፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገለጠ),
					result  => q(ተገለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገለባበጠ),
					result  => q(ተገለባበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገለበጠ),
					result  => q(ተገለበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገለማመጠ),
					result  => q(ተገለማመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተገለለ),
					result  => q(ተገለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጀነነ),
					result  => q(ተጀነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተጀመረ),
					result  => q(ተጀመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተድፈነፈነ),
					result  => q(ተድፈነፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተድቦለቦለ),
					result  => q(ተድቦለቦ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተድበሰበሰ),
					result  => q(ተድበሰበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተድበለበለ),
					result  => q(ተድበለበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተድረቀረቀ),
					result  => q(ተድረቀረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳፋ),
					result  => q(ተዳፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳፈነ),
					result  => q(ተዳፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳፈቀ),
					result  => q(ተዳፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳፈረ),
					result  => q(ተዳፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳደረ),
					result  => q(ተዳደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳከመ),
					result  => q(ተዳከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳኘ),
					result  => q(ተዳኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳነቀ),
					result  => q(ተዳነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳበለ),
					result  => q(ተዳበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳቀቀ),
					result  => q(ተዳቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳቀለ),
					result  => q(ተዳቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳራ),
					result  => q(ተዳራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳረገ),
					result  => q(ተዳረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳረቀ),
					result  => q(ተዳረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳረሰ),
					result  => q(ተዳረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳመጠ),
					result  => q(ተዳመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዳመረ),
					result  => q(ተዳመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደፋፈረ),
					result  => q(ተደፋፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደፋ),
					result  => q(ተደፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደፈነ),
					result  => q(ተደፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደፈቀ),
					result  => q(ተደፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደፈረ),
					result  => q(ተደፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደጎመ),
					result  => q(ተደጎ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደጋገፈ),
					result  => q(ተደጋገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደጋገመ),
					result  => q(ተደጋገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደገፈ),
					result  => q(ተደገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደገነ),
					result  => q(ተደገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደገሰ),
					result  => q(ተደገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደገመ),
					result  => q(ተደገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደወለ),
					result  => q(ተደወ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደከመ),
					result  => q(ተደከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደናገጠ),
					result  => q(ተደናገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደናገረ),
					result  => q(ተደና፟ገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደናበዘ),
					result  => q(ተደናበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደናበረ),
					result  => q(ተደናበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደናቂ),
					result  => q(ተደና፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደናቀፈ),
					result  => q(ተደናቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደነቀረብኝ),
					result  => q(ተደነቀ፟ረብኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደነቀረ),
					result  => q(ተደነቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደነቀ),
					result  => q(ተደነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደባደበ),
					result  => q(ተደባደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደባበቀ),
					result  => q(ተደባበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደባለቀ),
					result  => q(ተደባለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደበደበ),
					result  => q(ተደበደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደበቀ),
					result  => q(ተደበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደበላለቀ),
					result  => q(ተደበላለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደበለቀ),
					result  => q(ተደበለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደበለለ),
					result  => q(ተደበለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደቆሰ),
					result  => q(ተደቆ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደቀነ),
					result  => q(ተደቀ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደሳች),
					result  => q(ተደሳ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደሰተ),
					result  => q(ተደሰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደራጊ),
					result  => q(ተደራ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደራጀ),
					result  => q(ተደራጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደራደረ),
					result  => q(ተደራደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደራቢ),
					result  => q(ተደራ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደራረገ),
					result  => q(ተደራረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደራረበ),
					result  => q(ተደራረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደረገመ),
					result  => q(ተደረገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደረገ),
					result  => q(ተደረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደረደረ),
					result  => q(ተደረደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደረተ),
					result  => q(ተደረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደረበ),
					result  => q(ተደረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደረሰመ),
					result  => q(ተደረሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደረሰ),
					result  => q(ተደረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደማጭ),
					result  => q(ተደማ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደማሪ),
					result  => q(ተደማ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደማመጠ),
					result  => q(ተደማመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደመጠ),
					result  => q(ተደመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደመደመ),
					result  => q(ተደመደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደመሰሰ),
					result  => q(ተደመሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደመረ),
					result  => q(ተደመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደመመ),
					result  => q(ተደመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደላደለ),
					result  => q(ተደላደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደለደለ),
					result  => q(ተደለደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደለቀ),
					result  => q(ተደ፟ለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተደለለ),
					result  => q(ተደለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተያየ),
					result  => q(ተያየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዥጎደጎደ),
					result  => q(ተዥጎደጎ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዥጎረገረ),
					result  => q(ተዥጎረገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዠለጠ),
					result  => q(ተዠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝጐረጐረ),
					result  => q(ተዝጐረጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝጎረጎረ),
					result  => q(ተዝጎረጎ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝናና),
					result  => q(ተዝናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝረፈረፈ),
					result  => q(ተዝረፈረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝረጠረጠ),
					result  => q(ተዝረጠረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝረከረከ),
					result  => q(ተዝረከረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝረበረበ),
					result  => q(ተዝረበረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝለፈለፈ),
					result  => q(ተዝለፈለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዝለገለገ),
					result  => q(ተዝለገለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛፈቀ),
					result  => q(ተዛፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛዘነ),
					result  => q(ተዛዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛዘበ),
					result  => q(ተዛዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛወረ),
					result  => q(ተዛወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛናና),
					result  => q(ተዛናና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛና),
					result  => q(ተዛና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛነፈ),
					result  => q(ተዛነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛነቀ),
					result  => q(ተዛነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛባ),
					result  => q(ተዛ፟ባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛመደ),
					result  => q(ተዛመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛመተ),
					result  => q(ተዛመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛለፈ),
					result  => q(ተዛለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዛለለ),
					result  => q(ተዛለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘፈዘፈ),
					result  => q(ተዘፈዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘፈቀ),
					result  => q(ተዘፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘጋጀ),
					result  => q(ተዘጋጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘጋ),
					result  => q(ተዘ፟ጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘገጃጀ),
					result  => q(ተዘገጃጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘገረረ),
					result  => q(ተዘገረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘያየረ),
					result  => q(ተዘያየ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘዋወረ),
					result  => q(ተዘዋወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘወተረ),
					result  => q(ተዘወተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘካሪ),
					result  => q(ተዘካ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘከዘከ),
					result  => q(ተዘከዘ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘከረ),
					result  => q(ተዘከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘናፈለ),
					result  => q(ተዘናፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘናጋ),
					result  => q(ተዘናጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘናከተ),
					result  => q(ተዘናከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘነጋጋ),
					result  => q(ተዘነጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘነጋ),
					result  => q(ተዘነጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘነተረ),
					result  => q(ተዘነተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘነቀ),
					result  => q(ተዘነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘባነነ),
					result  => q(ተዘባነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘባበተ),
					result  => q(ተዘባበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘባረቀ),
					result  => q(ተዘባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘበራረቀ),
					result  => q(ተዘበራረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘቀዘቀ),
					result  => q(ተዘቀዘ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘራረፈ),
					result  => q(ተዘራረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘራ),
					result  => q(ተዘራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረፈጠ),
					result  => q(ተዘረፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረፈ),
					result  => q(ተዘረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረጋ),
					result  => q(ተዘረጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረገፈ),
					result  => q(ተዘረገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረዘረ),
					result  => q(ተዘረዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረካከተ),
					result  => q(ተዘረካከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረከተ),
					result  => q(ተዘረከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረነቀ),
					result  => q(ተዘረ፟ነቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘረረ),
					result  => q(ተዘረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘመዘመ),
					result  => q(ተዘመዘ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘለቀ),
					result  => q(ተዘለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዘለለ),
					result  => q(ተዘለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተውተፈተፈ),
					result  => q(ተውተፈተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተውተበተበ),
					result  => q(ተውተበተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተውተረተረ),
					result  => q(ተውተረተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተውረገረገ),
					result  => q(ተውረገረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተውለበለበ),
					result  => q(ተውለበለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋጋ),
					result  => q(ተዋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋደደ),
					result  => q(ተዋደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋደቀ),
					result  => q(ተዋደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋወቀ),
					result  => q(ተዋወ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋከበ),
					result  => q(ተዋከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋቀሰ),
					result  => q(ተዋቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋቀረ),
					result  => q(ተዋቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋሰነ),
					result  => q(ተዋሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋረደ),
					result  => q(ተዋረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋልቀ),
					result  => q(ተዋል፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተዋለደ),
					result  => q(ተዋለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወጫመደ),
					result  => q(ተወጫመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወጋ),
					result  => q(ተወጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወገደ),
					result  => q(ተወገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወገረ),
					result  => q(ተወገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወዳጅ),
					result  => q(ተወዳ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወዳጀ),
					result  => q(ተወዳጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወዳደረ),
					result  => q(ተወዳደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወደደ),
					result  => q(ተወደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወዛወዘ),
					result  => q(ተወዛወ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወዘፈ),
					result  => q(ተወዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወካይ),
					result  => q(ተወካ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወከለ),
					result  => q(ተወከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወንጀለ),
					result  => q(ተወንጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወናፈለ),
					result  => q(ተወናፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወናበደ),
					result  => q(ተወናበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወነጃጀለ),
					result  => q(ተወነጃጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወነባበደ),
					result  => q(ተወነባበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወተፈ),
					result  => q(ተወተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወቃቀሰ),
					result  => q(ተወቃቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወቃ),
					result  => q(ተወቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወቀጠ),
					result  => q(ተወቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወቀሰ),
					result  => q(ተወቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወሳ),
					result  => q(ተወሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወሰደ),
					result  => q(ተወሰ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወሰወሰ),
					result  => q(ተወሰወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወሰነ),
					result  => q(ተወሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወራጅ),
					result  => q(ተወራ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወራወረ),
					result  => q(ተወራወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወራሽ),
					result  => q(ተወራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወራረደ),
					result  => q(ተወራረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወራረሰ),
					result  => q(ተወራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወራ),
					result  => q(ተወራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወረደ),
					result  => q(ተወረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወረወረ),
					result  => q(ተወረወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወረሰ),
					result  => q(ተወረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወረረ),
					result  => q(ተወረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወላገደ),
					result  => q(ተወላገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወላጅ),
					result  => q(ተወላ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወላከፈ),
					result  => q(ተወላከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወላመመ),
					result  => q(ተወላመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወለጋገደ),
					result  => q(ተወለጋገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተወለደ),
					result  => q(ተወለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኳኰሰ),
					result  => q(ተኳኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኳሽነት),
					result  => q(ተኳሽነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኳሽ),
					result  => q(ተኳ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኳረፈ),
					result  => q(ተኳረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኰነነ),
					result  => q(ተኰነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኰሳተረ),
					result  => q(ተኰሳተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኰሰ),
					result  => q(ተኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኰረታተመ),
					result  => q(ተኰረታተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኰረተመ),
					result  => q(ተኰረተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኰላተፈ),
					result  => q(ተኰላተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮፋሽ),
					result  => q(ተኮፋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮፈሰ),
					result  => q(ተኮፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮተኮተ),
					result  => q(ተኮተኮ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮሳተረ),
					result  => q(ተኮሳተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮራፊ),
					result  => q(ተኮራ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮራመተ),
					result  => q(ተኮራመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮረፈ),
					result  => q(ተኮረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮረጀ),
					result  => q(ተኮረ፟ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮረተመ),
					result  => q(ተኮረተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮማተረ),
					result  => q(ተኮማተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኮላሸ),
					result  => q(ተኮላሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተክበሰበሰ),
					result  => q(ተክበሰበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተክለፈለፈ),
					result  => q(ተክለፈለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካፈተ),
					result  => q(ተካፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካፈለ),
					result  => q(ተካፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካዥ),
					result  => q(ተካ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካከለ),
					result  => q(ተካ፟ከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካበደ),
					result  => q(ተካበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካሰሰ),
					result  => q(ተካሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካረረ),
					result  => q(ተካረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካለሰ),
					result  => q(ተካለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካለለ),
					result  => q(ተካለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተካ),
					result  => q(ተካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኩነሰነሰ),
					result  => q(ተኩነሰነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኩስ),
					result  => q(ተኩ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኩራራ),
					result  => q(ተኩራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኩረፈረፈ),
					result  => q(ተኩረፈረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፋፈተ),
					result  => q(ተከፋፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፋፈለ),
					result  => q(ተከፋፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፋይ),
					result  => q(ተከፋ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፋች),
					result  => q(ተከፋ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፋ),
					result  => q(ተከፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፈፈ),
					result  => q(ተከፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፈከፈ),
					result  => q(ተከፈከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፈነ),
					result  => q(ተከፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፈተ),
					result  => q(ተከፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከፈለ),
					result  => q(ተከፈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከደነ),
					result  => q(ተከደ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከዘ),
					result  => q(ተከ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከካ),
					result  => q(ተከካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከናወነ),
					result  => q(ተከናወ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከናነበ),
					result  => q(ተከናነ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከነ),
					result  => q(ተከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከታይ),
					result  => q(ተከታ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከታከተ),
					result  => q(ተከታከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከታተለ),
					result  => q(ተከታተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተፈ),
					result  => q(ተከተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተከተ),
					result  => q(ተከተከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተከ),
					result  => q(ተከተ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተተ),
					result  => q(ተከተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተበ),
					result  => q(ተከተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተረ),
					result  => q(ተከተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተል),
					result  => q(ተከተ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተለበ),
					result  => q(ተከተለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከተለ),
					result  => q(ተከተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከባበረ),
					result  => q(ተከባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከበበ),
					result  => q(ተከበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከበረ),
					result  => q(ተከበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከሳከሰ),
					result  => q(ተከሳከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከሳሽ),
					result  => q(ተከሳ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከሰከሰ),
					result  => q(ተከሰከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከሰሰ),
					result  => q(ተከሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከራየ),
					result  => q(ተከራየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከራከረ),
					result  => q(ተከራከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከረከመ),
					result  => q(ተከረከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከረተፈ),
					result  => q(ተከረተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከረበተ),
					result  => q(ተከረበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከሠተ),
					result  => q(ተከሠ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከማቸ),
					result  => q(ተከማ፟ቸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከመከመ),
					result  => q(ተከመከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከመቻቸ),
					result  => q(ተከመቻቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከላከለ),
					result  => q(ተከላከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከለከለ),
					result  => q(ተከለከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከለበሰ),
					result  => q(ተከለበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከለሰ),
					result  => q(ተከለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከለለ),
					result  => q(ተከለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተከለ),
					result  => q(ተከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተአምር),
					result  => q(ተአም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተአምራታዊ),
					result  => q(ተአም፟ራታዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተአምረኛ),
					result  => q(ተአም፟ረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኝቷል),
					result  => q(ተኝ፟ቷል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኝቶ),
					result  => q(ተኝ፟ቶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኛት),
					result  => q(ተኛ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተኛ),
					result  => q(ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፏፏ),
					result  => q(ተንፏፏ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፏቀቀ),
					result  => q(ተንፏቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፋነፈ),
					result  => q(ተንፋነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፈቀፈቀ),
					result  => q(ተንፈቀፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፈስ),
					result  => q(ተንፈስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፈራፈረ),
					result  => q(ተንፈራፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፈራገጠ),
					result  => q(ተንፈራገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንፈላሰሰ),
					result  => q(ተንፈላሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጸባረቀ),
					result  => q(ተንጸባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጣለለ),
					result  => q(ተንጣለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጠራወዘ),
					result  => q(ተንጠራወ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጠራራ),
					result  => q(ተንጠራ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጠረዘዘ),
					result  => q(ተንጠረዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጠረበበ),
					result  => q(ተንጠረበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጓደደ),
					result  => q(ተንጓደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጓለለ),
					result  => q(ተንጓለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጐራደደ),
					result  => q(ተንጐራደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጎራደደ),
					result  => q(ተንጎራደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጋጋ),
					result  => q(ተንጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጋደደ),
					result  => q(ተንጋደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጋለለ),
					result  => q(ተንጋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገፈገፈ),
					result  => q(ተንገፈገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገጫገጨ),
					result  => q(ተንገጫገ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገዳገደ),
					result  => q(ተንገዳገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገደገደ),
					result  => q(ተንገደገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገዋለለ),
					result  => q(ተንገዋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገበገበ),
					result  => q(ተንገበገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገሸገሸ),
					result  => q(ተንገሸገ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገረገበ),
					result  => q(ተንገረገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገላጀጀ),
					result  => q(ተንገላጀ፟ጀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገላወደ),
					result  => q(ተንገላወ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንገላታ),
					result  => q(ተንገላታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጀረገገ),
					result  => q(ተንጀረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንጀላጀለ),
					result  => q(ተንጀላጀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዶለዶለ),
					result  => q(ተንዶለዶ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደፋደፈ),
					result  => q(ተንደፋደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደከደ),
					result  => q(ተንደከ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደባደበ),
					result  => q(ተንደባደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደባለለ),
					result  => q(ተንደባለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደበደበ),
					result  => q(ተንደበደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደቀደቀ),
					result  => q(ተንደቀደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደረደረ),
					result  => q(ተንደረደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደረከከ),
					result  => q(ተንደረከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደረበበ),
					result  => q(ተንደረበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንደላቀቀ),
					result  => q(ተንደላቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዣበበ),
					result  => q(ተንዣበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዠባረረ),
					result  => q(ተንዠባረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዠቀዠቀ),
					result  => q(ተንዠቀዠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዠረገገ),
					result  => q(ተንዠረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዛዛ),
					result  => q(ተንዛዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዘፈዘፈ),
					result  => q(ተንዘፈ፟ዘፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዘራፈጠ),
					result  => q(ተንዘራፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዘረፈፈ),
					result  => q(ተንዘረፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንዘረፈጠ),
					result  => q(ተንዘረፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንኳፈፈ),
					result  => q(ተንኳፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንኳኳ),
					result  => q(ተንኳኳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንኮለኛ),
					result  => q(ተንኮለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከፈረረ),
					result  => q(ተንከፈረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከዋተተ),
					result  => q(ተንከዋተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከታከተ),
					result  => q(ተንከታከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከተከተ),
					result  => q(ተንከተከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከባከበ),
					result  => q(ተንከባከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከባለለ),
					result  => q(ተንከባለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከራተተ),
					result  => q(ተንከራተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከረፈፈ),
					result  => q(ተንከረፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንከላወሰ),
					result  => q(ተንከላወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቻቻ),
					result  => q(ተንቻቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቶሰቶሰ),
					result  => q(ተንቶሰቶ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንተከተከ),
					result  => q(ተንተከተ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንተባተበ),
					result  => q(ተንተባተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንተረከከ),
					result  => q(ተንተረከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቦጫቦጨ),
					result  => q(ተንቦጫቦ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቦጫበጨ),
					result  => q(ተንቦጫበ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቦጨቦጨ),
					result  => q(ተንቦጨቦ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቦገቦገ),
					result  => q(ተንቦገቦ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቦራቀቀ),
					result  => q(ተንቦራቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቦረቀቀ),
					result  => q(ተንቦረቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቦለቦለ),
					result  => q(ተንቦለቦ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንበሸበሸ),
					result  => q(ተንበሸ፟በ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንበረከከ),
					result  => q(ተንበረከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንበለበለ),
					result  => q(ተንበለበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀፈደደ),
					result  => q(ተንቀፈደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀጠቀጠ),
					result  => q(ተንቀጠቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀዠቀዠ),
					result  => q(ተንቀዠቀ፟ዠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀዋለለ),
					result  => q(ተንቀዋለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀባደደ),
					result  => q(ተንቀባደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀባረረ),
					result  => q(ተንቀባረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀበደደ),
					result  => q(ተንቀበደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀበቀበ),
					result  => q(ተንቀበቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀሳቀሰ),
					result  => q(ተንቀሳቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀረፈፈ),
					result  => q(ተንቀረፈ፟ፈ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀረበበ),
					result  => q(ተንቀረበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንቀለቀለ),
					result  => q(ተንቀለቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሻተተ),
					result  => q(ተንሻተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሸዋረረ),
					result  => q(ተንሸዋረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሸራተተ),
					result  => q(ተንሸራተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሸረሸረ),
					result  => q(ተንሸረሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሶለሶለ),
					result  => q(ተንሶለሶ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሳፈፈ),
					result  => q(ተንሳፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሰፈሰፈ),
					result  => q(ተንሰፈሰ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሰቀሰቀ),
					result  => q(ተንሰቀሰ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተንሠቀሠቀ),
					result  => q(ተንሠቀሠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተን),
					result  => q(ተን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናፋ),
					result  => q(ተናፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናፈጠ),
					result  => q(ተናፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናፈቀ),
					result  => q(ተናፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናፈሰ),
					result  => q(ተናፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናጋ),
					result  => q(ተናጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናገረ),
					result  => q(ተናገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናገሠ),
					result  => q(ተናገ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናደደ),
					result  => q(ተናደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናዘዘ),
					result  => q(ተናዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናከሰ),
					result  => q(ተናከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናኘ),
					result  => q(ተናኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናነቀው),
					result  => q(ተናነ፟ቀው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናነቀ),
					result  => q(ተናነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናባቢ),
					result  => q(ተናባ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተናበበ),
					result  => q(ተናበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፋፋ),
					result  => q(ተነፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፋፈገ),
					result  => q(ተነፋፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፋፈቀ),
					result  => q(ተነፋፈ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፋፈሰ),
					result  => q(ተነፋፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፋነፈ),
					result  => q(ተነፋነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፋረቀ),
					result  => q(ተነፋረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፋ),
					result  => q(ተነፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፈገ),
					result  => q(ተነፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነፈሰ),
					result  => q(ተነፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነጫነጨ),
					result  => q(ተነጫነ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነጐረ),
					result  => q(ተነጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነጋገደ),
					result  => q(ተነጋገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነጋገረ),
					result  => q(ተነጋገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነገተ),
					result  => q(ተነገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነዳደፈ),
					result  => q(ተነዳደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነዳ),
					result  => q(ተነዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነደፈ),
					result  => q(ተነደ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነዛነዘ),
					result  => q(ተነዛነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነዛ),
					result  => q(ተነዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነዘነዘ),
					result  => q(ተነዘነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነኰተ),
					result  => q(ተነኰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነኰሰ),
					result  => q(ተነኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነካካ),
					result  => q(ተነካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነካከሰ),
					result  => q(ተነካከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነካ),
					result  => q(ተነካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነከሰ),
					result  => q(ተነከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነከረ),
					result  => q(ተነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነነ),
					result  => q(ተነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነታረከ),
					result  => q(ተነታረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነተገ),
					result  => q(ተነተ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነተነ),
					result  => q(ተነተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነባቢ),
					result  => q(ተነባ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነባበረ),
					result  => q(ተነባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነበየ),
					result  => q(ተነበ፟የ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነበበ),
					result  => q(ተነበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነቃነቀ),
					result  => q(ተነቃነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነቃቃ),
					result  => q(ተነቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነቃቀፈ),
					result  => q(ተነቃቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነቀፈ),
					result  => q(ተነቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነቀነቀ),
					result  => q(ተነቀነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነቀሰ),
					result  => q(ተነቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነቀለ),
					result  => q(ተነቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነሳ),
					result  => q(ተነ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነሰነሰ),
					result  => q(ተነሰነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነሣሣ),
					result  => q(ተነሣ፟ሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተነሣ),
					result  => q(ተነሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቻኰለ),
					result  => q(ተቻኰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቺ),
					result  => q(ተቺ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸፈገ),
					result  => q(ተቸፈ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸፈቸፈ),
					result  => q(ተቸፈቸ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸገረ),
					result  => q(ተቸገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸከለ),
					result  => q(ተቸከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸነከረ),
					result  => q(ተቸነከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸበቸበ),
					result  => q(ተቸበቸ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸለሰ),
					result  => q(ተቸለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቸ),
					result  => q(ተቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተትረፈረፈ),
					result  => q(ተትረፈረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተታፋ),
					result  => q(ተታፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተታኰሰ),
					result  => q(ተታኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተታለለ),
					result  => q(ተታለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተኰሰ),
					result  => q(ተተኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተካይ),
					result  => q(ተተካ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተካ),
					result  => q(ተተካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተከለ),
					result  => q(ተተከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተናኮለ),
					result  => q(ተተናኮ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተነተነ),
					result  => q(ተተነተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተቸ),
					result  => q(ተተቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተበተበ),
					result  => q(ተተበተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተራመሰ),
					result  => q(ተተራመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተረጐመ),
					result  => q(ተተረጐ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተረኰሰ),
					result  => q(ተተረኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተረከከ),
					result  => q(ተተረከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተረከ),
					result  => q(ተተረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተረተረ),
					result  => q(ተተረተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተረማመሰ),
					result  => q(ተተረማመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተመነ),
					result  => q(ተተመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተመተመ),
					result  => q(ተተመተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተተለተለ),
					result  => q(ተተለተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቧደነ),
					result  => q(ተቧደ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቦደሰ),
					result  => q(ተቦደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቦካ),
					result  => q(ተቦካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቦተረፈ),
					result  => q(ተቦተረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቦረቦረ),
					result  => q(ተቦረቦ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብከነከነ),
					result  => q(ተብከነከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብታባ),
					result  => q(ተብታባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብሰለሰለ),
					result  => q(ተብሰለሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብራራ),
					result  => q(ተብራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብረከረከ),
					result  => q(ተብረከረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብረቀረቀ),
					result  => q(ተብረቀረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብላላ),
					result  => q(ተብላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብለጨለጨ),
					result  => q(ተብለጨለ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተብለጠለጠ),
					result  => q(ተብለጠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባዛ),
					result  => q(ተባዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባበረ),
					result  => q(ተባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባቃ),
					result  => q(ተባቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባሸቀ),
					result  => q(ተባሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባረደ),
					result  => q(ተባረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባረከ),
					result  => q(ተባረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባረረ),
					result  => q(ተባረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባላ),
					result  => q(ተባላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተባ),
					result  => q(ተባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበጣበጠ),
					result  => q(ተበጣበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበጠበጠ),
					result  => q(ተበጠበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበገረ),
					result  => q(ተበገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበጃጀ),
					result  => q(ተበጃጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበጀ),
					result  => q(ተበጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበዳደረ),
					result  => q(ተበዳደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበዳይ),
					result  => q(ተበዳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበዳሪ),
					result  => q(ተበዳ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበዳ),
					result  => q(ተበዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበደረ),
					result  => q(ተበደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበደለ),
					result  => q(ተበደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበያጅ),
					result  => q(ተበያ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበየደ),
					result  => q(ተበየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበየነ),
					result  => q(ተበየ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበዘበዘ),
					result  => q(ተበዘበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበካከለ),
					result  => q(ተበካከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበከለ),
					result  => q(ተበከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበታተነ),
					result  => q(ተበታተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበተበ),
					result  => q(ተበተ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበቃይ),
					result  => q(ተበቃ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበቀለ),
					result  => q(ተበቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበሻቀጠ),
					result  => q(ተበሻቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበሳበሰ),
					result  => q(ተበሳበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበሳሳ),
					result  => q(ተበሳሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበሳ),
					result  => q(ተበሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበራከተ),
					result  => q(ተበራከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበረጋገደ),
					result  => q(ተበረጋገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበረዘ),
					result  => q(ተበረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበረበረ),
					result  => q(ተበረበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበረቃቀሰ),
					result  => q(ተበረቃቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበረቀሰ),
					result  => q(ተበረቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበላቀጠ),
					result  => q(ተበላቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበላሸ),
					result  => q(ተበላሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበላለጠ),
					result  => q(ተበላለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበላ),
					result  => q(ተበላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበለጠ),
					result  => q(ተበለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተበለቀጠ),
					result  => q(ተበለቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቋራጭ),
					result  => q(ተቋራ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቋረጠ),
					result  => q(ተቋረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቋላ),
					result  => q(ተቋላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቋለፈ),
					result  => q(ተቋለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈናኝ),
					result  => q(ተቈና፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈነደደ),
					result  => q(ተቈነደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈነነ),
					result  => q(ተቈነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈሰቈሰ),
					result  => q(ተቈሰቈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈራጭ),
					result  => q(ተቈራ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈራቈሰ),
					result  => q(ተቈራቈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈራረጠ),
					result  => q(ተቈራረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈራመደ),
					result  => q(ተቈራመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈራ),
					result  => q(ተቈራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈረጠ),
					result  => q(ተቈረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈረቈረ),
					result  => q(ተቈረቈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈለፈ),
					result  => q(ተቈለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቈለመመ),
					result  => q(ተቈለመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆፈረ),
					result  => q(ተቆፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆራኘ),
					result  => q(ተቆራኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆራረሰ),
					result  => q(ተቆራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆረጠ),
					result  => q(ተቆረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆረቆረ),
					result  => q(ተቆረቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆረሰ),
					result  => q(ተቆረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆላ),
					result  => q(ተቆላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቆለለ),
					result  => q(ተቆለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቅነዘነዘ),
					result  => q(ተቅነዘነ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቅበዘበዘ),
					result  => q(ተቅበዘበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቅለጠለጠ),
					result  => q(ተቅለጠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቅለበለበ),
					result  => q(ተቅለበለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቅለሰለሰ),
					result  => q(ተቅለሰለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃወሰ),
					result  => q(ተቃወ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃወመ),
					result  => q(ተቃወ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃኘ),
					result  => q(ተቃኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃና),
					result  => q(ተቃና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃባ),
					result  => q(ተቃባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃቀፈ),
					result  => q(ተቃቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃረነ),
					result  => q(ተቃረ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃረበ),
					result  => q(ተቃረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃረመ),
					result  => q(ተቃረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃማ),
					result  => q(ተቃማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃመሰ),
					result  => q(ተቃመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃለደ),
					result  => q(ተቃለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቃለለ),
					result  => q(ተቃለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቁነጠነጠ),
					result  => q(ተቁነጠነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቁለጨለጨ),
					result  => q(ተቁለጨለ፟ጨ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀፈፈ),
					result  => q(ተቀፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀፈደደ),
					result  => q(ተቀፈደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀፈቀፈ),
					result  => q(ተቀፈቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀፈረረ),
					result  => q(ተቀፈረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀጠቀጠ),
					result  => q(ተቀጠቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀዳጀ),
					result  => q(ተቀዳጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀዳደደ),
					result  => q(ተቀዳደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀዳደመ),
					result  => q(ተቀዳደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀዳሚ),
					result  => q(ተቀዳ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀዳ),
					result  => q(ተቀዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀደደ),
					result  => q(ተቀደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀደሰ),
					result  => q(ተቀደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀደመ),
					result  => q(ተቀደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀየጠ),
					result  => q(ተቀየ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀየደ),
					result  => q(ተቀየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀየረ),
					result  => q(ተቀየ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀየሠ),
					result  => q(ተቀየ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀየመ),
					result  => q(ተቀየ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀዛቀዘ),
					result  => q(ተቀዛቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀዘፈ),
					result  => q(ተቀዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀኘ),
					result  => q(ተቀኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀናና),
					result  => q(ተቀና፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀናነሰ),
					result  => q(ተቀናነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀናበረ),
					result  => q(ተቀናበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀናቃኝ),
					result  => q(ተቀናቃኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀናቀነ),
					result  => q(ተቀናቀ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀናሽ),
					result  => q(ተቀና፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀነፈ),
					result  => q(ተቀነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀነባበረ),
					result  => q(ተቀ፟ነባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀነሰ),
					result  => q(ተቀነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀተረ),
					result  => q(ተቀተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀባይ),
					result  => q(ተቀባ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀባበለ),
					result  => q(ተቀባበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀባ),
					result  => q(ተቀባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀበተተ),
					result  => q(ተቀበተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀበቀበ),
					result  => q(ተቀበቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀበረ),
					result  => q(ተቀበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀበለ),
					result  => q(ተቀበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀቀለ),
					result  => q(ተቀቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀሰተ),
					result  => q(ተቀሰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀሰቀሰ),
					result  => q(ተቀሰቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀሰረ),
					result  => q(ተቀሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀሰመ),
					result  => q(ተቀሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀራረፈ),
					result  => q(ተቀራረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀረፈ),
					result  => q(ተቀረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀረጸ),
					result  => q(ተቀረ፟ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀረጠ),
					result  => q(ተቀረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀረደደ),
					result  => q(ተቀረደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀረቀበ),
					result  => q(ተቀረቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀረቀረ),
					result  => q(ተቀረቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀማጭ),
					result  => q(ተቀማ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀማ),
					result  => q(ተቀማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀመጠ),
					result  => q(ተቀመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀመሰ),
					result  => q(ተቀመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀመመ),
					result  => q(ተቀመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀመለ),
					result  => q(ተቀመ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀላቢ),
					result  => q(ተቀላ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀላቀለ),
					result  => q(ተቀላቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀላለደ),
					result  => q(ተቀላለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀላ),
					result  => q(ተቀላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀለበሰ),
					result  => q(ተቀለበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀለበ),
					result  => q(ተቀለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተቀለሰ),
					result  => q(ተቀለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሽኮረመመ),
					result  => q(ተሽኮረመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሽከረከረ),
					result  => q(ተሽከረከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሽበለበለ),
					result  => q(ተሽበለበ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሽቆጠቆጠ),
					result  => q(ተሽቆጠቆ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሽቀዳደመ),
					result  => q(ተሽቀዳደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሽመደመደ),
					result  => q(ተሽመደመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሻገረ),
					result  => q(ተሻገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሻኰተ),
					result  => q(ተሻኰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሻሸ),
					result  => q(ተሻሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሻረከ),
					result  => q(ተሻረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሻማ),
					result  => q(ተሻማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሹለከለከ),
					result  => q(ተሹለከለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸፋፈነ),
					result  => q(ተሸፋፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸፈነ),
					result  => q(ተሸፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸጐጠ),
					result  => q(ተሸጐ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸጐረ),
					result  => q(ተሸጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸጋገረ),
					result  => q(ተሸጋገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸጋሸገ),
					result  => q(ተሸ፟ጋሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸካከመ),
					result  => q(ተሸካከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸካሚ),
					result  => q(ተሸካ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸከሸከ),
					result  => q(ተሸከሸ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸከመ),
					result  => q(ተሸከ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸኘ),
					result  => q(ተሸኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸናፊ),
					result  => q(ተሸና፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸናነፈ),
					result  => q(ተሸናነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸነተረ),
					result  => q(ተሸነተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸነሸነ),
					result  => q(ተሸነሸ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸበበ),
					result  => q(ተሸበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸበረ),
					result  => q(ተሸበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸቀበ),
					result  => q(ተሸቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸሸገ),
					result  => q(ተሸሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸራፊ),
					result  => q(ተሸራ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸራረፈ),
					result  => q(ተሸራረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸረፈ),
					result  => q(ተሸረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸረካከተ),
					result  => q(ተሸረካከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸረከተ),
					result  => q(ተሸረከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸረሸረ),
					result  => q(ተሸረሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸማቀቀ),
					result  => q(ተሸማቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸመተ),
					result  => q(ተሸመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸመቀቀ),
					result  => q(ተሸመቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸላሚ),
					result  => q(ተሸላ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸላለመ),
					result  => q(ተሸላለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸለተ),
					result  => q(ተሸለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸለቀቀ),
					result  => q(ተሸለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሸለመ),
					result  => q(ተሸለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተስፋፋ),
					result  => q(ተስፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተስገበገበ),
					result  => q(ተስገበገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተስማማ),
					result  => q(ተስማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተስለከለከ),
					result  => q(ተስለከለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተስለመለመ),
					result  => q(ተስለመለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳደደ),
					result  => q(ተሳደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳደበ),
					result  => q(ተሳደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳካ),
					result  => q(ተሳካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳከረ),
					result  => q(ተሳከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳተፈ),
					result  => q(ተሳተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳበበ),
					result  => q(ተሳበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳቀቀ),
					result  => q(ተሳቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳሰበ),
					result  => q(ተሳሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳረቀ),
					result  => q(ተሳረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳረረ),
					result  => q(ተሳ፟ረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳለቀ),
					result  => q(ተሳለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሳለመ),
					result  => q(ተሳለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰገሰገ),
					result  => q(ተሰገሰ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰዳደበ),
					result  => q(ተሰዳደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰደደ),
					result  => q(ተሰደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰደበ),
					result  => q(ተሰደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰየፈ),
					result  => q(ተሰየ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰወጠ),
					result  => q(ተሰወ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰካ),
					result  => q(ተሰካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰኘ),
					result  => q(ተሰኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰናዳ),
					result  => q(ተሰናዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰናዘረ),
					result  => q(ተሰናዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰናከለ),
					result  => q(ተሰናከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰናበተ),
					result  => q(ተሰናበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰነገ),
					result  => q(ተሰነ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰነዳዳ),
					result  => q(ተሰነዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰነከለ),
					result  => q(ተሰነከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰነባበተ),
					result  => q(ተሰነባበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰነቀረብኝ),
					result  => q(ተሰነቀ፟ረብኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰነቀረ),
					result  => q(ተሰነቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰነቀ),
					result  => q(ተሰነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰተረ),
					result  => q(ተሰተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰባበረ),
					result  => q(ተሰባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰባሪ),
					result  => q(ተሰባ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰበከ),
					result  => q(ተሰበ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰበሰበ),
					result  => q(ተሰበሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰበረ),
					result  => q(ተሰበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰቃይ),
					result  => q(ተሰቃ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰቃየ),
					result  => q(ተሰቃየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰቀቀ),
					result  => q(ተሰቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰቀለ),
					result  => q(ተሰቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰራረቀ),
					result  => q(ተሰራረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰረጐደ),
					result  => q(ተሰረጐ፟ደ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰረዘ),
					result  => q(ተሰረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰረነቀ),
					result  => q(ተሰረነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰረቀ),
					result  => q(ተሰረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰረሰረ),
					result  => q(ተሰረሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰረረ),
					result  => q(ተሰረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰማማ),
					result  => q(ተሰማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰማ),
					result  => q(ተሰማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰሚነት),
					result  => q(ተሰሚነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰላፊ),
					result  => q(ተሰላ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰላቸ),
					result  => q(ተሰላቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰለፈ),
					result  => q(ተሰለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰለቻቸ),
					result  => q(ተሰለቻቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰለቸ),
					result  => q(ተሰለቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰለበ),
					result  => q(ተሰለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰለቀ),
					result  => q(ተሰለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሰለለ),
					result  => q(ተሰለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተርገበገበ),
					result  => q(ተርገበገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተርካካ),
					result  => q(ተርካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተርከፈከፈ),
					result  => q(ተርከፈከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተርበደበደ),
					result  => q(ተርበደበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተርበተበተ),
					result  => q(ተርበተበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተርመጠመጠ),
					result  => q(ተርመጠመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተርመሰመሰ),
					result  => q(ተርመሰመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራገፈ),
					result  => q(ተራገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራገጠ),
					result  => q(ተራገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራገመ),
					result  => q(ተራገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራኰተ),
					result  => q(ተራኰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራኪ),
					result  => q(ተራ፟ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራች),
					result  => q(ተራ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራባ),
					result  => q(ተራባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራቢ),
					result  => q(ተራ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራቀቀ),
					result  => q(ተራቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራራማ),
					result  => q(ተራራማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራረደ),
					result  => q(ተራረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራረመ),
					result  => q(ተራረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተራመደ),
					result  => q(ተራመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረፈ),
					result  => q(ተረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረጐመ),
					result  => q(ተረጐ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረጋጋ),
					result  => q(ተረጋጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረገጠ),
					result  => q(ተረገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረገዘ),
					result  => q(ተረገ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረገረገ),
					result  => q(ተረገረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረገመ),
					result  => q(ተረገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረዳዳ),
					result  => q(ተረዳዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረዳ),
					result  => q(ተረዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረኰሰ),
					result  => q(ተረኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረካከበ),
					result  => q(ተረካከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረካቢ),
					result  => q(ተረካ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረከከ),
					result  => q(ተረከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረከበ),
					result  => q(ተረከ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረኛ),
					result  => q(ተረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረታ),
					result  => q(ተረታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረተረ),
					result  => q(ተረተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረተ),
					result  => q(ተረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረባረበ),
					result  => q(ተረባረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረበኛ),
					result  => q(ተረበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረበረበ),
					result  => q(ተረበረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረበ),
					result  => q(ተረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረሳሳ),
					result  => q(ተረሳሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረሳ),
					result  => q(ተረሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተረማመደ),
					result  => q(ተረማመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሣሠረ),
					result  => q(ተሣሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሠየመ),
					result  => q(ተሠየ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሠዋሪ),
					result  => q(ተሠዋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሠወረ),
					result  => q(ተሠወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሠቀሠቀ),
					result  => q(ተሠቀሠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሠረገ),
					result  => q(ተሠረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሠረሠረ),
					result  => q(ተሠረሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሟጋች),
					result  => q(ተሟጋ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሟገተ),
					result  => q(ተሟገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሟከረ),
					result  => q(ተሟከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሟሸ),
					result  => q(ተሟሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሟላ),
					result  => q(ተሟላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞጨለፈ),
					result  => q(ተሞጨለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞጋገሰ),
					result  => q(ተሞጋገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞጋሽ),
					result  => q(ተሞጋ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞገሰ),
					result  => q(ተሞገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞጀረ),
					result  => q(ተሞጀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞክሮ),
					result  => q(ተሞክ፟ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞካከረ),
					result  => q(ተሞካከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞከተ),
					result  => q(ተሞከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞከረ),
					result  => q(ተሞከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞሸረ),
					result  => q(ተሞሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞሸለቀ),
					result  => q(ተሞሸለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞረደ),
					result  => q(ተሞረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞላፈጠ),
					result  => q(ተሞላፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞላቀቀ),
					result  => q(ተሞላቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞላ),
					result  => q(ተሞላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተሞለጨ),
					result  => q(ተሞለ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተምዘገዘገ),
					result  => q(ተምዘገዘ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተምዘአዘገ),
					result  => q(ተምዘአዘ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተምነሸነሸ),
					result  => q(ተምነሸነ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተምታታ),
					result  => q(ተምታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተምቦጫቦጨ),
					result  => q(ተምቦጫቦ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማገደ),
					result  => q(ተማገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማገረ),
					result  => q(ተማገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማዘዘ),
					result  => q(ተማዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማከረ),
					result  => q(ተማከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማታ),
					result  => q(ተማታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማሰለ),
					result  => q(ተማሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማራ),
					result  => q(ተማራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማረዘ),
					result  => q(ተማረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማረከ),
					result  => q(ተማረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማረረ),
					result  => q(ተማረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማማ),
					result  => q(ተማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማመነ),
					result  => q(ተማመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተማለደ),
					result  => q(ተማለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመጻደቀ),
					result  => q(ተመጻደ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመጠወተ),
					result  => q(ተመጠወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመጋቢ),
					result  => q(ተመጋ፟ቢ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመገበ),
					result  => q(ተመገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመደበ),
					result  => q(ተመደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመዛዘነ),
					result  => q(ተመዛዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመዘገበ),
					result  => q(ተመዘገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመዘዘ),
					result  => q(ተመዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመዘነ),
					result  => q(ተመዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመዘበረ),
					result  => q(ተመዘበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመዘመዘ),
					result  => q(ተመዘመ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመካከረ),
					result  => q(ተመካከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመካ),
					result  => q(ተመካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመከተ),
					result  => q(ተመከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመከረ),
					result  => q(ተመከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመኘ),
					result  => q(ተመኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመናቀረ),
					result  => q(ተመናቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመነዘረ),
					result  => q(ተመነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመነተፈ),
					result  => q(ተመነተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመነቃቀረ),
					result  => q(ተመነቃቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመነ),
					result  => q(ተመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመቻቸ),
					result  => q(ተመቻቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመቸ),
					result  => q(ተመቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመታ),
					result  => q(ተመታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመተረ),
					result  => q(ተመተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመተመ),
					result  => q(ተመተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሳከረ),
					result  => q(ተመሳከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሳቀለ),
					result  => q(ተመሳቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሰጠ),
					result  => q(ተመሰ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሰገነ),
					result  => q(ተመሰገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሰከረ),
					result  => q(ተመሰከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሰቃቀለ),
					result  => q(ተመሰቃቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሰለ),
					result  => q(ተመሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመራጭነት),
					result  => q(ተመራ፟ጭነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመራጭ),
					result  => q(ተመራ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመራቂ),
					result  => q(ተመራ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመራመረ),
					result  => q(ተመራመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመራ),
					result  => q(ተመራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመረጠ),
					result  => q(ተመረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመረገ),
					result  => q(ተመረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመረዘ),
					result  => q(ተመረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመረኰዘ),
					result  => q(ተመረኰ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመረቀ),
					result  => q(ተመረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመረረ),
					result  => q(ተመረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመረመረ),
					result  => q(ተመረመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሥጦ),
					result  => q(ተመሥ፟ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሠጠ),
					result  => q(ተመ፟ሠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመሠረተ),
					result  => q(ተመሠ፟ረተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመመ),
					result  => q(ተመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመላኪ),
					result  => q(ተመላ፟ኪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመላሽ),
					result  => q(ተመላ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመላለጠ),
					result  => q(ተመላለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመላለሰ),
					result  => q(ተመላለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመለጠ),
					result  => q(ተመለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመለከተ),
					result  => q(ተመለከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመለከ),
					result  => q(ተመለ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተመለሰ),
					result  => q(ተመለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተልፈሰፈሰ),
					result  => q(ተልፈሰፈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተልካሳ),
					result  => q(ተልካሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተልከፈከፈ),
					result  => q(ተልከፈከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተልከስከሰ),
					result  => q(ተልከስከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላፋ),
					result  => q(ተላፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላወሰ),
					result  => q(ተላወሰ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላከከ),
					result  => q(ተላከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላቀቀ),
					result  => q(ተላቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላቀሰ),
					result  => q(ተላቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላመጠ),
					result  => q(ተላመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላመደ),
					result  => q(ተላመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላላፊ),
					result  => q(ተላላ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላላኪነት),
					result  => q(ተላላኪነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላለፈ),
					result  => q(ተላለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላለቀ),
					result  => q(ተላለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተላ),
					result  => q(ተላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለፋላፊ),
					result  => q(ተለፋላ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለፋለፈ),
					result  => q(ተለፋለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለፈፈ),
					result  => q(ተለፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለጠለጠ),
					result  => q(ተለጠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለያየ),
					result  => q(ተለያየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለየ),
					result  => q(ተለየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለዋጭ),
					result  => q(ተለዋ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለዋወጠ),
					result  => q(ተለዋወ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለወጠ),
					result  => q(ተለወ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለተመ),
					result  => q(ተለተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለተለ),
					result  => q(ተለተ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለባበሰ),
					result  => q(ተለባበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለባቂ),
					result  => q(ተለባ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለበጠ),
					result  => q(ተለበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለበደ),
					result  => q(ተለበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለበበ),
					result  => q(ተለበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለበቀ),
					result  => q(ተለበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለበለበ),
					result  => q(ተለበለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለቃለቀ),
					result  => q(ተለቃለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለቀቀ),
					result  => q(ተለ፟ቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለቀመ),
					result  => q(ተለቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለቀለቀ),
					result  => q(ተለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለቀ),
					result  => q(ተለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለሳለሰ),
					result  => q(ተለሳለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለሰነ),
					result  => q(ተለሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለማጭ),
					result  => q(ተለማ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለማጅ),
					result  => q(ተለማ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለማኝ),
					result  => q(ተለማ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለማመጠ),
					result  => q(ተለማመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለማመደ),
					result  => q(ተለማመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለማመነ),
					result  => q(ተለማመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለመጠ),
					result  => q(ተለመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለመደ),
					result  => q(ተለመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለመዘገ),
					result  => q(ተለመዘ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለመነ),
					result  => q(ተለመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለመሰሰ),
					result  => q(ተለመሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለመለመ),
					result  => q(ተለመለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ተለመ),
					result  => q(ተለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቧገተ),
					result  => q(ቧገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦጭ),
					result  => q(ቦጭ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦጫጨረ),
					result  => q(ቦጫ፟ጨረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦጨቅ),
					result  => q(ቦጨ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦግታ),
					result  => q(ቦግ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦግ),
					result  => q(ቦግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦደሰ),
					result  => q(ቦደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦዘንተኛ),
					result  => q(ቦዘንተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦዘነ),
					result  => q(ቦዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦካ),
					result  => q(ቦካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦከቦከ),
					result  => q(ቦከቦ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦነነ),
					result  => q(ቦነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦታ),
					result  => q(ቦታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦተረፈ),
					result  => q(ቦተረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦቃማ),
					result  => q(ቦቃማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦርቃቃ),
					result  => q(ቦርቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦራቂ),
					result  => q(ቦራ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦረቦረ),
					result  => q(ቦረቦ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦረቀ),
					result  => q(ቦረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቦሎቄ),
					result  => q(ቦሎ፟ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብጥብጥ),
					result  => q(ብጥብ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብድግ),
					result  => q(ብድግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብድር),
					result  => q(ብድ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብይድ),
					result  => q(ብይ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብይን),
					result  => q(ብይ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብይ),
					result  => q(ብይ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብዬ),
					result  => q(ብዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብያኔ),
					result  => q(ብያ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብየዳ),
					result  => q(ብየ፟ዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብው),
					result  => q(ብው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብክት),
					result  => q(ብክ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብክል),
					result  => q(ብክ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብካች),
					result  => q(ብካ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብኩንነት),
					result  => q(ብኩንነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብኩርና),
					result  => q(ብኩርና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብናኝ),
					result  => q(ብና፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብቻ),
					result  => q(ብቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብቸኝነት),
					result  => q(ብቸ፟ኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብቸኛ),
					result  => q(ብቸ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብትን),
					result  => q(ብት፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብትቷም),
					result  => q(ብትቷ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብትቶ),
					result  => q(ብትቶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብብት),
					result  => q(ብብ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብቡ),
					result  => q(ብቡ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብቅ),
					result  => q(ብቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብቁነት),
					result  => q(ብቁ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብስጭትጭት),
					result  => q(ብስጭትጭ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብስባሽ),
					result  => q(ብስባ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብርጭቆ),
					result  => q(ብርጭቆ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብርግድ),
					result  => q(ብርግድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብርካቴ),
					result  => q(ብርካ፟ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብርኩማ),
					result  => q(ብርኩማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብርቅስቅስ),
					result  => q(ብርቅስቅ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብርሌ),
					result  => q(ብርሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብር),
					result  => q(ብር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብራኳ),
					result  => q(ብራኳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብራና),
					result  => q(ብራና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብራቢሮ),
					result  => q(ብራቢሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብራ),
					result  => q(ብራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብረድስት),
					result  => q(ብረድ፟ስት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብሕትውና),
					result  => q(ብሕትውና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብሔረተኛ),
					result  => q(ብሔረተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብሎት),
					result  => q(ብሎ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልፅግና),
					result  => q(ብልፅግ፟ና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልጭታ),
					result  => q(ብል፟ጭታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልጭ),
					result  => q(ብል፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልጫ),
					result  => q(ብል፟ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልጥግና),
					result  => q(ብልጥግ፟ና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልግና),
					result  => q(ብልግና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልግ),
					result  => q(ብል፟ግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልዝ),
					result  => q(ብል፟ዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልኮ),
					result  => q(ብል፟ኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልት),
					result  => q(ብል፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልሹ),
					result  => q(ብልሹ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብልሃተኛ),
					result  => q(ብልሃተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብላጊ),
					result  => q(ብላ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብላቴን),
					result  => q(ብላቴ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብላቴና),
					result  => q(ብላቴ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ብላታ),
					result  => q(ብላታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቤዛ),
					result  => q(ቤዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቤተኛ),
					result  => q(ቤተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባዘተ),
					result  => q(ባዘ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባዘቀ),
					result  => q(ባዘ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባከነ),
					result  => q(ባከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባኞ),
					result  => q(ባኞ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባንድነት),
					result  => q(ባንድነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባነነ),
					result  => q(ባነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባባ),
					result  => q(ባባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባሻ),
					result  => q(ባሻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባርነት),
					result  => q(ባርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባርማሽላ),
					result  => q(ባርማሽላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባረከ),
					result  => q(ባረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባረቀ),
					result  => q(ባረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባልጩት),
					result  => q(ባልጩት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባልንጀርነት),
					result  => q(ባልንጀርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባልና),
					result  => q(ባልና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባልትና),
					result  => q(ባልትና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባላንጣነት),
					result  => q(ባላንጣነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባላባትነት),
					result  => q(ባላባ፟ትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባላባት),
					result  => q(ባላባ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባላ),
					result  => q(ባላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለፀጋ),
					result  => q(ባለፀጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለጥግ),
					result  => q(ባለጥግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለጠጋ),
					result  => q(ባለጠጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለጌነት),
					result  => q(ባለጌነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለጉዳይ),
					result  => q(ባለጉዳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለገ),
					result  => q(ባለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለጅ),
					result  => q(ባለጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለእጅ),
					result  => q(ባለእጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለብር),
					result  => q(ባለብር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለስድስት),
					result  => q(ባለስድ፟ስት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለሳምንት),
					result  => q(ባለሳም፟ንት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ባለሥልጣኖች),
					result  => q(ባለሥልጣኖች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቢዘገይም),
					result  => q(ቢዘገይ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቢራቢሮ),
					result  => q(ቢራ፟ቢሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቢልቢላ),
					result  => q(ቢልቢላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቢል),
					result  => q(ቢል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቢላዎ),
					result  => q(ቢላ፟ዎ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቢላዋ),
					result  => q(ቢላ፟ዋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቢሆንም),
					result  => q(ቢሆንም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡፍ),
					result  => q(ቡፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡግ),
					result  => q(ቡግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡድነት),
					result  => q(ቡድነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡድስ),
					result  => q(ቡድ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡዳነት),
					result  => q(ቡዳነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡንኝ),
					result  => q(ቡን፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡን),
					result  => q(ቡን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡናኝ),
					result  => q(ቡና፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡናማ),
					result  => q(ቡና፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡና),
					result  => q(ቡና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡችላ),
					result  => q(ቡች፟ላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡትርፍ),
					result  => q(ቡትርፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡቡ),
					result  => q(ቡቡ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡቃያ),
					result  => q(ቡቃያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡሬማ),
					result  => q(ቡሬ፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡሬ),
					result  => q(ቡሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡራኬ),
					result  => q(ቡራ፟ኬ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡራቡሬ),
					result  => q(ቡራ፟ቡሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡረቃ),
					result  => q(ቡረ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡልቅታ),
					result  => q(ቡል፟ቅታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡልቅ),
					result  => q(ቡል፟ቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቡላ),
					result  => q(ቡላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጭፍን),
					result  => q(በጭፍ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጭካኔ),
					result  => q(በጭካ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጭራሽ),
					result  => q(በጭራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጥፊ),
					result  => q(በጥፊ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጥያቄ),
					result  => q(በጥያ፟ቄ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጥሞና),
					result  => q(በጥሞ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጡጫ),
					result  => q(በጡጫ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጠበጠ),
					result  => q(በጠበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጠቅላላው),
					result  => q(በጠቅላላ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጠቅላላ),
					result  => q(በጠቅላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጐነት),
					result  => q(በጐ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጐ),
					result  => q(በጐ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በግድ),
					result  => q(በግድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በግምት),
					result  => q(በግም፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በግል),
					result  => q(በግል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በግላጭ),
					result  => q(በግላ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በገዛ),
					result  => q(በገዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በገነ),
					result  => q(በገ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጅምር),
					result  => q(በጅም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በጀ),
					result  => q(በጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በድጋሚ),
					result  => q(በድጋ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዳይ),
					result  => q(በዳ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዳ),
					result  => q(በዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዱላ),
					result  => q(በዱላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በደዊ),
					result  => q(በደዊ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በደል),
					result  => q(በደ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በደለኛ),
					result  => q(በደለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በደለ),
					result  => q(በደ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በያጅ),
					result  => q(በያ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በያኝ),
					result  => q(በያ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በያለበት),
					result  => q(በያ፟ለ፟በ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየፊናው),
					result  => q(በየ፟ፊናው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየግል),
					result  => q(በየ፟ግል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየጊዜው),
					result  => q(በየ፟ጊዜው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየደ),
					result  => q(በየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየዓመቱ),
					result  => q(በየ፟ዓመቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየወቅቱ),
					result  => q(በየ፟ወቅቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየነ),
					result  => q(በየ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየተራ),
					result  => q(በየ፟ተራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየቀኑ),
					result  => q(በየ፟ቀኑ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በየሰዓቱ),
					result  => q(በየ፟ሰዓቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዛ),
					result  => q(በዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዚያ),
					result  => q(በዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዚህም),
					result  => q(በዚህም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዚህ),
					result  => q(በዚ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በዘበዘ),
					result  => q(በዘበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በወዘ),
					result  => q(በወ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በካይ),
					result  => q(በካ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በኩል),
					result  => q(በኩ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በከተ),
					result  => q(በከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በከለ),
					result  => q(በከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በአጋጣሚ),
					result  => q(በአጋጣ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በነነ),
					result  => q(በነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በትር),
					result  => q(በት፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በታተነ),
					result  => q(በታተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በተጨማሪ),
					result  => q(በተጨማ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በተነ),
					result  => q(በተ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በተረፈ),
					result  => q(በተረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በተለይ),
					result  => q(በተለይ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቡጢ),
					result  => q(በቡጢ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቈልት),
					result  => q(በቈ፟ልት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቆሎ),
					result  => q(በቆ፟ሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቅበቃ),
					result  => q(በቅበቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቃኝ),
					result  => q(በቃ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቃ),
					result  => q(በቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቀደም),
					result  => q(በቀደ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቀተ),
					result  => q(በቀ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቀስታ),
					result  => q(በቀስ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቀስ),
					result  => q(በቀስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቀል),
					result  => q(በቀ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቀለኛ),
					result  => q(በቀለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በቀለ),
					result  => q(በቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሽታ),
					result  => q(በሽ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሽተኛ),
					result  => q(በሽ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሸቀጠ),
					result  => q(በሸቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሸቀ),
					result  => q(በሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሶ),
					result  => q(በሶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በስባሳ),
					result  => q(በስባሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሳል),
					result  => q(በሳ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሳ),
					result  => q(በሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሰፊው),
					result  => q(በሰፊ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሰበሰ),
					result  => q(በሰበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሰለ),
					result  => q(በሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በርጩማ),
					result  => q(በርጩማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በርዳማ),
					result  => q(በርዳማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በርካታ),
					result  => q(በርካታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በርበሬ),
					result  => q(በርበሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በር),
					result  => q(በር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በራፍ),
					result  => q(በራ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በራድ),
					result  => q(በራ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በራዥ),
					result  => q(በራ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በራረዘ),
					result  => q(በራረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በራ),
					result  => q(በራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረጋገደ),
					result  => q(በረጋገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረገገ),
					result  => q(በረገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረገደ),
					result  => q(በረገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረደኝ),
					result  => q(በረ፟ደኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረደ),
					result  => q(በረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረዘ),
					result  => q(በረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረኸኛ),
					result  => q(በረኸኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረከተ),
					result  => q(በረከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረኛ),
					result  => q(በረ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረታ),
					result  => q(በረታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረበረ),
					result  => q(በረበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረቃቀሰ),
					result  => q(በረቃቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረቀሰ),
					result  => q(በረቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረቀ),
					result  => q(በረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረረ),
					result  => q(በረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በረሃማ),
					result  => q(በረሃማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሞላ),
					result  => q(በሞላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በመጀመሪያው),
					result  => q(በመጀመ፟ሪያው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በል),
					result  => q(በል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሌለበት),
					result  => q(በሌለ፟በት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በላ),
					result  => q(በላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሊታ),
					result  => q(በሊ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በሉጥ),
					result  => q(በሉ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በለጠ),
					result  => q(በለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በለገ),
					result  => q(በለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በለዘ),
					result  => q(በለ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በለኝ),
					result  => q(በለኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በለተ),
					result  => q(በለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(በለቀጠ),
					result  => q(በለቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቍስለ),
					result  => q(ቍስለ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቍርጥ),
					result  => q(ቍር፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቍራጭ),
					result  => q(ቍራ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቍልጭ),
					result  => q(ቍል፟ጭ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቋጥኝ),
					result  => q(ቋጥ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቋያ),
					result  => q(ቋያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቋቍቻ),
					result  => q(ቋቍ፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቋቅታ),
					result  => q(ቋቅ፟ታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቋቅ),
					result  => q(ቋቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቋመጠ),
					result  => q(ቋመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈንቋና),
					result  => q(ቈንቋና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈነጐለ),
					result  => q(ቈነጐ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈነደደ),
					result  => q(ቈነደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈነነ),
					result  => q(ቈነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈነሰ),
					result  => q(ቈነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈሰቈሰ),
					result  => q(ቈሰቈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈሰለ),
					result  => q(ቈሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈርፋዳ),
					result  => q(ቈርፋዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈርቋዛ),
					result  => q(ቈርቋ፟ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈርቈዘ),
					result  => q(ቈርቈ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈርማዳ),
					result  => q(ቈርማዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈራጥ),
					result  => q(ቈራ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈራረጠ),
					result  => q(ቈራረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈራ),
					result  => q(ቈራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈረፈደ),
					result  => q(ቈረፈ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈረጠ),
					result  => q(ቈረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈረበ),
					result  => q(ቈረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈረቈሰ),
					result  => q(ቈረቈ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈረቈረ),
					result  => q(ቈረቈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈረሰ),
					result  => q(ቈረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈረመደ),
					result  => q(ቈረመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈላፍ),
					result  => q(ቈላ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈላፋ),
					result  => q(ቈላ፟ፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈላለፈ),
					result  => q(ቈላለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈለፈ),
					result  => q(ቈለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈለቈለ),
					result  => q(ቈለቈ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቈለመመ),
					result  => q(ቈለመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆፋፈረ),
					result  => q(ቆፋፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆፋሪ),
					result  => q(ቆፋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆፈነነ),
					result  => q(ቆፈነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆፈረ),
					result  => q(ቆፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆጶስ),
					result  => q(ቆጶ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆጠቆጠ),
					result  => q(ቆጠቆ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆይታ),
					result  => q(ቆይ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆየ),
					result  => q(ቆየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆነጣጠረ),
					result  => q(ቆነጣ፟ጠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆነጀ),
					result  => q(ቆነጀ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆሽማዳ),
					result  => q(ቆሽማዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆሸሸ),
					result  => q(ቆሸ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆርጦኝ),
					result  => q(ቆርጦኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆርቆሮ),
					result  => q(ቆርቆሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆራጥ),
					result  => q(ቆራ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆራረሰ),
					result  => q(ቆራረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆም),
					result  => q(ቆም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆመጠ),
					result  => q(ቆመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆልቋላ),
					result  => q(ቆልቋላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆልማማ),
					result  => q(ቆልማማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆሌ),
					result  => q(ቆሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆላ),
					result  => q(ቆላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆለኛ),
					result  => q(ቆለ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆለመመ),
					result  => q(ቆለመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቆለለ),
					result  => q(ቆለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅፍርር),
					result  => q(ቅፍርር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅፍር),
					result  => q(ቅፍር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅጥቃጤ),
					result  => q(ቅጥቃ፟ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅጥረኛ),
					result  => q(ቅጥረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅጠልያ),
					result  => q(ቅጠልያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅጅ),
					result  => q(ቅጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅድስና),
					result  => q(ቅድ፟ስና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅድስት),
					result  => q(ቅድ፟ስት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅድስተ),
					result  => q(ቅድ፟ስተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅድሳት),
					result  => q(ቅድ፟ሳት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅድም),
					result  => q(ቅድ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅድ),
					result  => q(ቅድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዳጅ),
					result  => q(ቅዳ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዳሴ),
					result  => q(ቅዳ፟ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዱስነት),
					result  => q(ቅዱ፟ስነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዱስ),
					result  => q(ቅዱ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዱሳን),
					result  => q(ቅዱ፟ሳን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅይጥ),
					result  => q(ቅይ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅይድ),
					result  => q(ቅይ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅያሪ),
					result  => q(ቅያ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅያሜ),
					result  => q(ቅያ፟ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅየሣ),
					result  => q(ቅየ፟ሣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዥቅዥ),
					result  => q(ቅዥቅዥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዝዝ),
					result  => q(ቅዝ፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅዝቃዜ),
					result  => q(ቅዝቃ፟ዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅኝት),
					result  => q(ቅኝ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅኝ),
					result  => q(ቅኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅንፍ),
					result  => q(ቅን፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅንዲላ),
					result  => q(ቅንዲላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅንዝረኛ),
					result  => q(ቅንዝረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅንነት),
					result  => q(ቅንነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅንብር),
					result  => q(ቅንብ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅናሽ),
					result  => q(ቅና፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅነሳ),
					result  => q(ቅነ፟ሳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅብብሎሽ),
					result  => q(ቅብብ፟ሎሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅብብል),
					result  => q(ቅብብ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅባቅዱስ),
					result  => q(ቅባቅዱ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅበላ),
					result  => q(ቅበ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅቅል),
					result  => q(ቅቅ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅስና),
					result  => q(ቅስ፟ና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅስት),
					result  => q(ቅስ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅርፍፍ),
					result  => q(ቅርፍፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅርፊት),
					result  => q(ቅርፊት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅርጥፍ),
					result  => q(ቅርጥፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅር),
					result  => q(ቅር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሬታ),
					result  => q(ቅሬ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅራፊ),
					result  => q(ቅራ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅራሪ),
					result  => q(ቅራ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሪት),
					result  => q(ቅሪ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሪላ),
					result  => q(ቅሪላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሥር),
					result  => q(ቅሥ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅምጥ),
					result  => q(ቅም፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅምብቻ),
					result  => q(ቅምብቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅምምጦሽ),
					result  => q(ቅምም፟ጦሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሚያ),
					result  => q(ቅሚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅመማ),
					result  => q(ቅመ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅልጥፍጥፍ),
					result  => q(ቅልጥፍ፟ጥፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅልጥፍና),
					result  => q(ቅልጥፍና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅልጥ),
					result  => q(ቅል፟ጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅልብ),
					result  => q(ቅል፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅልቅል),
					result  => q(ቅልቅ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅልሽስሽ),
					result  => q(ቅልሽስሽ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሌት),
					result  => q(ቅሌ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሌታም),
					result  => q(ቅሌ፟ታም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቅሌተኛ),
					result  => q(ቅሌ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቄንጠኛ),
					result  => q(ቄንጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቃዠ),
					result  => q(ቃዠ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቃኘ),
					result  => q(ቃኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቃተተ),
					result  => q(ቃተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቃበዘ),
					result  => q(ቃበ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቃሬ),
					result  => q(ቃሬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቃረመ),
					result  => q(ቃረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቃልቻ),
					result  => q(ቃል፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቂጥኝ),
					result  => q(ቂጥኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቂመኛ),
					result  => q(ቂመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁፍር),
					result  => q(ቁፍ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁፋሮ),
					result  => q(ቁፋ፟ሮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁፋሪ),
					result  => q(ቁፋ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁፈራ),
					result  => q(ቁፈ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁጥር),
					result  => q(ቁጥ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁንጅና),
					result  => q(ቁንጅና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁንን),
					result  => q(ቁን፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁና),
					result  => q(ቁና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁቅ),
					result  => q(ቁቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁስለኛ),
					result  => q(ቁስለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁርጥምጥም),
					result  => q(ቁርጥምጥም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁር),
					result  => q(ቁር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁራጭ),
					result  => q(ቁራ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁራኛ),
					result  => q(ቁራኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁራሽ),
					result  => q(ቁራ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁምጥና),
					result  => q(ቁምጥና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁምጥ),
					result  => q(ቁም፟ጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁማጭ),
					result  => q(ቁማ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁማርተኛ),
					result  => q(ቁማርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁልፍ),
					result  => q(ቁል፟ፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁልም),
					result  => q(ቁልም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁሌት),
					result  => q(ቁሌ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቁለላ),
					result  => q(ቁለ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀፍራራ),
					result  => q(ቀፍራ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀፈፈ),
					result  => q(ቀፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀፈደደ),
					result  => q(ቀፈደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀፈቀፈ),
					result  => q(ቀፈቀ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀፈረረ),
					result  => q(ቀፈረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀጨቀጨ),
					result  => q(ቀጨቀ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀጣፊነት),
					result  => q(ቀጣፊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀጠቀጠ),
					result  => q(ቀጠቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዶ),
					result  => q(ቀዶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዳሽ),
					result  => q(ቀዳ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዳሚነት),
					result  => q(ቀዳሚነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀደደ),
					result  => q(ቀደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀደሰ),
					result  => q(ቀደ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀደምትነት),
					result  => q(ቀደ፟ምትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀደመ),
					result  => q(ቀደ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀይ),
					result  => q(ቀይ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀያየጠ),
					result  => q(ቀያየ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀያየረ),
					result  => q(ቀያየ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀያቴ),
					result  => q(ቀያ፟ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀያሽ),
					result  => q(ቀያ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀየጠ),
					result  => q(ቀየ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀየደ),
					result  => q(ቀየ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀየረ),
					result  => q(ቀየ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀየሠ),
					result  => q(ቀየ፟ሠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዥቃዣ),
					result  => q(ቀዥቃዣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዝቃዛ),
					result  => q(ቀዝቃዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዘፈ),
					result  => q(ቀዘ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዘዘ),
					result  => q(ቀዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዘነ),
					result  => q(ቀዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዘቀዘው),
					result  => q(ቀዘቀ፟ዘው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀዘቀዘ),
					result  => q(ቀዘቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀውላላ),
					result  => q(ቀውላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀኝ),
					result  => q(ቀኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀኛዝማች),
					result  => q(ቀኛ፟ዝማች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀኖና),
					result  => q(ቀኖ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀንደኛ),
					result  => q(ቀንደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀን),
					result  => q(ቀን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀናነሰ),
					result  => q(ቀናነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀናተኛ),
					result  => q(ቀና፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀና),
					result  => q(ቀና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀነፈ),
					result  => q(ቀነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀነደበ),
					result  => q(ቀነደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀነዘረ),
					result  => q(ቀነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀነተ),
					result  => q(ቀነ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀነበረ),
					result  => q(ቀነበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀነቀነ),
					result  => q(ቀነቀ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀነሰ),
					result  => q(ቀነ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀተረ),
					result  => q(ቀተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀብቃባ),
					result  => q(ቀብቃባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀብራራ),
					result  => q(ቀብራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀባጀረ),
					result  => q(ቀባጀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀባባ),
					result  => q(ቀባባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀባ),
					result  => q(ቀባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀበጠ),
					result  => q(ቀበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀበዝባዛ),
					result  => q(ቀበዝባዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀበኛ),
					result  => q(ቀበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀበቶ),
					result  => q(ቀበቶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀበተተ),
					result  => q(ቀበተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀበቀበ),
					result  => q(ቀበቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀበሌኛ),
					result  => q(ቀበሌኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀቃይ),
					result  => q(ቀቃ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀቀለ),
					result  => q(ቀቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀስታ),
					result  => q(ቀስ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀስተኛ),
					result  => q(ቀስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀስ),
					result  => q(ቀስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሳፈተ),
					result  => q(ቀሳፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሳሰመ),
					result  => q(ቀሳሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሰተ),
					result  => q(ቀሰ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሰቀሰ),
					result  => q(ቀሰቀ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሰስተኛነት),
					result  => q(ቀሰስተኛ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሰስተኛ),
					result  => q(ቀሰስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሰሰ),
					result  => q(ቀሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሰረ),
					result  => q(ቀሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሰመ),
					result  => q(ቀሰ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀርፋፋ),
					result  => q(ቀርፋፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀር),
					result  => q(ቀር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀራረፈ),
					result  => q(ቀራረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀራረመ),
					result  => q(ቀራረ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረፈ),
					result  => q(ቀረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረጸ),
					result  => q(ቀረ፟ጸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረጠ),
					result  => q(ቀረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረደደ),
					result  => q(ቀረደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረና),
					result  => q(ቀረና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረበ),
					result  => q(ቀረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረቀበ),
					result  => q(ቀረቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረቀረ),
					result  => q(ቀረቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረሽ),
					result  => q(ቀረ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረረ),
					result  => q(ቀረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀረ),
					result  => q(ቀረ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሠፈ),
					result  => q(ቀሠ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀሠረ),
					result  => q(ቀሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀማኛ),
					result  => q(ቀማ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀማሚ),
					result  => q(ቀማ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀማመሰ),
					result  => q(ቀማመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀማ),
					result  => q(ቀማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀመቀመ),
					result  => q(ቀመቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀመስ),
					result  => q(ቀመ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀመሰ),
					result  => q(ቀመ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀመመ),
					result  => q(ቀመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀመለ),
					result  => q(ቀመ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀልጣፋ),
					result  => q(ቀልጣፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀልጠፍ),
					result  => q(ቀልጠፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀልደኛ),
					result  => q(ቀልደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀልቃላ),
					result  => q(ቀልቃላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀልማዳ),
					result  => q(ቀልማዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላጅ),
					result  => q(ቀላ፟ጅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላወጠ),
					result  => q(ቀላወ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላቢ),
					result  => q(ቀላ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላማጅነት),
					result  => q(ቀላማጅ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላመደ),
					result  => q(ቀላመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላል),
					result  => q(ቀላ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላለደ),
					result  => q(ቀላለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላለሰ),
					result  => q(ቀላለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀላ),
					result  => q(ቀላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለጠ),
					result  => q(ቀለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለደ),
					result  => q(ቀለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለብተኛ),
					result  => q(ቀለ፟ብተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለብላባ),
					result  => q(ቀለብላ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለብ),
					result  => q(ቀለ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለበሰ),
					result  => q(ቀለበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለበ),
					result  => q(ቀለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለሰ),
					result  => q(ቀለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለመ),
					result  => q(ቀለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለል),
					result  => q(ቀለል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ቀለለ),
					result  => q(ቀለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሾጥ),
					result  => q(ሾጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሾከከ),
					result  => q(ሾከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሾላካ),
					result  => q(ሾላ፟ካ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሾለከ),
					result  => q(ሾለ፟ከ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽፍን),
					result  => q(ሽፍ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽፍትነት),
					result  => q(ሽፍትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽፍታ),
					result  => q(ሽፍ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽፍ),
					result  => q(ሽፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽፋች),
					result  => q(ሽፋ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽጉጥ),
					result  => q(ሽጉ፟ጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽጉር),
					result  => q(ሽጉ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽያጭ),
					result  => q(ሽያ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽውታ),
					result  => q(ሽው፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽው),
					result  => q(ሽው፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽኮኮ),
					result  => q(ሽኮኮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽክፍ),
					result  => q(ሽክ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽክና),
					result  => q(ሽክ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽክ),
					result  => q(ሽክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽንፍላ),
					result  => q(ሽንፍላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽቶ),
					result  => q(ሽቶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽታው),
					result  => q(ሽታ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽታ),
					result  => q(ሽታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽቱ),
					result  => q(ሽቱ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽብር),
					result  => q(ሽብ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽብልቅ),
					result  => q(ሽብል፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽቅብ),
					result  => q(ሽቅ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽቀባ),
					result  => q(ሽቀ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽቀላ),
					result  => q(ሽቀ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽሽግ),
					result  => q(ሽሽ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽሽት),
					result  => q(ሽሽ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽርፋት),
					result  => q(ሽር፟ፋት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽርጥ),
					result  => q(ሽር፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽርክና),
					result  => q(ሽርክና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽርሽር),
					result  => q(ሽር፟ሽር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽርሙጥና),
					result  => q(ሽርሙጥና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽር),
					result  => q(ሽር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽምግልና),
					result  => q(ሽምግል፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽምብራ),
					result  => q(ሽምብራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽማግሌ),
					result  => q(ሽማግሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽሚያ),
					result  => q(ሽሚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽመቃ),
					result  => q(ሽመ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽልጦ),
					result  => q(ሽል፟ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽልግ),
					result  => q(ሽል፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽልት),
					result  => q(ሽል፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽልም),
					result  => q(ሽል፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽልማት),
					result  => q(ሽል፟ማት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሽለላ),
					result  => q(ሽለ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻፈደ),
					result  => q(ሻፈ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻግያ),
					result  => q(ሻግያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻገተ),
					result  => q(ሻገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻከር),
					result  => q(ሻከር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻከረ),
					result  => q(ሻከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻኛ),
					result  => q(ሻኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻንቅላ),
					result  => q(ሻንቅላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻቀለ),
					result  => q(ሻቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሻምበል),
					result  => q(ሻምበል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሺህኛ),
					result  => q(ሺህኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሹክክ),
					result  => q(ሹክክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሹክ),
					result  => q(ሹክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሹካ),
					result  => q(ሹካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሹርቤ),
					result  => q(ሹርቤ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሹራብ),
					result  => q(ሹራ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሹሩባ),
					result  => q(ሹሩ፟ባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸፍጠኛ),
					result  => q(ሸፍጠኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸፋፈነ),
					result  => q(ሸፋፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸፋጭ),
					result  => q(ሸፋ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸፈፈ),
					result  => q(ሸፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸፈጠ),
					result  => q(ሸፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸፈነ),
					result  => q(ሸፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸፈተ),
					result  => q(ሸፈ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸጠኝ),
					result  => q(ሸጠኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸጐጠ),
					result  => q(ሸጐ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸጐረ),
					result  => q(ሸጐ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸየኛ),
					result  => q(ሸየኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸውሻዋ),
					result  => q(ሸውሻዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸውራራ),
					result  => q(ሸውራ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸኮተ),
					result  => q(ሸኮ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸካፋ),
					result  => q(ሸካ፟ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸከፈ),
					result  => q(ሸከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸከሸከ),
					result  => q(ሸከሸ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸኚ),
					result  => q(ሸኚ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸኘ),
					result  => q(ሸኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸንዳራ),
					result  => q(ሸንዳራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸንካፋ),
					result  => q(ሸንካ፟ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸንከሎ),
					result  => q(ሸንከሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸንተረርማ),
					result  => q(ሸንተረርማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸንበቆ),
					result  => q(ሸንበቆ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸና),
					result  => q(ሸና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነጠ),
					result  => q(ሸነ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነገለ),
					result  => q(ሸነገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነደረ),
					result  => q(ሸነደ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነከፈ),
					result  => q(ሸነከ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነታተረ),
					result  => q(ሸነታተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነተረ),
					result  => q(ሸነተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነቆጠ),
					result  => q(ሸነቆ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነቆረ),
					result  => q(ሸነቆ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነቀጠ),
					result  => q(ሸነቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነቀረ),
					result  => q(ሸነ፟ቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸነሸነ),
					result  => q(ሸነሸ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸተትያ),
					result  => q(ሸተትያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸተት),
					result  => q(ሸተት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸተተው),
					result  => q(ሸተ፟ተው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸተተ),
					result  => q(ሸተ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸብራቃ),
					result  => q(ሸብራቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸብ),
					result  => q(ሸብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸበቶ),
					result  => q(ሸበ፟ቶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸበተ),
					result  => q(ሸበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸበበ),
					result  => q(ሸበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸበሸበ),
					result  => q(ሸበሸ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸበለለ),
					result  => q(ሸበለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸቃጭ),
					result  => q(ሸቃ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸቃይ),
					result  => q(ሸቃ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸቃቢ),
					result  => q(ሸቃ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸቀጠ),
					result  => q(ሸቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸቀበ),
					result  => q(ሸቀ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸቀሸቀ),
					result  => q(ሸቀሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸቀለ),
					result  => q(ሸቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸሻጊ),
					result  => q(ሸሻ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸር),
					result  => q(ሸር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸራረፈ),
					result  => q(ሸራረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረፈ),
					result  => q(ሸረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረደደ),
					result  => q(ሸረደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረካከተ),
					result  => q(ሸረካከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረከተ),
					result  => q(ሸረከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረኝነት),
					result  => q(ሸረኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረኛ),
					result  => q(ሸረ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረሸረ),
					result  => q(ሸረሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸረሞጠ),
					result  => q(ሸረሞ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸምበቆ),
					result  => q(ሸምበቆ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸምቃቃ),
					result  => q(ሸምቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸምቀቆ),
					result  => q(ሸምቀቆ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸሜኔ),
					result  => q(ሸሜ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸማኔ),
					result  => q(ሸማ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸማች),
					result  => q(ሸማ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸማቂ),
					result  => q(ሸማ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸመገለ),
					result  => q(ሸመገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸመድማዳ),
					result  => q(ሸመድማዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸመደደ),
					result  => q(ሸመደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸመታ),
					result  => q(ሸመ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸመተ),
					result  => q(ሸመ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸመቀቀ),
					result  => q(ሸመቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸመቀ),
					result  => q(ሸመ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸላይ),
					result  => q(ሸላ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸላች),
					result  => q(ሸላ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸላሚ),
					result  => q(ሸላ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸላለመ),
					result  => q(ሸላለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸለገ),
					result  => q(ሸለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸለተ),
					result  => q(ሸለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸለብ),
					result  => q(ሸለ፟ብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸለቀቀ),
					result  => q(ሸለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸለሸለ),
					result  => q(ሸለሸ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸለመ),
					result  => q(ሸለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሸለለ),
					result  => q(ሸለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሶምሶማ),
					result  => q(ሶምሶ፟ማ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሶመሶመ),
					result  => q(ሶመሶ፟መ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስፖርተኛ),
					result  => q(ስፖርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስፍስፍ),
					result  => q(ስፍስፍ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስፋፊ),
					result  => q(ስፋ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስግስግ),
					result  => q(ስግስግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስጋጃ),
					result  => q(ስጋጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስድስት),
					result  => q(ስድ፟ስት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስድስተኛ),
					result  => q(ስድ፟ስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስድሳኛ),
					result  => q(ስድሳኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስድ),
					result  => q(ስድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስደት),
					result  => q(ስደ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስደተኛ),
					result  => q(ስደ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስያሜ),
					result  => q(ስያ፟ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስውር),
					result  => q(ስው፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስኳር),
					result  => q(ስኳ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስንፍና),
					result  => q(ስንፍና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስንጣሪ),
					result  => q(ስን፟ጣ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስንግ),
					result  => q(ስን፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስንኝ),
					result  => q(ስንኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስንተኛ),
					result  => q(ስንተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስንባጭ),
					result  => q(ስንባ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስትር),
					result  => q(ስት፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስተተኛ),
					result  => q(ስተተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስብስብ),
					result  => q(ስብስብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስብራት),
					result  => q(ስብ፟ራት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስባሪ),
					result  => q(ስባ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስቅቅ),
					result  => q(ስቅ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስቅላት),
					result  => q(ስቅ፟ላት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስርዝ),
					result  => q(ስር፟ዝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስርቅታ),
					result  => q(ስር፟ቅታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስርቅ),
					result  => q(ስር፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስሪያ),
					result  => q(ስሪ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስረዛ),
					result  => q(ስረ፟ዛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስሞተኛ),
					result  => q(ስሞተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስምንት),
					result  => q(ስም፟ንት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስምንተኛ),
					result  => q(ስምንተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስምምነት),
					result  => q(ስምምነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስምም),
					result  => q(ስምም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስሜት),
					result  => q(ስሜ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስመኛ),
					result  => q(ስመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስልከኛ),
					result  => q(ስልከኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስልቻ),
					result  => q(ስል፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስልቅ),
					result  => q(ስል፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስልሳኛ),
					result  => q(ስልሳኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስልምልም),
					result  => q(ስልምልም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስልም),
					result  => q(ስል፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስሌት),
					result  => q(ስሌ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስለዚያ),
					result  => q(ስለዚ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስለዚህ),
					result  => q(ስለዚ፟ህ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስለሱ),
					result  => q(ስለሱ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ስለላ),
					result  => q(ስለ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሴትነት),
					result  => q(ሴትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሴተኛ),
					result  => q(ሴተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሴሰኝነት),
					result  => q(ሴሰኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሴሰኛነት),
					result  => q(ሴሰኛ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሴሰኛ),
					result  => q(ሴሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሴሰነ),
					result  => q(ሴሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሴረኛ),
					result  => q(ሴረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳዱላ),
					result  => q(ሳዱላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳይንሰኛ),
					result  => q(ሳይንሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳንባማ),
					result  => q(ሳንባማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳቢያ),
					result  => q(ሳቢ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳቅ),
					result  => q(ሳቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳቂታ),
					result  => q(ሳቂ፟ታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳምንት),
					result  => q(ሳም፟ንት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳምንታዊ),
					result  => q(ሳም፟ንታዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳማ),
					result  => q(ሳማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳሎን),
					result  => q(ሳሎ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሳሌ),
					result  => q(ሳሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሲቀድ),
					result  => q(ሲቀድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሲል),
					result  => q(ሲል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሱፋጭ),
					result  => q(ሱፋ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሱካር),
					result  => q(ሱካ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሱሰኛ),
					result  => q(ሱሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሱሪ),
					result  => q(ሱሪ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሱረት),
					result  => q(ሱረ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፍሳፋ),
					result  => q(ሰፍሳፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፋ),
					result  => q(ሰፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፊው),
					result  => q(ሰፊ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፊ),
					result  => q(ሰ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፈፈ),
					result  => q(ሰፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፈነ),
					result  => q(ሰፈ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፈርተኛ),
					result  => q(ሰፈርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፈረተኛ),
					result  => q(ሰፈረተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰፈረ),
					result  => q(ሰፈ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰጠመ),
					result  => q(ሰጠ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰጠ),
					result  => q(ሰጠ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰጓዳ),
					result  => q(ሰጓዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰጐደ),
					result  => q(ሰጐ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰጉዳት),
					result  => q(ሰጉ፟ዳ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰገገ),
					result  => q(ሰገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰገደ),
					result  => q(ሰገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰገነት),
					result  => q(ሰገነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰገሰገ),
					result  => q(ሰገሰ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰደደ),
					result  => q(ሰደ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰደበ),
					result  => q(ሰደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰይፈኛ),
					result  => q(ሰይፈኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰያፍ),
					result  => q(ሰያ፟ፍ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰያፊ),
					result  => q(ሰያ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰየፈ),
					result  => q(ሰየ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰየመ),
					result  => q(ሰየ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰውዬ),
					result  => q(ሰውዬ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰውየውን),
					result  => q(ሰውየ፟ውን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰውየው),
					result  => q(ሰውየ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰውነት),
					result  => q(ሰውነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰውነቱን),
					result  => q(ሰውነ፟ቱን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰውነቱ),
					result  => q(ሰውነ፟ቱ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰካራም),
					result  => q(ሰካ፟ራም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰካ),
					result  => q(ሰካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰከነ),
					result  => q(ሰከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰከሰከ),
					result  => q(ሰከሰ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰከረ),
					result  => q(ሰከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰኞ),
					result  => q(ሰኞ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰንካላ),
					result  => q(ሰንካላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰንከሎ),
					result  => q(ሰንከሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰኔና),
					result  => q(ሰኔና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነፈጠ),
					result  => q(ሰነፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነፈ),
					result  => q(ሰነ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነገ),
					result  => q(ሰነ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነዘረ),
					result  => q(ሰነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነከለ),
					result  => q(ሰነከ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነኘ),
					result  => q(ሰነኘ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነበጠ),
					result  => q(ሰነበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነበተ),
					result  => q(ሰነበ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነቀረ),
					result  => q(ሰነቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰነቀ),
					result  => q(ሰነ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰታራ),
					result  => q(ሰታ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰተት),
					result  => q(ሰተት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰተረ),
					result  => q(ሰተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰብሳባ),
					result  => q(ሰብሳባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰባኛ),
					result  => q(ሰባኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰባት),
					result  => q(ሰባት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰባተኛ),
					result  => q(ሰባተ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰባበረ),
					result  => q(ሰባበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰባሰበ),
					result  => q(ሰባሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰባ),
					result  => q(ሰባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰበከ),
					result  => q(ሰበ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰበበኛ),
					result  => q(ሰበበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰበቀ),
					result  => q(ሰበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰበሰበ),
					result  => q(ሰበሰ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰበረ),
					result  => q(ሰበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰቅ),
					result  => q(ሰቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰቀዘ),
					result  => q(ሰቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰቀቀኝ),
					result  => q(ሰቀ፟ቀኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰቀቀ),
					result  => q(ሰቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰቀለ),
					result  => q(ሰቀ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰሰነ),
					result  => q(ሰሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰራረዘ),
					result  => q(ሰራረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰረጎደ),
					result  => q(ሰረጎ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰረገላ),
					result  => q(ሰረገላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰረዘ),
					result  => q(ሰረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰረቀ),
					result  => q(ሰረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰረሰረ),
					result  => q(ሰረሰ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰረረ),
					result  => q(ሰረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰሞንኛ),
					result  => q(ሰሞንኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰምና),
					result  => q(ሰምና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰማዕትነት),
					result  => q(ሰማዕትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰማ),
					result  => q(ሰማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰመጠ),
					result  => q(ሰመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰመመ),
					result  => q(ሰመ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰልፈኛ),
					result  => q(ሰልፈኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰልካካ),
					result  => q(ሰልካካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰላይ),
					result  => q(ሰላ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰላች),
					result  => q(ሰላ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰላማዊነት),
					result  => q(ሰላማዊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰላላ),
					result  => q(ሰላ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰላ),
					result  => q(ሰላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለቸ),
					result  => q(ሰለቸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለተ),
					result  => q(ሰለ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለበ),
					result  => q(ሰለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለቀጠ),
					result  => q(ሰለቀ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለቀ),
					result  => q(ሰለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለሰለ),
					result  => q(ሰለሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለመ),
					result  => q(ሰለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሰለለ),
					result  => q(ሰለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሮሮ),
					result  => q(ሮሮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርጋፊ),
					result  => q(ርጋ፟ፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርጋጭ),
					result  => q(ርጋ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርዝራዥ),
					result  => q(ርዝራ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርክክብ),
					result  => q(ርክክ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርካሽ),
					result  => q(ርካ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርችት),
					result  => q(ርች፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርቀት),
					result  => q(ርቀ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ርሚጦ),
					result  => q(ርሚ፟ጦ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ራብተኛ),
					result  => q(ራብተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ራራ),
					result  => q(ራራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሩስኛ),
					result  => q(ሩስኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሩሩ),
					result  => q(ሩሩ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረፋድ),
					result  => q(ረፋ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረፈደ),
					result  => q(ረፈ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረፈረፈ),
					result  => q(ረፈረ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረጋገጠ),
					result  => q(ረጋገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረጋ),
					result  => q(ረጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረገፈ),
					result  => q(ረገ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረገጠ),
					result  => q(ረገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረገብ),
					result  => q(ረገብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረገበ),
					result  => q(ረገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረገመ),
					result  => q(ረገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረጅም),
					result  => q(ረጅ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረዳት),
					result  => q(ረዳ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረዳ),
					result  => q(ረዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረዥም),
					result  => q(ረዥ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረዘቀ),
					result  => q(ረዘ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረዘረዘ),
					result  => q(ረዘረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረዘመ),
					result  => q(ረዘ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረኸጥነት),
					result  => q(ረኸጥነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረካ),
					result  => q(ረካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረከሰ),
					result  => q(ረከ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረኅብተኛ),
					result  => q(ረኅብተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረታ),
					result  => q(ረታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረብሸኛ),
					result  => q(ረብሸኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረባዳ),
					result  => q(ረባ፟ዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረባ),
					result  => q(ረባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረበበ),
					result  => q(ረበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረበሸ),
					result  => q(ረበ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረበረበ),
					result  => q(ረበረ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረቂቅነት),
					result  => q(ረቂቅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረቀቀ),
					result  => q(ረቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረሳ),
					result  => q(ረሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረሰረሰ),
					result  => q(ረሰረ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ረመጠ),
					result  => q(ረመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሦስተኛ),
					result  => q(ሦስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥያሜ),
					result  => q(ሥያ፟ሜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥቅቅ),
					result  => q(ሥቅቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥርቻ),
					result  => q(ሥርቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥሥነት),
					result  => q(ሥሥነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥሥት),
					result  => q(ሥሥ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥሡ),
					result  => q(ሥሡ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥልጣኔ),
					result  => q(ሥል፟ጣ፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥላሴ),
					result  => q(ሥላ፟ሴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥሉጥ),
					result  => q(ሥሉ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሥሉስ),
					result  => q(ሥሉ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሣርማ),
					result  => q(ሣርማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሣሣ),
					result  => q(ሣሣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠጋር),
					result  => q(ሠጋ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠጋ),
					result  => q(ሠጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠገረ),
					result  => q(ሠገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠያሚ),
					result  => q(ሠያ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠየመ),
					result  => q(ሠየ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠዓሊነት),
					result  => q(ሠዓሊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠዋራ),
					result  => q(ሠዋ፟ራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠዋ),
					result  => q(ሠዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠዊ),
					result  => q(ሠዊ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠወርዋራ),
					result  => q(ሠወርዋራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠወረ),
					result  => q(ሠወ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠናይ),
					result  => q(ሠና፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠቀቀ),
					result  => q(ሠቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠቀሠቀ),
					result  => q(ሠቀሠ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠራጊ),
					result  => q(ሠራ፟ጊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠራው),
					result  => q(ሠራ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠራተኛ),
					result  => q(ሠራ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠራ),
					result  => q(ሠራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠረገ),
					result  => q(ሠረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠረሠረ),
					result  => q(ሠረሠ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠመረ),
					result  => q(ሠመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠላጤ),
					result  => q(ሠላ፟ጤ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠለጠ),
					result  => q(ሠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሠለሰ),
					result  => q(ሠለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሟጠጠ),
					result  => q(ሟጠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሟከከ),
					result  => q(ሟከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሟሸሸ),
					result  => q(ሟሸ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሟሟ),
					result  => q(ሟሟ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሟለጠ),
					result  => q(ሟለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞጨሞጨ),
					result  => q(ሞጨሞ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞጨለፈ),
					result  => q(ሞጨለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞጋች),
					result  => q(ሞጋ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞገገ),
					result  => q(ሞገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞገደኛ),
					result  => q(ሞገደ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞገተ),
					result  => q(ሞገ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞጀረ),
					result  => q(ሞጀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞያተኛ),
					result  => q(ሞያተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞዛዛነት),
					result  => q(ሞዛዛነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞዘዘ),
					result  => q(ሞዘ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞካች),
					result  => q(ሞካ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞካሪ),
					result  => q(ሞካ፟ሪ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞከከ),
					result  => q(ሞከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞከተ),
					result  => q(ሞከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞከረ),
					result  => q(ሞከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞነተፈ),
					result  => q(ሞነተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞቅሟቃ),
					result  => q(ሞቅሟቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞቃት),
					result  => q(ሞቃ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞቀኝ),
					result  => q(ሞቀኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞቀሞቀ),
					result  => q(ሞቀሞ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞሽላቃ),
					result  => q(ሞሽላቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞሸረ),
					result  => q(ሞሸ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞሸለቀ),
					result  => q(ሞሸለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞረድ),
					result  => q(ሞረ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞረደ),
					result  => q(ሞረ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞረሞረ),
					result  => q(ሞረሞ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞልቃቃ),
					result  => q(ሞልቃቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞልሟላ),
					result  => q(ሞልሟ፟ላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞላጫ),
					result  => q(ሞላ፟ጫ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞላላነት),
					result  => q(ሞላላ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞላላ),
					result  => q(ሞላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞላ),
					result  => q(ሞላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞለፈጠ),
					result  => q(ሞለፈ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞለጨ),
					result  => q(ሞለ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞለሞለ),
					result  => q(ሞለሞ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሞለለ),
					result  => q(ሞለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምጥዋተኛ),
					result  => q(ምጥዋተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምድጃ),
					result  => q(ምድጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምደባ),
					result  => q(ምደ፟ባ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምክትል),
					result  => q(ምክት፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምኞት),
					result  => q(ምኞ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምንጠራ),
					result  => q(ምንጠ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምንጅላት),
					result  => q(ምንጅላ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምንደኛ),
					result  => q(ምንደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምንኩስና),
					result  => q(ምንኩስና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምንኛ),
					result  => q(ምንኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምንም),
					result  => q(ምንም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምናኔ),
					result  => q(ምና፟ኔ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምነና),
					result  => q(ምነ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምቾት),
					result  => q(ምቾ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምች),
					result  => q(ምች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምቹነት),
					result  => q(ምቹ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምቹ),
					result  => q(ምቹ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምትክ),
					result  => q(ምትክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምቀኝነት),
					result  => q(ምቀ፟ኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምቀኛ),
					result  => q(ምቀ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሽግ),
					result  => q(ምሽ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሽት),
					result  => q(ምሽ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስፍና),
					result  => q(ምስፍና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስጢረኛ),
					result  => q(ምስጢረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስግ),
					result  => q(ምስ፟ግ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስክር),
					result  => q(ምስክ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስኪንነት),
					result  => q(ምስኪንነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስራች),
					result  => q(ምስራች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስሪት),
					result  => q(ምስ፟ሪት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምስ),
					result  => q(ምስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሳር),
					result  => q(ምሳ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሳሌ),
					result  => q(ምሳ፟ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሰሶ),
					result  => q(ምሰሶ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምርጊት),
					result  => q(ምርጊት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምርኮኛ),
					result  => q(ምርኮኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምርቃት),
					result  => q(ምር፟ቃት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምርር),
					result  => q(ምርር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምርምር),
					result  => q(ምርም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምር),
					result  => q(ምር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሬት),
					result  => q(ምሬ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምራጭ),
					result  => q(ምራ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሪት),
					result  => q(ምሪ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምሩቅ),
					result  => q(ምሩ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምረት),
					result  => q(ምረ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምረቃ),
					result  => q(ምረ፟ቃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምልክት),
					result  => q(ምልክ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምልስ),
					result  => q(ምል፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምላሽ),
					result  => q(ምላ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምላሰኝነት),
					result  => q(ምላሰኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ምላሰኛ),
					result  => q(ምላሰኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሜዳማ),
					result  => q(ሜዳማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማፈኛ),
					result  => q(ማፈ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማግሰኞ),
					result  => q(ማግሰኞ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማጋጭነት),
					result  => q(ማጋጭነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማጋጣነት),
					result  => q(ማጋጣነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማገጠ),
					result  => q(ማገ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማገጃ),
					result  => q(ማገ፟ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማገደ),
					result  => q(ማገ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማገረ),
					result  => q(ማገ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማድጋ),
					result  => q(ማድጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማዳመጫ),
					result  => q(ማዳ፟መጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማደያ),
					result  => q(ማደ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማይክሮስኮፕ),
					result  => q(ማይክሮስኮፕ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማዕድን),
					result  => q(ማዕድ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማዕድ),
					result  => q(ማዕድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማዕረገኛ),
					result  => q(ማዕረገኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማዋሐጃ),
					result  => q(ማዋ፟ሐጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማክሰኞ),
					result  => q(ማክሰኞ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማካፈል),
					result  => q(ማካ፟ፈል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማከፋፈያ),
					result  => q(ማከ፟ፋፈያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማእድ),
					result  => q(ማእድ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማንኛውም),
					result  => q(ማን፟ኛ፟ውም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማንም),
					result  => q(ማንም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማን),
					result  => q(ማን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማናበቢያ),
					result  => q(ማና፟በቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማነቃቂያ),
					result  => q(ማነ፟ቃቂያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማኅበርተኝነት),
					result  => q(ማኅበርተኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማኅበርተኛ),
					result  => q(ማኅበርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማኅበረተኛ),
					result  => q(ማኅበረተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማተሚያ),
					result  => q(ማተ፟ሚያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማቋረጫ),
					result  => q(ማቋ፟ረጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማቀቀ),
					result  => q(ማቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሾለቂያ),
					result  => q(ማሾለ፟ቂያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሽላ),
					result  => q(ማሽላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሻሻያ),
					result  => q(ማሻ፟ሻያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሸጊያ),
					result  => q(ማሸ፟ጊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማስጠሎ),
					result  => q(ማስጠሎ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማስወረድ),
					result  => q(ማስወረ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማስቀመጫ),
					result  => q(ማስቀመ፟ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማስረጃ),
					result  => q(ማስረጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሳተሚያ),
					result  => q(ማሳተ፟ሚያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሳመኛ),
					result  => q(ማሳመ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሰፊያ),
					result  => q(ማሰ፟ፊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሰሻ),
					result  => q(ማሰ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማራገቢያ),
					result  => q(ማራ፟ገቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማራቢያ),
					result  => q(ማራ፟ቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማረገኛ),
					result  => q(ማረገኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማረከ),
					result  => q(ማረ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማረረ),
					result  => q(ማረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሟያ),
					result  => q(ማሟ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሞኛ),
					result  => q(ማሞኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሞ),
					result  => q(ማሞ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማምረቻና),
					result  => q(ማምረቻና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማማሰያ),
					result  => q(ማማ፟ሰያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሚቶ),
					result  => q(ማሚ፟ቶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሚቴ),
					result  => q(ማሚ፟ቴ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማመሻ),
					result  => q(ማመ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማመላለሻ),
					result  => q(ማመ፟ላለሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማሕሌተኛ),
					result  => q(ማሕሌተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማላጋነት),
					result  => q(ማላጋነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማላ),
					result  => q(ማላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማለገ),
					result  => q(ማለ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማለደ),
					result  => q(ማለ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማለቢያ),
					result  => q(ማለቢ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ማለለ),
					result  => q(ማለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሚዳቋ),
					result  => q(ሚዳቋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሚሊዮን),
					result  => q(ሚሊ፟ዮን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙጥኝ),
					result  => q(ሙጥ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙግግ),
					result  => q(ሙግግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙግት),
					result  => q(ሙግ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙጅር),
					result  => q(ሙጅ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙጃማ),
					result  => q(ሙጃ፟ማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙጃ),
					result  => q(ሙጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዳ),
					result  => q(ሙዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙያተኛ),
					result  => q(ሙያተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙያሌ),
					result  => q(ሙያ፟ሌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዝዝ),
					result  => q(ሙዝዝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዚቀኛ),
					result  => q(ሙዚቀኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዋጠጠ),
					result  => q(ሙዋጠ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዋሸሸ),
					result  => q(ሙዋሸ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዋርተኛ),
					result  => q(ሙዋርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዋሙዋ),
					result  => q(ሙዋሙ፟ዋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙዋለጠ),
					result  => q(ሙዋለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙክክ),
					result  => q(ሙክክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙክት),
					result  => q(ሙክ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙከራ),
					result  => q(ሙከ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙትቻ),
					result  => q(ሙትቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙሽራ),
					result  => q(ሙሽ፟ራ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙሽሪት),
					result  => q(ሙሽሪ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙረዳ),
					result  => q(ሙረ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙልል),
					result  => q(ሙልል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙላጭ),
					result  => q(ሙላ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሙሀቻ),
					result  => q(ሙሀቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መፈክር),
					result  => q(መፈክ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መፈናፈኛ),
					result  => q(መፈ፟ናፈኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መፈተኛ),
					result  => q(መፈተ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጸወተ),
					result  => q(መጸወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጫኛ),
					result  => q(መጫኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጨመጨ),
					result  => q(መጨመ፟ጨ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጥቼ),
					result  => q(መጥቼ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጠይቅ),
					result  => q(መጠይ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጠወተ),
					result  => q(መጠወ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጠነኛ),
					result  => q(መጠነኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጠመጠ),
					result  => q(መጠመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጓጓዣ),
					result  => q(መጓ፟ጓዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጎናጸፊ),
					result  => q(መጎ፟ናጸፊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጎናጠፊያ),
					result  => q(መጎ፟ናጠፊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጋዣ),
					result  => q(መጋዣ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጋዞ),
					result  => q(መጋ፟ዞ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጋቢት),
					result  => q(መጋ፟ቢት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጋቢ),
					result  => q(መጋ፟ቢ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጋረጃ),
					result  => q(መጋ፟ረጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መገጣጠሚያ),
					result  => q(መገ፟ጣጠሚያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መገነዣ),
					result  => q(መገነ፟ዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መገበ),
					result  => q(መገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መገመገ),
					result  => q(መገመ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መገለ),
					result  => q(መገ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መጀመሪያ),
					result  => q(መጀመ፟ሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መድፈኛ),
					result  => q(መድፈኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መድጎሚያ),
					result  => q(መድጎ፟ሚያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መድሃኒተኛ),
					result  => q(መድሃኒተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደገፊያ),
					result  => q(መደ፟ገፊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደደ),
					result  => q(መደደ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደብር),
					result  => q(መደብ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደብ),
					result  => q(መደ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደበኛ),
					result  => q(መደበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደበ),
					result  => q(መደ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደቆሻ),
					result  => q(መደቆ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደረቢያ),
					result  => q(መደረ፟ቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደመደ),
					result  => q(መደመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደለያ),
					result  => q(መደ፟ለያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መደለዣ),
					result  => q(መደለ፟ዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዛኝ),
					result  => q(መዛ፟ኝ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘገበ),
					result  => q(መዘገ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘዘኛ),
					result  => q(መዘዘኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘውር),
					result  => q(መዘው፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘክር),
					result  => q(መዘክ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘነ),
					result  => q(መዘ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘባበቻ),
					result  => q(መዘ፟ባበቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘበረ),
					result  => q(መዘበ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘምር),
					result  => q(መዘም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘምራን),
					result  => q(መዘም፟ራን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዘመዘ),
					result  => q(መዘመ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዐተኛ),
					result  => q(መዐተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መዋጮ),
					result  => q(መዋ፟ጮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መወሰኛ),
					result  => q(መወሰ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መኰንን),
					result  => q(መኰን፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መካከረ),
					result  => q(መካከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መካከል),
					result  => q(መካከ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መካከለኛ),
					result  => q(መካከ፟ለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መካንነት),
					result  => q(መካ፟ንነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መካን),
					result  => q(መካ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መካች),
					result  => q(መካ፟ች),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከፈኛ),
					result  => q(መከፈ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከዳ),
					result  => q(መከ፟ዳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከናነቢያ),
					result  => q(መከ፟ናነቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከነ),
					result  => q(መከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከተ),
					result  => q(መከ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከረኛ),
					result  => q(መከረ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከረ),
					result  => q(መከ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከማቻ),
					result  => q(መከ፟ማቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከላከያ),
					result  => q(መከ፟ላከያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መከለሻ),
					result  => q(መከለ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መኝታ),
					result  => q(መኝ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መኖ),
					result  => q(መኖ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንፈሳዊነት),
					result  => q(መንፈሳዊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንጫቃ),
					result  => q(መንጫ፟ቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንጫራ),
					result  => q(መንጫራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንጠቆ),
					result  => q(መንጠቆ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንገደኛ),
					result  => q(መንገደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንደርተኛ),
					result  => q(መንደርተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንደረኛ),
					result  => q(መንደረኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንቻካ),
					result  => q(መንቻካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንቃራ),
					result  => q(መንቃራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መንማና),
					result  => q(መንማና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መናፈሻ),
					result  => q(መና፟ፈሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መናገሻ),
					result  => q(መና፟ገሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መናኝ),
					result  => q(መና፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መናኛ),
					result  => q(መናኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መና),
					result  => q(መና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነጽር),
					result  => q(መነጽ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነጥር),
					result  => q(መነጥ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነገገ),
					result  => q(መነገ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነዛዘረ),
					result  => q(መነዛዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነዘረ),
					result  => q(መነዘ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነኰሰ),
					result  => q(መነኰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነነ),
					result  => q(መነ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነቸከ),
					result  => q(መነቸ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነተፈ),
					result  => q(መነተ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነቃቀረ),
					result  => q(መነቃቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነቀረ),
					result  => q(መነቀ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነሾ),
					result  => q(መነ፟ሾ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነሻ),
					result  => q(መነ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነሣት),
					result  => q(መነ፟ሣት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መነመነ),
					result  => q(መነመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቼውንም),
					result  => q(መቼ፟ውንም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቼም),
					result  => q(መቼ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቶኛ),
					result  => q(መቶኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መትረየስ),
					result  => q(መትረየ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታጫ),
					result  => q(መታ፟ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታጠፊያ),
					result  => q(መታ፟ጠፊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታጠቢያ),
					result  => q(መታ፟ጠቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታጠቂያ),
					result  => q(መታ፟ጠቂያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታወቂያ),
					result  => q(መታ፟ወቂያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታታ),
					result  => q(መታታ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታተረ),
					result  => q(መታተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታሻ),
					result  => q(መታ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታሰቢያ),
					result  => q(መታ፟ሰቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታረቂያ),
					result  => q(መታ፟ረቂያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታሠሪያ),
					result  => q(መታ፟ሠሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታመኛ),
					result  => q(መታ፟መኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መታ),
					result  => q(መ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተዳደሪያ),
					result  => q(መተ፟ዳደሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተከያ),
					result  => q(መተ፟ከያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተከዣ),
					result  => q(መተከ፟ዣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተኛ),
					result  => q(መተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተተኛ),
					result  => q(መተተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተረክያ),
					result  => q(መተረ፟ክያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተረቻ),
					result  => q(መተረ፟ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተረ),
					result  => q(መተ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተማመኛ),
					result  => q(መተ፟ማመኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መተላለፊያ),
					result  => q(መተ፟ላለፊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መበደሪያ),
					result  => q(መበ፟ደሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መበያ),
					result  => q(መበ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መበየጃ),
					result  => q(መበየ፟ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መበላት),
					result  => q(መበ፟ላት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መበለት),
					result  => q(መበለ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቍጠሪያ),
					result  => q(መቍ፟ጠሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቋቋሚያ),
					result  => q(መቋ፟ቋሚያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቆፈሪያ),
					result  => q(መቆፈ፟ሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቆጣጠሪያ),
					result  => q(መቆ፟ጣጠሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቆያ),
					result  => q(መቆያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቃጠሪያ),
					result  => q(መቃ፟ጠሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀጮ),
					result  => q(መቀ፟ጮ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀጫ),
					result  => q(መቀ፟ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀጣጫ),
					result  => q(መቀ፟ጣጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀየሻ),
					result  => q(መቀየ፟ሻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀነቻ),
					result  => q(መቀነ፟ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀነት),
					result  => q(መቀነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀቀያ),
					result  => q(መቀቀ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀመጫ),
					result  => q(መቀ፟መጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መቀለጃ),
					result  => q(መቀለ፟ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሻገሪያ),
					result  => q(መሻ፟ገሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸፈኛ),
					result  => q(መሸፈ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸፈቻ),
					result  => q(መሸፈ፟ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸጋሸጊያ),
					result  => q(መሸ፟ጋሸጊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸገ),
					result  => q(መሸ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸኛ),
					result  => q(መሸኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸተኛ),
					result  => q(መሸተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸተ),
					result  => q(መሸ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸበቢያ),
					result  => q(መሸበ፟ቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸቀጫ),
					result  => q(መሸቀ፟ጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸሸጊያ),
					result  => q(መሸ፟ሸጊያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸለቻ),
					result  => q(መሸለ፟ቻ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሸ),
					result  => q(መሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መስፈሪያ),
					result  => q(መስ፟ፈሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መስኮብኛ),
					result  => q(መስኮብኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መስካሪነት),
					result  => q(መስካሪነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መስተአምር),
					result  => q(መስተአም፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መስቀልያ),
					result  => q(መስቀልያ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መስቀልኛ),
					result  => q(መስቀልኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሳፍቻ),
					result  => q(መሳ፟ፍቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሳጭ),
					result  => q(መሳ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሳለቂያ),
					result  => q(መሳ፟ለቂያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሳለሚያ),
					result  => q(መሳ፟ለሚያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሳ),
					result  => q(መሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰጠ),
					result  => q(መሰ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰገ),
					result  => q(መሰ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰደጃ),
					result  => q(መሰ፟ደጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰኪያ),
					result  => q(መሰኪ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰከነ),
					result  => q(መሰከ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰከረ),
					result  => q(መሰከ፟ረ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰናዶ),
					result  => q(መሰ፟ናዶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰናዘሪያ),
					result  => q(መሰ፟ናዘሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰነ),
					result  => q(መሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰብሰቢያ),
					result  => q(መሰ፟ብሰቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሰለ),
					result  => q(መሰ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መርዘኛ),
					result  => q(መርዘኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መርከበኛ),
					result  => q(መርከበኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መር),
					result  => q(መር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራጭነት),
					result  => q(መራጭነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራገጫ),
					result  => q(መራ፟ገጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራዥ),
					result  => q(መራ፟ዥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራቢያ),
					result  => q(መራ፟ቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራቂ),
					result  => q(መራ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራርነት),
					result  => q(መራ፟ርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራር),
					result  => q(መራ፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራራነት),
					result  => q(መራ፟ራነት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መራ),
					result  => q(መራ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሪነት),
					result  => q(መሪነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረጠ),
					result  => q(መረ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረጋገጫ),
					result  => q(መረ፟ጋገጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረገጫ),
					result  => q(መረ፟ገጫ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረገ),
					result  => q(መረ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረጃ),
					result  => q(መረ፟ጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረዘ),
					result  => q(መረ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረዋ),
					result  => q(መረዋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረነ),
					result  => q(መረ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረተ),
					result  => q(መረ፟ተ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረባ),
					result  => q(መረባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረቀዘ),
					result  => q(መረቀ፟ዘ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረቀ),
					result  => q(መረ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረረው),
					result  => q(መረ፟ረው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረረ),
					result  => q(መረ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረማመጃ),
					result  => q(መረ፟ማመጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መረመረ),
					result  => q(መረመ፟ረ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሥዋዕትነት),
					result  => q(መሥዋዕትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሣሪያ),
					result  => q(መሣ፟ሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሠውር),
					result  => q(መሠው፟ር),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሠዊያ),
					result  => q(መሠዊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሠሪነት),
					result  => q(መሠሪ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሠሪ),
					result  => q(መሠሪ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መምህርነት),
					result  => q(መምህርነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መማለጃ),
					result  => q(መማ፟ለጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መመጻደቅ),
					result  => q(መመ፟ጻደቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መመዝገቢያ),
					result  => q(መመ፟ዝገቢያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መመዘኛ),
					result  => q(መመዘ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መመነኛ),
					result  => q(መመነ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መመሪያ),
					result  => q(መመ፟ሪያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሐላ),
					result  => q(መሐላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሐለቅ),
					result  => q(መሐለ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መልከኛ),
					result  => q(መልከኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መልእክተኛ),
					result  => q(መልእክተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መልቲነት),
					result  => q(መልቲነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መልሶ),
					result  => q(መል፟ሶ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መልመጃ),
					result  => q(መል፟መጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መላጣነት),
					result  => q(መላጣነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መላክተኛ),
					result  => q(መላክተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መላሽ),
					result  => q(መላ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መላ),
					result  => q(መላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለጠ),
					result  => q(መለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለዮ),
					result  => q(መለ፟ዮ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለወጫ),
					result  => q(መለ፟ወጫ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለኮትነት),
					result  => q(መለኮትነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለቃለቂያ),
					result  => q(መለ፟ቃለቂያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለሰ),
					result  => q(መለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለማመጃ),
					result  => q(መለ፟ማመጃ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መለለ),
					result  => q(መለ፟ለ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሃይምነት),
					result  => q(መሃይ፟ምነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሃይም),
					result  => q(መሃይ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሀከል),
					result  => q(መሀከ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሀከለኛ),
					result  => q(መሀከ፟ለኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(መሀንዲስነት),
					result  => q(መሀንዲስነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕፃንነት),
					result  => q(ሕፃን፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕጓ),
					result  => q(ሕጓ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕግ),
					result  => q(ሕግ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕጋዊነት),
					result  => q(ሕጋ፟ዊነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕጋዊ),
					result  => q(ሕጋ፟ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕገ),
					result  => q(ሕገ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕያውነት),
					result  => q(ሕያውነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕክምና),
					result  => q(ሕክ፟ምና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕቅታ),
					result  => q(ሕቅ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕቅ),
					result  => q(ሕቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሕመምተኛ),
					result  => q(ሕመምተ፟ኛ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሑርነት),
					result  => q(ሑር፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሑር),
					result  => q(ሑር፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐዲስ),
					result  => q(ሐዲ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐዘንተኛ),
					result  => q(ሐዘንተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐዋርያነት),
					result  => q(ሐዋርያነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐዋላ),
					result  => q(ሐዋ፟ላ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐኬተኝነት),
					result  => q(ሐኬተኝ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐኬተኛ),
					result  => q(ሐኬተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐካይ),
					result  => q(ሐካ፟ይ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐች),
					result  => q(ሐች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐተተኛ),
					result  => q(ሐተተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐቅ),
					result  => q(ሐቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐቀኛነት),
					result  => q(ሐቀ፟ኛ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐቀኛ),
					result  => q(ሐቀ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐሳዌ),
					result  => q(ሐሳ፟ዌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐሳብ),
					result  => q(ሐሳ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐሰት),
					result  => q(ሐሰ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐሰተኛ),
					result  => q(ሐሰ፟ተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐሜት),
					result  => q(ሐሜ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐሜተኛ),
					result  => q(ሐሜተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐማልነት),
					result  => q(ሐማ፟ልነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሐማል),
					result  => q(ሐማ፟ል),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሎቲ),
					result  => q(ሎቲ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሎሌነት),
					result  => q(ሎሌነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልፋጭ),
					result  => q(ልፋ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልፋጫም),
					result  => q(ልፋ፟ጫም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልፊያ),
					result  => q(ልፊ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልፈፋ),
					result  => q(ልፈ፟ፋ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልጨኛ),
					result  => q(ልጨ፟ኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልጥፋት),
					result  => q(ል፟ጥ፟ፋት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልግስና),
					result  => q(ልግ፟ስና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልግመኛ),
					result  => q(ልግመኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልጉም),
					result  => q(ልጉ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልጅነት),
					result  => q(ልጅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልጃገረድነት),
					result  => q(ልጃገረድነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልዩነት),
					result  => q(ልዩ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልዩ),
					result  => q(ልዩ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልዝብ),
					result  => q(ልዝ፟ብ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልዕልና),
					result  => q(ልዕልና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልውውጥ),
					result  => q(ልውው፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልዋጭ),
					result  => q(ልዋ፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልክ),
					result  => q(ልክ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልኩን),
					result  => q(ልኩ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልብጥ),
					result  => q(ልብ፟ጥ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልብድ),
					result  => q(ልብ፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልብዳት),
					result  => q(ልብ፟ዳት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልብቅ),
					result  => q(ልብ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልብስ),
					result  => q(ልብ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልብ),
					result  => q(ልብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልባዊ),
					result  => q(ልባ፟ዊ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልባሽ),
					result  => q(ልባ፟ሽ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልባም),
					result  => q(ልባ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቡና),
					result  => q(ልቡ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቡ),
					result  => q(ልቡ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልበ),
					result  => q(ልበ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቅነት),
					result  => q(ልቅ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቅቅ),
					result  => q(ልቅቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቅም),
					result  => q(ልቅ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቅ),
					result  => q(ልቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቃቂት),
					result  => q(ልቃ፟ቂት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቃቂ),
					result  => q(ልቃ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልቃሚ),
					result  => q(ልቃ፟ሚ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልስን),
					result  => q(ልስ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልስላሴ),
					result  => q(ልስላ፟ሴ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልሳን),
					result  => q(ልሳ፟ን),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልሳነ),
					result  => q(ልሳ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልምጭ),
					result  => q(ልም፟ጭ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልምጥ),
					result  => q(ልም፟ጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልምምድ),
					result  => q(ልምም፟ድ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልማደኛ),
					result  => q(ልማደኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ልመና),
					result  => q(ልመ፟ና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሌጣነት),
					result  => q(ሌጣነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሌብነት),
					result  => q(ሌብነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላጲስ),
					result  => q(ላጲ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላይኛ),
					result  => q(ላይኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላከከ),
					result  => q(ላከ፟ከ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላቆጠ),
					result  => q(ላቆ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላቅ),
					result  => q(ላቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላቂያ),
					result  => q(ላቂ፟ያ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላሸቀ),
					result  => q(ላሸ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላሸ),
					result  => q(ላሸ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላምባ),
					result  => q(ላምባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ላላ),
					result  => q(ላላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሊቅነት),
					result  => q(ሊቅነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለፋ),
					result  => q(ለፋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለፈፈ),
					result  => q(ለፈ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለፈለፈ),
					result  => q(ለፈለ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጫካ),
					result  => q(ለጫካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጠለጠ),
					result  => q(ለጠለ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጐመ),
					result  => q(ለጐ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጎደ),
					result  => q(ለጎ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጎን),
					result  => q(ለጎን፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለግላጋ),
					result  => q(ለግላጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጋስነት),
					result  => q(ለጋ፟ስነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጋስ),
					result  => q(ለጋ፟ስ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጋ),
					result  => q(ለጋ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለገሰ),
					result  => q(ለገ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለገመ),
					result  => q(ለገ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለጅ),
					result  => q(ለጅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለይስሙላ),
					result  => q(ለይስሙላ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለያየ),
					result  => q(ለያየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለየብቻ),
					result  => q(ለየ፟ብቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለየ),
					result  => q(ለየ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለዛው),
					result  => q(ለዛ፟ው),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለዛ),
					result  => q(ለዛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለዘብተኛ),
					result  => q(ለዘ፟ብተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለዘበ),
					result  => q(ለዘ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለዋሳ),
					result  => q(ለዋ፟ሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለወጠ),
					result  => q(ለወ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለወሰ),
					result  => q(ለወሰ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለኮፈ),
					result  => q(ለኮ፟ፈ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለኮሰ),
					result  => q(ለኮ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለካ),
					result  => q(ለካ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለተመ),
					result  => q(ለተ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለብቻ),
					result  => q(ለብ፟ቻ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለብታ),
					result  => q(ለብ፟ታ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለብ),
					result  => q(ለብ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለባበሰ),
					result  => q(ለባበ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለባቃ),
					result  => q(ለባ፟ቃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለበጠ),
					result  => q(ለበ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለበደ),
					result  => q(ለበ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለበበ),
					result  => q(ለበ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለበቀ),
					result  => q(ለበ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለበሰ),
					result  => q(ለበሰ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለበለበ),
					result  => q(ለበለ፟በ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቅላቂ),
					result  => q(ለቅላ፟ቂ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቅለቅ),
					result  => q(ለቅለቅ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቃቀመ),
					result  => q(ለቃቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቀቅ),
					result  => q(ለቀ፟ቅ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቀቀ),
					result  => q(ለቀ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቀስተኛ),
					result  => q(ለቀ፟ስተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቀም),
					result  => q(ለቀም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቀመ),
					result  => q(ለቀ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለቀለቀ),
					result  => q(ለቀለ፟ቀ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለሸለሸ),
					result  => q(ለሸለ፟ሸ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለስላሳነት),
					result  => q(ለስላሳ፟ነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለስላሳ),
					result  => q(ለስላሳ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለስ),
					result  => q(ለስ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለሳኝ),
					result  => q(ለሳ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለሱ),
					result  => q(ለሱ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለሰነ),
					result  => q(ለሰ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለሰሰ),
					result  => q(ለሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለሰለሰ),
					result  => q(ለሰለ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለምነት),
					result  => q(ለምነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለማጣ),
					result  => q(ለማ፟ጣ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለማዳነት),
					result  => q(ለማ፟ዳነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለማዳ),
					result  => q(ለማ፟ዳ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለማኝነት),
					result  => q(ለማ፟ኝነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለማኝ),
					result  => q(ለማ፟ኝ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለማመደ),
					result  => q(ለማመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለማ),
					result  => q(ለማ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለመጥ),
					result  => q(ለመ፟ጥ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለመጠ),
					result  => q(ለመ፟ጠ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለመደ),
					result  => q(ለመ፟ደ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለመዘገ),
					result  => q(ለመዘ፟ገ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለመነ),
					result  => q(ለመ፟ነ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለመሰሰ),
					result  => q(ለመሰ፟ሰ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ለመለመ),
					result  => q(ለመለ፟መ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሆጃ),
					result  => q(ሆጃ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሆኖም),
					result  => q(ሆኖም፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሆነበት),
					result  => q(ሆነበ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሆነለት),
					result  => q(ሆነለ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሆሳዕና),
					result  => q(ሆሳ፟ዕና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ህክምና),
					result  => q(ህክ፟ምና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ህልውና),
					result  => q(ህል፟ውና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ህላዌ),
					result  => q(ህላ፟ዌ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሃይማኖተኛ),
					result  => q(ሃይማኖተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሃያኛ),
					result  => q(ሃያኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሂስና),
					result  => q(ሂስና፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁከተኛ),
					result  => q(ሁከተኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁነኛ),
					result  => q(ሁነኛ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁልጊዜ),
					result  => q(ሁል፟ጊዜ),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁል),
					result  => q(ሁል፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁሌ),
					result  => q(ሁሌ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁሉም),
					result  => q(ሁሉ፟ም),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁሉ),
					result  => q(ሁሉ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁለት),
					result  => q(ሁለት፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁለቴ),
					result  => q(ሁለቴ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁለተ),
					result  => q(ሁለተ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁለመና),
					result  => q(ሁለ፟መና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሁለ),
					result  => q(ሁለ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሀች),
					result  => q(ሀች፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሀቻምና),
					result  => q(ሀቻ፟ምና),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ሀብታምነት),
					result  => q(ሀብታምነ፟ት),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ገባ),
					result  => q(ገባ፟),
					revisit => 0,
				},
				{
					before  => q(),
					after   => q(),
					replace => q(ግል),
					result  => q(ግል፟),
					revisit => 0,
				},
			]
		},
	] },
);

no Moo;

1;

# vim: tabstop=4
